import { ethers, Signer, providers, BigNumber, ContractTransaction } from "ethers";
import { FxTokenAddressMap } from "../config";
import { BridgeNetwork, BridgeNetworkMap } from "..";
export type BridgeConfigByNetwork = BridgeNetworkMap<{
    address: string;
    id: number;
}>;
export type BridgeConfig = {
    apiBaseUrl: string;
    byNetwork: BridgeConfigByNetwork;
    forexAddress: string;
    fxTokenAddresses: FxTokenAddressMap;
};
export type BridgeDepositArguments = {
    fromNetwork: BridgeNetwork;
    toNetwork: BridgeNetwork;
    tokenSymbol: string;
    amount: BigNumber;
};
export type BridgeWithdrawArguments = {
    tokenSymbol: string;
    amount: BigNumber;
    nonce: BigNumber;
    fromNetwork: BridgeNetwork;
    toNetwork: BridgeNetwork;
    signature: string;
    address?: string;
};
export type BridgeGetNonceArguments = {
    fromNetwork: BridgeNetwork;
    toNetwork: BridgeNetwork;
    address?: string;
};
export type PendingWithdrawal = {
    txHash: string;
    tokenSymbol: string;
    amount: BigNumber;
    nonce: BigNumber;
    fromNetwork: BridgeNetwork;
    toNetwork: BridgeNetwork;
};
export default class Bridge {
    config: BridgeConfig;
    constructor(c?: BridgeConfig);
    deposit: (args: BridgeDepositArguments, signer: Signer, options?: ethers.Overrides) => Promise<ContractTransaction>;
    doesDepositMeetMinimumAmount: (tokenSymbol: string, amount: BigNumber, withdrawNetwork: BridgeNetwork) => Promise<boolean>;
    getTokenFee: (tokenSymbol: string, withdrawNetwork: BridgeNetwork) => Promise<BigNumber>;
    withdraw: (args: BridgeWithdrawArguments, signer: Signer, options?: ethers.Overrides) => Promise<ContractTransaction>;
    requestAutomaticWithdraw: (network: BridgeNetwork, txHash: string) => Promise<any>;
    getDepositAllowance: (account: string, token: string, network: BridgeNetwork, signer: Signer) => Promise<BigNumber>;
    setDepositAllowance: (token: string, network: BridgeNetwork, amount: BigNumber, signer: Signer, options?: ethers.Overrides) => Promise<ContractTransaction>;
    getPendingWithdrawals: (account: string, signers: BridgeNetworkMap<Signer>) => Promise<PendingWithdrawal[]>;
    getWithdrawSignature: (network: BridgeNetwork, txHash: string) => Promise<any>;
    getWithdrawNonce: (args: BridgeGetNonceArguments, signer: Signer) => Promise<BigNumber>;
    private getPendingWithdrawsForNetwork;
    private getTokenAddress;
    private getTokenSymbolFromAddress;
    getBridgeContract: (network: BridgeNetwork, signerOrProvider: Signer | providers.Provider) => import("../contracts").Bridge;
    private bridgeIdToNetwork;
}
