import { ERC20__factory } from "../contracts";
import { callMulticallObjects, createMulticallProtocolContracts, } from "../utils/contract";
import sdkConfig from "../config";
import Graph from "./graph";
import { BENTOBOX_ADDRESS } from "@sushiswap/core-sdk";
import { NETWORK_NAME_TO_CHAIN_ID } from "../constants";
import { getFxTokensFromAddresses } from "../utils/fxToken";
import { HandleTokenManagerInstance } from "./token-manager/HandleTokenManager";
export default class FxTokens {
    constructor(c) {
        this.getFxTokens = async (provider) => {
            const { provider: multicallProvider } = createMulticallProtocolContracts(this.config.protocolAddresses, this.config.chainId, provider);
            const multicalls = this.tokens.map((a) => this.getFxTokenMulticall(a.symbol, provider));
            const raw = await callMulticallObjects(multicalls, multicallProvider);
            return raw.map((t, index) => this.includeTokenPrice(this.tokens[index], t.price));
        };
        this.getIndexedFxTokens = async () => {
            const fxTokens = await this.graph.fxTokens.query({});
            return fxTokens
                .map(this.indexedToFxToken)
                .filter((fx) => this.tokens.find((t) => t.address.toLowerCase() === fx.address.toLowerCase()));
        };
        this.getRepayAllowance = (fxToken, account, signer) => {
            const contract = this.getFxTokenContract(fxToken, signer);
            return contract.allowance(account, this.config.protocolAddresses.comptroller);
        };
        this.getSingleCollateralRepayAllowance = (fxToken, account, network, signer) => {
            const contract = this.getFxTokenContract(fxToken, signer);
            const chainId = NETWORK_NAME_TO_CHAIN_ID[network];
            return contract.allowance(account, BENTOBOX_ADDRESS[chainId]);
        };
        this.setRepayAllowance = (fxTokenSymbol, amount, signer, options = {}) => {
            const fxContract = this.getFxTokenContract(fxTokenSymbol, signer);
            return fxContract.approve(this.config.protocolAddresses.comptroller, amount, options);
        };
        this.setSingleCollateralRepayAllowance = (fxTokenSymbol, amount, network, signer, options = {}) => {
            const fxContract = this.getFxTokenContract(fxTokenSymbol, signer);
            const chainId = NETWORK_NAME_TO_CHAIN_ID[network];
            return fxContract.approve(BENTOBOX_ADDRESS[chainId], amount, options);
        };
        this.getFxTokenMulticall = (fxTokenSymbol, provider) => {
            const tokenAddress = this.config.fxTokenAddresses[fxTokenSymbol];
            if (!tokenAddress) {
                throw new Error(`fxTokens not initialised with token that matches: ${fxTokenSymbol}`);
            }
            const { contracts } = createMulticallProtocolContracts(this.config.protocolAddresses, this.config.chainId, provider);
            return {
                price: contracts.handle.getTokenPrice(tokenAddress),
            };
        };
        this.includeTokenPrice = (token, price) => {
            return {
                ...token,
                price,
            };
        };
        this.indexedToFxToken = (fxToken) => {
            // note that address does not matter in this case, as all fx tokens have the same addresses across chains
            const fullFxToken = HandleTokenManagerInstance.getTokenByAddress(fxToken.address, 1);
            if (!fullFxToken)
                throw new Error("Could not find fxToken to match indexed fxToken");
            return {
                ...fullFxToken,
                ...fxToken,
                price: fxToken.rate,
            };
        };
        this.getFxTokenContract = (fxTokenSymbol, signer) => {
            const tokenAddress = this.config.fxTokenAddresses[fxTokenSymbol];
            if (!tokenAddress) {
                throw new Error(`fxTokens not initialised with token that matches: ${fxTokenSymbol}`);
            }
            return ERC20__factory.connect(tokenAddress, signer);
        };
        this.config = c || {
            protocolAddresses: sdkConfig.protocol.arbitrum.protocol,
            fxTokenAddresses: sdkConfig.fxTokenAddresses,
            chainId: NETWORK_NAME_TO_CHAIN_ID.arbitrum,
            graphEndpoint: sdkConfig.theGraphEndpoints.arbitrum.fx,
        };
        this.tokens = getFxTokensFromAddresses(Object.values(this.config.fxTokenAddresses));
        this.graph = new Graph(this.config.graphEndpoint);
    }
}
