import { LpStakingData, AnyLpStaking, LpStakingName } from "../types/lp/staking";
import { BigNumber, ContractTransaction, Overrides, Signer } from "ethers";
export type LpStakingConfig = {
    pools: Record<LpStakingName, AnyLpStaking>;
    forexAddress: string;
    chainId: number;
};
export type LpStakingPoolMulticall = {
    totalDeposited: BigNumber;
    lpTokenTotalSupply: BigNumber;
    distributionRate: BigNumber;
    distributionPeriodEnds: BigNumber;
    distributionDuration: BigNumber;
    rewardsBalance: BigNumber;
    deposited?: BigNumber;
    claimableRewards?: BigNumber;
};
export type StakeAndWithdrawArgs = {
    poolName: LpStakingName;
    amount: BigNumber;
};
export default class LpStaking {
    config: LpStakingConfig;
    constructor(c?: LpStakingConfig);
    getPools: (account: string | undefined, signer: Signer) => Promise<LpStakingData[]>;
    stake: (args: StakeAndWithdrawArgs, signer: Signer, options?: Overrides) => Promise<ContractTransaction>;
    unstake: (args: StakeAndWithdrawArgs, signer: Signer, options?: Overrides) => Promise<ContractTransaction>;
    claim: (poolName: LpStakingName, signer: Signer, options?: Overrides) => Promise<ContractTransaction>;
    private getMulticall;
    private getTokenDepositedIntoLP;
    private getContract;
}
