import { ethers } from "ethers";
import { createVault } from "../utils/vault";
export default class VaultController {
    constructor(currentVault, protocolParameters, fxToken, collaterals) {
        this.currentVault = currentVault;
        this.protocolParameters = protocolParameters;
        this.fxToken = fxToken;
        this.collaterals = collaterals;
        this.setDebt = (debt) => {
            this.vault = createVault({
                ...this.vault,
                debt,
            }, this.protocolParameters, this.fxToken, this.collaterals);
        };
        this.addDebt = (amount) => {
            const fee = amount
                .mul(this.protocolParameters.mintFee)
                .div(ethers.constants.WeiPerEther);
            this.setDebt(this.currentVault.debt.add(amount).add(fee));
        };
        this.removeDebt = (amount) => {
            this.setDebt(this.currentVault.debt.sub(amount));
        };
        this.setCollateral = (symbol, amount) => {
            const currentCollateral = this.getCollateral(symbol);
            const updatedCollateral = {
                ...currentCollateral,
                amount,
            };
            const collateral = [
                ...this.currentVault.collateral.filter((collateral) => collateral.symbol !== symbol),
                updatedCollateral,
            ];
            this.vault = createVault({
                ...this.vault,
                collateral,
            }, this.protocolParameters, this.fxToken, this.collaterals);
        };
        this.addCollateral = (symbol, amount) => {
            const currentCollateral = this.getCollateral(symbol);
            const fee = amount
                .mul(this.protocolParameters.depositFee)
                .div(ethers.constants.WeiPerEther);
            this.setCollateral(symbol, currentCollateral.amount.add(amount).sub(fee));
        };
        this.removeCollateral = (symbol, amount) => {
            const currentCollateral = this.getCollateral(symbol);
            this.setCollateral(symbol, currentCollateral.amount.sub(amount));
        };
        this.resetCollateral = () => {
            this.vault = createVault({
                ...this.vault,
                collateral: this.currentVault.collateral,
            }, this.protocolParameters, this.fxToken, this.collaterals);
        };
        this.getCollateral = (symbol) => {
            const collateral = this.currentVault.collateral.find((collateral) => collateral.symbol === symbol);
            if (!collateral) {
                throw new Error("Symbol doesnt match any collateral in vault");
            }
            return collateral;
        };
        this.vault = createVault(currentVault, protocolParameters, fxToken, collaterals);
    }
}
