import { ethers } from "ethers";
import { FxToken } from "../types/fxTokens";
import { Collateral, CollateralSymbolWithNative } from "../types/collaterals";
import { SingleCollateralVault, SingleCollateralVaultSymbol, Vault } from "../types/vaults";
import { ProtocolContractAddressMap, CollateralDetails, FxTokenAddressMap, SingleCollateralVaults } from "../config";
import { ProtocolParameters } from "./Protocol";
import { SingleCollateralVaultNetwork } from "../types/network";
export type VaultsConfig = {
    forexTokenAddress: string;
    protocolAddresses: ProtocolContractAddressMap;
    fxTokenAddresses: FxTokenAddressMap;
    collaterals: CollateralDetails;
    singleCollateralVaults: SingleCollateralVaults;
    chainId: number;
    graphEndpoint: string;
};
type MintArguments = {
    fxToken: string;
    amount: ethers.BigNumber;
    collateral?: {
        symbol: CollateralSymbolWithNative;
        amount: ethers.BigNumber;
    };
    deadline?: number;
    referral?: string;
};
type DepositCollateralArguments = {
    account: string;
    fxToken: string;
    collateral: CollateralSymbolWithNative;
    amount: ethers.BigNumber;
    referral?: string;
};
type BurnArguments = {
    amount: ethers.BigNumber;
    fxToken: string;
    deadline?: number;
};
type WithdrawCollateralArguments = {
    account: string;
    fxToken: string;
    collateral: CollateralSymbolWithNative;
    amount: ethers.BigNumber;
};
type SingleCollateralMintAndDepositArguments = {
    network: SingleCollateralVaultNetwork;
    vaultSymbol: SingleCollateralVaultSymbol;
    mintAmount?: ethers.BigNumber;
    depositAmount?: ethers.BigNumber;
    approveKashiSignature?: ethers.Signature;
};
type SingleCollateralBurnAndWithdrawArguments = {
    network: SingleCollateralVaultNetwork;
    vaultSymbol: SingleCollateralVaultSymbol;
    burnAmount?: ethers.BigNumber;
    withdrawAmount?: ethers.BigNumber;
};
type SingleCollateralSupplyFxToken = {
    network: SingleCollateralVaultNetwork;
    vaultSymbol: SingleCollateralVaultSymbol;
    amount: ethers.BigNumber;
    approveKashiSignature?: ethers.Signature;
};
export default class Vaults {
    private config;
    private fxTokens;
    private collaterals;
    private protocolParameters;
    private fxTokensSDK;
    private collateralsSDK;
    private protocolSDK;
    private graph;
    private initialised;
    constructor(c?: VaultsConfig);
    initAsync: (provider?: ethers.providers.Provider) => Promise<void>;
    initSync: (protocolParamters: ProtocolParameters, fxTokens: FxToken[], collaterals: Collateral[]) => void;
    getVaults: (account: string, provider?: ethers.providers.Provider, shouldAutoInitialise?: boolean) => Promise<Vault[]>;
    getVault: (account: string, fxTokenSymbol: string, signer: ethers.Signer) => Promise<Vault>;
    getSingleCollateralVault: (account: string, vaultSymbol: SingleCollateralVaultSymbol, network: SingleCollateralVaultNetwork, signer: ethers.Signer) => Promise<SingleCollateralVault>;
    getIndexedVault: (account: string, fxTokenSymbol: string) => Promise<Vault>;
    getIndexedVaults: (account: string) => Promise<Vault[]>;
    getSingleCollateralVaults: (account: string, network: SingleCollateralVaultNetwork, signer: ethers.Signer) => Promise<SingleCollateralVault[]>;
    mint: (args: MintArguments, signer: ethers.Signer, options?: ethers.Overrides) => Promise<ethers.ContractTransaction>;
    mintAndDepositSingleCollateral: (args: SingleCollateralMintAndDepositArguments, signer: ethers.Signer, options?: ethers.Overrides) => Promise<ethers.ContractTransaction>;
    burnAndWithdrawSingleCollateral: (args: SingleCollateralBurnAndWithdrawArguments, signer: ethers.Signer, options?: ethers.Overrides) => Promise<ethers.ContractTransaction>;
    supplyFxTokenSingleCollateral: (args: SingleCollateralSupplyFxToken, signer: ethers.Signer, options?: ethers.Overrides) => Promise<ethers.ContractTransaction>;
    depositCollateral: (args: DepositCollateralArguments, signer: ethers.Signer, options?: ethers.Overrides) => Promise<ethers.ContractTransaction>;
    burn: (args: BurnArguments, signer: ethers.Signer, options?: ethers.Overrides) => Promise<ethers.ContractTransaction>;
    withdrawCollateral: (args: WithdrawCollateralArguments, signer: ethers.Signer, options?: ethers.Overrides) => Promise<ethers.ContractTransaction>;
    private getVaultMulitcall;
    private createMulticallObjectForVaultCollateralBalance;
    private chainDataToVault;
    private indexedDataToVault;
    private initialisationCheck;
    private createEmptyIndexedVault;
}
export {};
