import { BigNumber, ethers, Signer } from "ethers";
import { Network } from "../../types/network";
import { TokenInfo } from "@uniswap/token-lists";
type ConvertRouteArgs = {
    fromToken: TokenInfo;
    toToken: TokenInfo;
    sellAmount: BigNumber;
    gasPrice?: BigNumber;
    network: Network;
};
export type ConvertQuoteRouteArgs = ConvertRouteArgs & {
    provider: ethers.providers.Provider;
    receivingAccount?: string;
};
export type ConvertTransactionRouteArgs = ConvertRouteArgs & {
    buyAmount: BigNumber;
    slippage: number;
    minOut: BigNumber;
    signer: Signer;
    receivingAccount: string;
    referrer?: string;
};
type ConvertInput = Omit<ConvertRouteArgs, "network">;
type ConvertQuoteInput = ConvertInput & {
    provider?: ethers.providers.Provider;
    receivingAccount?: string;
};
type ConvertTransactionInput = ConvertInput & {
    buyAmount: BigNumber;
    slippage: number;
    signer: Signer;
};
type Allowance = {
    token: TokenInfo;
    target: string;
    amount: BigNumber;
};
export type AllowanceTarget = Array<Allowance>;
export type RawQuote = {
    buyAmount: string;
    sellAmount: string;
    gas: number;
    allowanceTarget: AllowanceTarget;
    feeBasisPoints: number;
    feeChargedBeforeConvert: boolean;
};
export type Quote = RawQuote & {
    usdValues: {
        valueIn: number | undefined;
        valueOut: number | undefined;
    };
};
export default class Convert {
    private static getHighestWeightRoute;
    private static getValidatedNetwork;
    static getQuote: (input: ConvertQuoteInput) => Promise<Quote>;
    static getSwap: (input: ConvertTransactionInput) => Promise<ethers.PopulatedTransaction>;
}
export {};
