var _a;
import { BigNumber } from "ethers";
import routes from "./routes";
import { CHAIN_ID_TO_NETWORK_NAME } from "../../constants";
import { getNetworkFromSignerOrProvider } from "../../utils/general";
import { getUsdValue } from "../../utils/price";
import { HandleTokenManagerInstance } from "../token-manager/HandleTokenManager";
import { getMinOut } from "../../utils/convert";
import config from "../../config";
class Convert {
}
_a = Convert;
Convert.getHighestWeightRoute = async (weightInfo) => {
    const weightedRoutes = await Promise.all(routes.map((route) => route
        .weight(weightInfo)
        .catch((_) => 0)
        .then((calculatedWeight) => ({
        quote: route.quote,
        transaction: route.transaction,
        calculatedWeight,
    }))));
    weightedRoutes.sort((a, b) => b.calculatedWeight - a.calculatedWeight);
    const route = weightedRoutes[0];
    if (route.calculatedWeight === 0) {
        throw new Error(`No route found for ${weightInfo.fromToken.symbol} and ${weightInfo.toToken.symbol}`);
    }
    return route;
};
Convert.getValidatedNetwork = async (token1, token2, signerOrProvider) => {
    // ensures tokens are on same network
    if (token1.chainId !== token2.chainId) {
        throw new Error(`Tokens ${token1.symbol} and ${token2.symbol} are on different chains`);
    }
    const network = CHAIN_ID_TO_NETWORK_NAME[token1.chainId];
    // ensures network is supported
    if (!network) {
        throw new Error(`Token ${token1.symbol} is on an unsupported chain`);
    }
    // if there is a signer or provider, make sure it is on the same chain as the token
    if (signerOrProvider &&
        network !== (await getNetworkFromSignerOrProvider(signerOrProvider))) {
        throw new Error(`Signer/Provider is on a different network than the tokens`);
    }
    return network;
};
Convert.getQuote = async (input) => {
    const network = await Convert.getValidatedNetwork(input.fromToken, input.toToken, input.provider);
    const provider = input.provider || config.providers[network];
    const route = await _a.getHighestWeightRoute({
        fromToken: input.fromToken,
        toToken: input.toToken,
        provider,
        network: network,
    });
    const quoteInput = {
        ...input,
        provider,
        network,
    };
    await HandleTokenManagerInstance.initialLoad;
    const quote = await route.quote(quoteInput);
    const [volumeIn, volumeOut] = await Promise.all([
        getUsdValue(input.fromToken, BigNumber.from(quote.sellAmount)),
        getUsdValue(input.toToken, BigNumber.from(quote.buyAmount)),
    ]);
    return {
        ...quote,
        usdValues: {
            valueIn: volumeIn,
            valueOut: volumeOut,
        },
    };
};
Convert.getSwap = async (input) => {
    const network = await Convert.getValidatedNetwork(input.fromToken, input.toToken, input.signer);
    if (!input.signer.provider)
        throw new Error("signer must have provider");
    const route = await _a.getHighestWeightRoute({
        fromToken: input.fromToken,
        toToken: input.toToken,
        provider: input.signer.provider,
        network: network,
    });
    const receivingAccount = await input.signer.getAddress();
    await HandleTokenManagerInstance.initialLoad;
    const tx = await route.transaction({
        ...input,
        // DEPRECATED. TODO: remove.
        referrer: undefined,
        network,
        receivingAccount,
        minOut: getMinOut(input.buyAmount, input.slippage),
    });
    // insert gas estimate depending on tx type
    if (tx.type === 2) {
        tx.maxFeePerGas = input.gasPrice;
    }
    else {
        tx.gasPrice = input.gasPrice;
    }
    return tx;
};
export default Convert;
