import { config } from "../../..";
import { WETH__factory } from "../../../contracts";
import { HandleTokenManagerInstance } from "../../token-manager/HandleTokenManager";
import { WETH_WEIGHT } from "./weights";
const wethWeight = async (input) => {
    const weth = HandleTokenManagerInstance.getHlpWrappedNativeToken(input.network)?.address;
    if (!weth)
        return 0;
    if ((input.fromToken.address.toLowerCase() === weth.toLowerCase() &&
        input.toToken.extensions?.isNative) ||
        (input.toToken.address.toLowerCase() === weth.toLowerCase() &&
            input.fromToken.extensions?.isNative)) {
        return WETH_WEIGHT;
    }
    return 0;
};
const wethQuoteHandler = async (input) => {
    return {
        allowanceTarget: [],
        buyAmount: input.sellAmount.toString(),
        sellAmount: input.sellAmount.toString(),
        gas: config.convert.gasEstimates.weth,
        feeBasisPoints: 0,
        feeChargedBeforeConvert: false,
    };
};
const wethTransactionHandler = async (input) => {
    const { fromToken, toToken, network, sellAmount, signer } = input;
    const weth = HandleTokenManagerInstance.getHlpWrappedNativeToken(input.network)?.address;
    if (input.minOut.gt(input.sellAmount)) {
        throw new Error("Min out not met");
    }
    if (!weth)
        throw new Error(`No WETH contract found for ${network}`);
    if (fromToken.extensions?.isNative && toToken.address === weth) {
        return WETH__factory.connect(weth, signer).populateTransaction.deposit({
            value: sellAmount,
        });
    }
    if (toToken.extensions?.isNative && fromToken.address === weth) {
        return WETH__factory.connect(weth, signer).populateTransaction.withdraw(sellAmount);
    }
    throw new Error("Invalid WETH swap");
};
export default {
    weight: wethWeight,
    quote: wethQuoteHandler,
    transaction: wethTransactionHandler,
};
