import config from "../config";
import { fetchPromisifiedObject, getGovernanceLockContract, } from "../utils/contract";
import { fetchCacheApi } from "../utils/sdk";
const MAX_LOCK_SECONDS = 365 * 24 * 60 * 60;
export const getData = async (account, isRetired = false) => {
    if (!account && config.sdk.shouldUseCacheServer) {
        return fetchCacheApi("earn-pools/governance");
    }
    const response = await fetchPromisifiedObject(getGovernanceLockDataMulticall(account, isRetired));
    return {
        totalForexLocked: response.totalForexLocked,
        account: response.acountLocked?.amount &&
            response.acountLocked?.end &&
            response.accountBalance
            ? {
                forexLocked: response.acountLocked?.amount,
                unlocksAt: response.acountLocked?.end,
                veForexBalance: response.accountBalance,
            }
            : undefined,
    };
};
export const createLock = (args, signer, options = {}) => {
    if (args.durationInSeconds > MAX_LOCK_SECONDS) {
        throw new Error(`Duration cannot be greater than ${MAX_LOCK_SECONDS} seconds`);
    }
    const unlockDate = Math.floor(Date.now() / 1000 + args.durationInSeconds);
    return getGovernanceLockContract(signer).createLock(args.forexAmount, unlockDate, options);
};
export const increaseLockedAmount = (forexAmount, signer, options = {}) => getGovernanceLockContract(signer).increaseAmount(forexAmount, options);
export const increaseLockDurationBy = (args, signer, options = {}) => {
    const newUnlocksAt = Math.floor(args.currentUnlocksAt.toNumber() + args.increaseDurationByInSeconds);
    const now = Date.now() / 1000;
    if (newUnlocksAt - now > MAX_LOCK_SECONDS) {
        throw new Error(`Duration cannot be greater than ${MAX_LOCK_SECONDS} seconds`);
    }
    return getGovernanceLockContract(signer).increaseUnlockTime(newUnlocksAt, options);
};
export const withdraw = (signer, options = {}, isRetired = false) => getGovernanceLockContract(signer, isRetired).withdraw(options);
const getGovernanceLockDataMulticall = (account, isRetired = false) => {
    const contract = getGovernanceLockContract(undefined, isRetired);
    const base = {
        totalForexLocked: contract.supply(),
    };
    if (account) {
        return {
            ...base,
            acountLocked: contract.locked(account),
            accountBalance: contract.balanceOf(account),
        };
    }
    return base;
};
