import { ethers } from "ethers";
import { gql } from "graphql-request/dist";
import { buildFilter } from "../utils";
export default class CollateralGraphClient {
    constructor(client, chainId) {
        this.client = client;
        this.chainId = chainId;
        this.query = async (filter) => {
            const data = await this.client.request(this.getQueryString(filter));
            const tokens = data?.collateralTokens;
            if (tokens == null)
                throw new Error("Could not read collateral tokens");
            return tokens.map((t) => ({
                ...t,
                symbol: t.symbol,
                address: t.id,
                mintCollateralRatio: ethers.BigNumber.from(t.mintCollateralRatio),
                interestRate: ethers.BigNumber.from(t.interestRate),
                liquidationFee: ethers.BigNumber.from(t.liquidationFee),
                totalBalance: ethers.BigNumber.from(t.totalBalance),
                rate: ethers.BigNumber.from(t.rate),
                name: t.name,
                chainId: this.chainId,
            }));
        };
        this.getQueryString = (filter) => gql `
  query {
    collateralTokens${buildFilter(filter)} {
      id
      name
      symbol
      mintCollateralRatio
      liquidationFee
      interestRate
      totalBalance
      isValid
      decimals
      rate
    }
  }
`;
    }
}
