import { ethers } from "ethers";
import { gql } from "graphql-request/dist";
import { buildFilter } from "../utils";
export default class FxKeeperPoolGraphClient {
    constructor(client) {
        this.client = client;
        this.query = async (filter) => {
            const data = await this.client.request(this.getQueryString(filter));
            const pools = data?.fxKeeperPools;
            if (pools == null)
                throw new Error("Could not read fxTokens");
            return data.fxKeeperPools.map((pool) => ({
                ...pool,
                address: pool.id,
                totalDeposits: ethers.BigNumber.from(pool.totalDeposits),
                depositorCount: ethers.BigNumber.from(pool.depositorCount),
                liquidationsExecuted: ethers.BigNumber.from(pool.liquidationsExecuted),
                collateralTokens: pool.collateralTokens.map((ct) => ({
                    address: ct.address,
                    amount: ethers.BigNumber.from(ct.amount),
                })),
            }));
        };
        this.getQueryString = (filter) => gql `
  query {
    fxKeeperPools${buildFilter(filter)} {
      id
      fxToken
      totalDeposits
      depositorCount
      liquidationsExecuted
      collateralTokens {
        address
        amount
      }
      collateralAddresses
    }
  }
`;
    }
}
