import { ethers } from "ethers";
import { gql } from "graphql-request/dist";
import { buildFilter } from "../utils";
export default class FxTokenGraphClient {
    constructor(client) {
        this.client = client;
        this.query = async (filter) => {
            const data = await this.client.request(this.getQueryString(filter));
            const tokens = data?.fxTokens;
            if (tokens == null)
                throw new Error("Could not read fxTokens");
            return tokens.map((t) => ({
                ...t,
                address: t.id.toLowerCase(),
                totalSupply: ethers.BigNumber.from(t.totalSupply),
                rate: ethers.BigNumber.from(t.rate),
            }));
        };
        this.getQueryString = (filter) => gql `
  query {
    fxTokens${buildFilter(filter)} {
      id
      name
      symbol
      totalSupply
      isValid
      decimals
      rate
    }
  }
`;
    }
}
