import { gql } from "graphql-request/dist";
import { buildFilter } from "../utils";
export default class VaultGraphClient {
    constructor(client, fxTokenGraphClient) {
        this.client = client;
        this.fxTokenGraphClient = fxTokenGraphClient;
        this.queryOne = async (filter) => {
            const response = await this.query({ ...filter, first: 1 });
            return response[0];
        };
        this.query = async (filter) => {
            const data = await this.client.request(this.getQueryString(filter));
            // If the array is not present, there was an error in the request.
            if (!Array.isArray(data?.vaults))
                throw new Error("Could not load indexed vault data");
            return data.vaults;
        };
        this.withLowestCRForEachFxToken = async () => {
            const tokens = await this.fxTokenGraphClient.query({});
            const result = await Promise.all(tokens.map(async (token) => this.queryOne({
                first: 1,
                where: { fxToken: token.address },
                orderBy: "collateralRatio",
                orderDirection: "asc",
            })));
            return result.filter((r) => !!r);
        };
        this.getQueryString = (filter) => gql `
  query {
    vaults${buildFilter(filter)} {
      account
      debt
      fxToken
      collateralTokens {
        address
        amount
      }
      redeemableTokens
      collateralAsEther
      collateralRatio
      minimumRatio
      isRedeemable
      isLiquidatable
    }
  }
`;
    }
}
