export type Portfolio = {
    assets: PortfolioAssets;
    liabilities: PortfolioLiabilities;
    income: PortfolioIncome;
    expenses: PortfolioExpenses;
};
export type PortfolioAssets = {
    staking: PortfolioStaking;
    governance: PortfolioGovernance;
    collateral: PortfolioCollateral;
    tradeProfits: AssetAmount[];
};
export type PortfolioStaking = {
    hlp: AssetAmount;
    keeper: AssetAmount[];
};
export type PortfolioGovernance = {
    lock: PortfolioGovernanceLock | null;
};
export type PortfolioGovernanceLock = {
    tokenSymbol: string;
    tokenAmount: number;
    untilDate: number;
    veForexBalance: number;
};
export type PortfolioCollateral = {
    cdp: PortfolioCdpCollateral[];
};
export type PortfolioCdpCollateral = {
    fxTokenSymbol: string;
    collateral: AssetAmount;
};
export type AssetAmount = {
    symbol: string;
    amount: number;
};
export type PortfolioLiabilities = {
    debt: PortfolioDebtLiability;
    tradeLosses: AssetAmount[];
};
export type PortfolioDebtLiability = {
    cdp: AssetAmount[];
};
export type PortfolioIncome = {
    tradeProfits: AssetAmount[];
    keeperGains: AssetAmount[];
    rewards: AssetAmount[];
    rebates: AssetAmount[];
    referrals: AssetAmount[];
};
export type PortfolioExpenses = {
    tradeLosses: AssetAmount[];
    bridgeFees: AssetAmount[];
    tradeFees: AssetAmount[];
    cdpInterest: AssetAmount[];
};
export declare const fetchPortfolio: (account: string) => Promise<Portfolio>;
