import axios from "axios";
import { HandleTokenManagerInstance } from "../../token-manager/HandleTokenManager";
import { NETWORK_NAME_TO_CHAIN_ID } from "../../../constants";
import config from "../../../config";
const NETWORK_MAP = {
    ethereum: "ethereum",
    polygon: "polygon-pos",
    arbitrum: "arbitrum-one",
    "arbitrum-sepolia": "arbitrum-one",
};
const getCoinGeckoNetworkName = (network) => {
    const networkMap = {
        polygon: "matic-network",
        ethereum: "ethereum",
        arbitrum: "arbitrum-one",
        "arbitrum-sepolia": "arbitrum-one",
    };
    return networkMap[network];
};
const getCoinGeckoNativeTokenId = (network) => {
    const networkMap = {
        polygon: "matic-network",
        ethereum: "ethereum",
        arbitrum: "ethereum",
        "arbitrum-sepolia": "arbitrum-one",
    };
    return networkMap[network];
};
export const fetchTokenBasics = async (address, network) => {
    const NETWORK_MAP = {
        ethereum: "ethereum",
        polygon: "polygon-pos",
        arbitrum: "arbitrum-one",
        "arbitrum-sepolia": "arbitrum-one",
    };
    const nwk = NETWORK_MAP[network];
    const { data } = await axios.get(`${config.api.baseUrl}/proxy/coingecko/coins/${nwk}/contract/${address.toLowerCase()}`);
    return {
        symbol: data.symbol,
        id: data.id,
        name: data.name,
    };
};
export const fetchTokenDetails = async (address, network) => {
    const { data } = await axios.get(`${config.api.baseUrl}/proxy/coingecko/coins/${NETWORK_MAP[network]}/contract/${address.toLowerCase()}`);
    return data;
};
export const fetchTokenPrice = async (address, network) => {
    const tokenData = await fetchTokenDetails(address, network);
    return tokenData.market_data.current_price?.usd;
};
export const fetchNativeUsdPrices = async () => {
    const NETWORK_MAP = {
        ethereum: "ethereum",
        polygon: "matic-network",
        arbitrum: "ethereum",
        "arbitrum-sepolia": "ethereum",
    };
    const { data } = await axios.get(`${config.api.baseUrl}/proxy/coingecko/simple/price`, {
        params: {
            ids: `${NETWORK_MAP.ethereum},${NETWORK_MAP.polygon}`,
            vs_currencies: "usd",
        },
    });
    return Object.keys(NETWORK_MAP).reduce((progress, ntw) => {
        const network = ntw;
        return {
            ...progress,
            [network]: data[NETWORK_MAP[network]].usd,
        };
    }, {});
};
export const fetchCoinGeckoTokenPriceData = async (network, address, fiat, days) => {
    try {
        const { data } = await axios.get(getContractRequestUrl(network, address, fiat, days));
        return data.prices.map(([date, price]) => ({
            date,
            price,
        }));
    }
    catch (error) {
        // Look up prices on ethereum if fails to get them on arb/polygon
        if (network !== "ethereum") {
            // Try to get token address on ETH, defaulting to input address on fail.
            const addressEth = HandleTokenManagerInstance.tryGetTokenByAddress(address, "ethereum")
                ?.address ?? address;
            return fetchCoinGeckoTokenPriceData("ethereum", addressEth, fiat, days);
        }
        else {
            throw error;
        }
    }
};
const getContractRequestUrl = (network, address, fiat, days) => `${config.api.baseUrl}/proxy/coingecko/coins/${getCoinGeckoNetworkName(network)}/contract/${address.toLowerCase()}/market_chart?vs_currency=${fiat.toLowerCase()}&days=${days}`;
export const fetchCoinGeckoNativeTokenPriceData = async (network, fiat, days) => {
    const { data } = await axios.get(`${config.api.baseUrl}/proxy/coingecko/coins/${getCoinGeckoNativeTokenId(network)}/market_chart?vs_currency=${fiat.toLowerCase()}&days=${days}`);
    return data.prices.map((p) => ({
        date: p[0],
        price: p[1],
    }));
};
export const fetchCoinGeckoTokenPricesData = async (network, tokenAddresses) => {
    const { data } = await axios.get(`${config.api.baseUrl}/proxy/coingecko/simple/token_price/${getCoinGeckoNetworkName(network)}?contract_addresses=${tokenAddresses
        .join("%2C")
        .toLowerCase()}&vs_currencies=usd`);
    return data;
};
export const fetchTokenDetailsFromAddress = async (address, network) => {
    const customToken = await fetchTokenDetails(address, network);
    return {
        symbol: parseIncomingTokenSymbol(customToken.symbol),
        name: customToken.name,
        address,
        // TODO: fetch correct decimal count.
        decimals: 18,
        logoURI: customToken.image?.large || "",
        chainId: NETWORK_NAME_TO_CHAIN_ID[network],
    };
};
const parseIncomingTokenSymbol = (symbol) => 
// Edge case fix because CoinGecko API returns $DG as dg
symbol === "dg" ? "$DG" : symbol.toUpperCase();
export const fetchCoinGeckoTokenPrice = async (network, token, fiat) => {
    const pricePoints = await fetchCoinGeckoTokenPriceData(network, token.address, fiat, 0);
    if (pricePoints.length < 1) {
        throw new Error(`fetchCoinGeckoTokenPrice: no price for ${token.symbol}`);
    }
    return pricePoints[0];
};
