import config from "../config";
import { Rebates__factory } from "../contracts";
import { parseMainNetwork } from "../types/network";
const FOREX = config.forexAddress;
export const getFilters = (rebates, account, token) => {
    const rebateFilter = rebates.filters.Rebate(account, token);
    const claimFilter = rebates.filters.ClaimRebate(token, null, account);
    return {
        rebateFilter,
        claimFilter,
    };
};
const getRebateContract = (network, signerOrProvider) => Rebates__factory.connect(config.protocol[parseMainNetwork(network)].protocol.rebates, signerOrProvider);
export const addListener = async (account, network, callback, provider = config.providers[network], token = FOREX) => {
    const rebates = getRebateContract(network, provider);
    const { rebateFilter, claimFilter } = getFilters(rebates, account, token);
    rebates.on(rebateFilter, callback);
    rebates.on(claimFilter, callback);
};
export const removeListener = async (account, network, callback, provider = config.providers[network], token = FOREX) => {
    const rebates = getRebateContract(network, provider);
    const { rebateFilter, claimFilter } = getFilters(rebates, account, token);
    rebates.off(rebateFilter, callback);
    rebates.off(claimFilter, callback);
};
export const getClaimAmount = async (account, network, provider = config.providers[network], token = FOREX) => {
    const rebates = getRebateContract(network, provider);
    return rebates.userTokenRebates(account, token);
};
export const claimRebates = async (signer, network, overrides, token = FOREX) => {
    const rebates = getRebateContract(network, signer);
    return rebates.claim(token, overrides);
};
