import { BigNumber } from "ethers";
export type Referrer = {
    id: number;
    parent: number | null;
    children: Referrer[];
    parentWeight: BigNumber;
    codes: ReferralCode[];
};
export type ReferralCode = {
    code: string;
    userRebate: BigNumber;
    referrals: Referral[];
};
export type Referral = EthAddressReferral | TradeAccountReferral;
export type EthAddressReferral = {
    EthAddress: {
        address: string;
    };
};
export type TradeAccountReferral = {
    TradeAccount: {
        accountId: number;
    };
};
export type ReferredTrade = {
    notionalUsd: BigNumber;
    feeUsd: BigNumber;
    blockNumer: number;
    txHash: string;
    timestamp: number;
    user: {
        TradeAccount: number;
    };
};
export declare const API_BASE = "https://staging.ref.handle.fi";
export declare const endpoints: {
    getReferrerById(id: number): string;
    getReferredTrades(id: number, fromTimestamp: number, toTimestamp: number): string;
    getUserReferrers(address: string): string;
};
export declare const fetchReferrerById: (referrerId: number) => Promise<Referrer>;
export declare const fetchReferrersByUserAddress: (userAddress: string) => Promise<Referrer[]>;
export declare const fetchReferredTrades: (referrerId: number, fromTimestamp: number, toTimestamp: number) => Promise<ReferredTrade[]>;
