import axios from "axios";
import { parseEther } from "ethers/lib/utils";
// TODO: handle multiple networks (mainnet & testnet)
export const API_BASE = "https://staging.ref.handle.fi";
export const endpoints = {
    getReferrerById(id) {
        return `${API_BASE}/referrer/${id}`;
    },
    getReferredTrades(id, fromTimestamp, toTimestamp) {
        const query = `from_timestamp=${fromTimestamp}&to_timestamp=${toTimestamp}`;
        return `${this.getReferrerById(id)}/referred/trades?${query}`;
    },
    getUserReferrers(address) {
        return `${API_BASE}/user/${address}/referrers`;
    },
};
/// Returns the referrer with all of its children, and a parent ID.
export const fetchReferrerById = async (referrerId) => axios
    .get(endpoints.getReferrerById(referrerId))
    .then((response) => mapReferrerResponse(ensureJson(response.data)));
export const fetchReferrersByUserAddress = async (userAddress) => axios
    .get(endpoints.getUserReferrers(userAddress))
    .then((response) => ensureJson(response.data).referrers.map(mapReferrerResponse));
/// Converts raw String types into BigNumber instances.
const mapReferrerResponse = (referrer) => {
    referrer.parentWeight = parseEther(String(referrer.parentWeight));
    referrer.codes = referrer.codes.map((code) => ({
        ...code,
        userRebate: parseEther(String(code.userRebate)),
    }));
    referrer.children.map(mapReferrerResponse);
    return referrer;
};
export const fetchReferredTrades = async (referrerId, fromTimestamp, toTimestamp) => axios
    .get(endpoints.getReferredTrades(referrerId, fromTimestamp, toTimestamp))
    .then((response) => response.data.trades.map(mapReferredTradeResponse));
const mapReferredTradeResponse = (referredTrade) => {
    referredTrade.notionalUsd = parseEther(String(referredTrade.notionalUsd));
    referredTrade.feeUsd = parseEther(String(referredTrade.feeUsd));
    return referredTrade;
};
const ensureJson = (data) => typeof data === "string" ? JSON.parse(String(data)) : data;
