import { TokenInfo } from "@uniswap/token-lists";
import { BigNumber } from "ethers";
import { SubscriptionId } from "../../types/general";
import { Availability, AvailableLiquidity, GetAvailabilityArgs, GetAvailableLiquidityArgs, GetTradePriceArgs, TradeLiquidityPool, LpTradeArgs, MarketPrice, OrderArgs, SubscribeMarketPriceArgs, TradeEffect, TradePair, LpId, TradeAdapter, OpenInterest, LpPairTradeabilityListener } from "./index";
import { Pair } from "../../types/trade";
import { PairState } from "./pairState";
export interface TradeLpPriceFeed {
    getLatestPrice(pair: Pair): BigNumber;
    subscribe(pair: Pair, callback: () => void): SubscriptionId;
    unsubscribe(id: SubscriptionId): void;
}
export declare class TradeLpPriceFeedH2so implements TradeLpPriceFeed {
    getLatestPrice(pair: Pair): BigNumber;
    subscribe(pair: Pair, callback: () => void): SubscriptionId;
    unsubscribe(id: SubscriptionId): void;
}
export declare class LiquidityPoolSingle implements TradeLiquidityPool {
    id: LpId;
    onUpdate?: () => void;
    private readonly tradePairs;
    private readonly underlyingToken;
    private adapter;
    private priceFeed;
    private pairTradeability;
    private pairTradeabilityListeners;
    private pairStates;
    constructor(id: LpId, tradePairs: TradePair[], underlyingToken: TokenInfo, adapter: TradeAdapter, priceFeed: TradeLpPriceFeed);
    private handleLpPublication;
    trade(args: LpTradeArgs): Promise<TradeEffect>;
    getPrice(pair: Pair, size?: BigNumber): MarketPrice;
    getTradePrice(args: GetTradePriceArgs): BigNumber;
    getOpenInterest(args: {
        pair: Pair;
    }): OpenInterest;
    getPairState(pair: Pair): PairState;
    tryGetPairState(pair: Pair): PairState | undefined;
    private adjustOpenInterestForTrade;
    subscribeToMarketPrice(args: SubscribeMarketPriceArgs): number;
    unsubscribeFromMarketPrice(id: number): void;
    getTradePairs(): TradePair[];
    getUnderlyingToken(): TokenInfo;
    getTradePair(pair: Pair): TradePair;
    shouldUsePriceImpact(pair: Pair): boolean;
    order(_: OrderArgs): Promise<void>;
    getAvailableLiquidity(_: GetAvailableLiquidityArgs): Promise<AvailableLiquidity>;
    getPairAvailability({ pair }: GetAvailabilityArgs): Availability;
    getLpTokenPrice(): Promise<BigNumber>;
    listenToLpPairTradeability(listener: LpPairTradeabilityListener): void;
}
