import glpTokenList from "../../../../../config/token-lists/glp-tokens.json";
import { validateTokenList } from "../../../../../utils/tokenlist";
import TokenManager, { getNativeTokenInfo } from "../../../../token-manager";
import { isEtherAddress } from "../../../utils";
import { GLP_NETWORK } from "../config";
export const glpTokenManager = new TokenManager({
    tokens: validateTokenList(glpTokenList).tokens,
});
/// Returns the first stable token found. Throws if not found.
export const getStableToken = () => {
    const tokens = glpTokenManager.getLoadedTokens(GLP_NETWORK);
    const stableTokens = tokens.filter((token) => token.extensions.isStable) ?? [];
    const token = stableTokens[0];
    if (!token) {
        throw new Error("getStableToken: not found");
    }
    return token;
};
export const getTokens = (includeEth = true) => [
    glpTokenManager.getLoadedTokens(GLP_NETWORK),
    // Also include ETH.
    includeEth ? [getNativeTokenInfo(GLP_NETWORK)] : [],
].flat();
export const getCollateralTokens = (_) => getTokens();
export const getTokenInfoGlpBySymbol = (symbol) => {
    const whitelistedTokens = glpTokenManager.getLoadedTokens(GLP_NETWORK);
    const token = whitelistedTokens.find((token) => token.symbol == symbol);
    if (!token) {
        throw new Error("getTokenInfoGlpBySymbol: token not found");
    }
    return token;
};
export const getTokenInfoGlpByAddress = (address) => {
    const whitelistedTokens = glpTokenManager.getLoadedTokens(GLP_NETWORK);
    const isInputNative = isEtherAddress(address);
    const token = whitelistedTokens.find((token) => !isInputNative
        ? token.address.toLowerCase() === address.toLowerCase()
        : token.symbol === "WETH");
    if (!token) {
        throw new Error("getTokenInfoGlpByAddress: collateral token not found");
    }
    return {
        token,
        isInputNative,
    };
};
