import { BigNumber } from "ethers";
import { ERC20, HLP, Router, Vault, VaultUtils, HlpManagerRouter, HlpManager, Reader, VaultPriceFeed, HlpRewardRouter, HpsmTrade, OrderBook } from "../../../../contracts";
import { SignerOrProvider } from "../../../../utils/general";
import { Network } from "../../../../types/network";
import { TokenInfo } from "@uniswap/token-lists";
import { Pair } from "../../../../types/trade";
/** Currently the only available hLP network */
export declare const DEFAULT_HLP_NETWORK: Network;
export declare const HLP_PLATFORM_NAME: "hlp";
export declare const HLP_IMAGE_URL = "https://app.handle.fi/assets/images/handle.fiLogoLightNewCut.png";
export declare const MIN_LEVERAGE: number;
export declare const FUNDING_FEE_DIVISOR = 10000;
export declare const FUNDING_RATE_PRECISION = 1000000;
export declare const READER_POSITION_PROPS_LENGTH = 7;
export declare const HANDLE_SUBGRAPH_STAGING = "https://api.thegraph.com/subgraphs/name/handle-fi/handle-trade-staging";
/**
 * Map from symbol to subgraph entity ID for Chainlink aggregator.
 * Used to fetch historic price data from Chainlink's subgraph.
 */
export declare const CHAINLINK_GQL_FEED_ID_MAP: {
    [key: string]: string;
};
export type HlpContracts = {
    vault: Vault;
    vaultUtils: VaultUtils;
    vaultPriceFeed: VaultPriceFeed;
    router: Router;
    reader: Reader;
    hlpManager: HlpManager;
    hlp: HLP;
    hlpManagerRouter: HlpManagerRouter;
    hlpRewardRouter: HlpRewardRouter;
    usdHlp: ERC20;
    sHlp: ERC20;
    hpsmTradeRouter: HpsmTrade;
    orderBook: OrderBook;
};
export declare const getHlpContracts: (network: Network, signerOrProvider?: SignerOrProvider) => HlpContracts;
export declare const isHlpAvailableForNetwork: (network: Network) => boolean;
/**
 * Gets the hlp token used directly by the Handle Liquidity Manager.
 * This is internal as users should only have access to staked hLP (shLP)
 * @param network the network the internal hlp token is on
 * @throws if there is to handle liquidity token on the network
 * @returns the internal hlp token
 */
export declare const getInternalHlpToken: (network: Network) => TokenInfo;
export declare const shouldHlpPairBeReversed: (pair: Pair) => boolean;
export declare const getActualHlpPairIfReversed: (pair: Pair) => Pair;
export declare const getReversedHlpPairIfApplicable: (pair: Pair) => Pair;
export declare const isReversedPair: (pair: Pair) => boolean;
/** hLP dynamic config */
export type HlpConfig = {
    maxLeverage: number;
    mintBurnFeeBasisPoints: number;
    taxBasisPoints: number;
    stableTaxBasisPoints: number;
    minProfitTime: number;
    marginFeeBasisPoints: number;
    swapFeeBasisPoints: number;
    stableSwapFeeBasisPoints: number;
    liquidationFee: BigNumber;
};
/**
 * Fetches and caches the hLP config, loading from cache on subsequent calls.
 * @param network The network to fetch the hLP config for.
 * @param forceReload Whether to fetch the config ignoring the cached values.
 */
export declare const fetch: (network: Network, forceReload?: boolean) => Promise<HlpConfig>;
export declare const get: (network: Network) => HlpConfig;
export declare const getMinimumTokenPurchaseAmountUsd: () => BigNumber;
export declare const HLP_TRADING_ENABLED_ON_WEEKEND: Record<string, boolean | undefined>;
export declare const initialise: () => Promise<void>;
