import { BigNumber } from "ethers";
import { Network } from "../../../../..";
import { Spread } from "../../legacyInterface";
import { HlpToken } from "./tokens";
export type Aum = Spread<BigNumber>;
/**
 * Token object containing token-specific properties from the `Vault` contract
 * which are required for the Aum calculation.
 */
type VaultToken = {
    token: string;
    poolAmount: BigNumber;
    size: BigNumber;
    averagePrice: BigNumber;
    guaranteedUsd: BigNumber;
    reservedAmount: BigNumber;
};
export type AumToken = Omit<HlpToken, "tokenWeight" | "minProfitBasisPoints" | "maxUsdHlpAmount" | "isShortable"> & Omit<VaultToken, "token"> & {
    price: BigNumber;
};
/**
 * This function replicates `HlpManager` contract's `getAums`
 * ("get assets under management"), but using the input price getters directly
 * instead of fetching the `Vault` contract's `getMinPrice` or `getMaxPrice`.
 */
export declare const getAum: (network: Network) => Promise<Aum>;
export declare const fetchAumTokens: () => Promise<Spread<AumToken[]>>;
export declare const fetchAumTokensUncached: () => Promise<Spread<AumToken[]>>;
export declare const calculateAum: (tokens: AumToken[], aumAddition: BigNumber, aumDeduction: BigNumber) => BigNumber;
export {};
