import { BigNumber } from "ethers";
import { getFeeBasisPoints } from "./getFeeBasisPoints";
import { HandleTokenManagerInstance } from "../../../../token-manager/HandleTokenManager";
export const getSwapFeeBasisPoints = (args, network = "arbitrum") => {
    const isStableSwap = HandleTokenManagerInstance.isHlpStableTokenByAddress(args.tokenIn, network) &&
        HandleTokenManagerInstance.isHlpStableTokenByAddress(args.tokenOut, network);
    const swapBasisPoints = isStableSwap
        ? args.config.stableSwapFeeBasisPoints
        : args.config.swapFeeBasisPoints;
    const taxBasisPoints = isStableSwap
        ? args.config.stableTaxBasisPoints
        : args.config.taxBasisPoints;
    const feeBasisPoints1 = getFeeBasisPoints({
        usdHlpDelta: args.usdHlpDelta,
        targetUsdHlpAmount: args.targetUsdHlpAmountTokenIn,
        usdHlpSupply: args.usdHlpSupplyTokenIn,
        increment: true,
        feeBasisPoints: BigNumber.from(swapBasisPoints),
        taxBasisPoints: BigNumber.from(taxBasisPoints),
    });
    const feeBasisPoints2 = getFeeBasisPoints({
        usdHlpDelta: args.usdHlpDelta,
        targetUsdHlpAmount: args.targetUsdHlpAmountTokenOut,
        usdHlpSupply: args.usdHlpSupplyTokenOut,
        increment: false,
        feeBasisPoints: BigNumber.from(swapBasisPoints),
        taxBasisPoints: BigNumber.from(taxBasisPoints),
    });
    // return largest fee basis points
    return feeBasisPoints1.gt(feeBasisPoints2)
        ? feeBasisPoints1
        : feeBasisPoints2;
};
