import { ethers } from "ethers";
import { fetchTokens } from "./tokens";
import { fetchUsdHlpTotalSupply } from "./fetchUsdHlpTotalSupply";
export const getTokenTargetUsdHlpAmount = async (tokenAddress) => getTokenTargetUsdHlpAmountSync(tokenAddress, await fetchTokens(), await fetchUsdHlpTotalSupply());
/// Returns all target USDhLP amounts in an object indexed by token address.
export const getAllTokenTargetUsdHlpAmounts = async () => {
    const tokens = await fetchTokens();
    const usdHlpTotalSupply = await fetchUsdHlpTotalSupply();
    return tokens.reduce((object, token) => ({
        ...object,
        [token.address]: getTokenTargetUsdHlpAmountSync(token.address, tokens, usdHlpTotalSupply),
    }), {});
};
export const getTokenTargetUsdHlpAmountSync = (tokenAddress, tokens, usdHlpTotalSupply) => {
    const token = tokens.find((x) => x.address.toLowerCase() === tokenAddress.toLowerCase());
    const totalTokenWeights = tokens.reduce((sum, token) => sum + token.tokenWeight, 0);
    if (!token || totalTokenWeights == 0)
        return ethers.constants.Zero;
    return usdHlpTotalSupply.mul(token.tokenWeight).div(totalTokenWeights);
};
