import { BigNumber } from "ethers";
import { Position } from "../../../legacyInterface";
type GetLeverageArgs = {
    size: BigNumber;
    collateral: BigNumber;
    entryFundingRate?: BigNumber;
    cumulativeFundingRate?: BigNumber;
    hasProfit: boolean;
    delta?: BigNumber;
};
type PositionDelta = {
    sizeDelta: BigNumber;
    increaseSize: boolean;
    collateralDelta: BigNumber;
    increaseCollateral: boolean;
};
/**
 * Gets the leverage of a position, including possible deltas.
 * @param leverageArgs the arguments necessary for calculating the leverage
 * @param marginFeeBasisPoints the margin fee as basis points
 * @param deltas the position deltas
 * @returns the leverage in basis points
 */
export declare const getLeverage: ({ size, collateral, entryFundingRate, cumulativeFundingRate, hasProfit, delta, }: GetLeverageArgs, marginFeeBasisPoints: number, { sizeDelta, collateralDelta, increaseCollateral, increaseSize, }?: PositionDelta) => BigNumber;
/**
 * Gets the current leverage for a positon, including potential changes.
 * @param position The position from which to get the leverage
 * @param marginFeeBasisPoints the margin fee as basis points
 * @param positionDelta Any changes to the position size or collateral
 * @param cumulativeFundingRate The cumulative funding rate of the position index token
 * @returns the new leverage in basis points
 */
export declare const getLeverageFromPosition: (position: Required<Position>, marginFeeBasisPoints: number, positionDelta?: PositionDelta, cumulativeFundingRate?: BigNumber) => BigNumber;
export {};
