import { BigNumber } from "ethers";
import { Position } from "../../../legacyInterface";
/**
 * Gets the delta for a position given the current price of the index token.
 * @param position the position from which to calculate the delta
 * @param minProfitTime the number of seconds until the position can take profit.
 * @param minProfitBasisPoints the profit percentage a position has to reach to
 * take profit before {minProfitTime}
 * @returns the current delta, and delta percentage, and pending delta of
 * the position as well as whether the position has profit. Pending delta
 * refers to the delta of the position before the minimum profit time has
 * passed, or the minimum profit delta has been exceeded.
 */
export declare const getPositionDelta: (position: Position, minProfitTime: number, minProfitBasisPoints: number, priceOverride?: BigNumber) => {
    delta: BigNumber;
    pendingDelta: BigNumber;
    pendingDeltaPercentage: BigNumber;
    hasProfit: boolean;
    deltaPercentage: BigNumber;
};
export declare const getPositionDeltaForActualPosition: (indexPrice: BigNumber, position: Pick<Position, "size" | "collateral" | "isLong" | "averagePrice" | "lastIncreasedTime">, minProfitTime: number, minProfitBasisPoints: number) => {
    delta: BigNumber;
    pendingDelta: BigNumber;
    pendingDeltaPercentage: BigNumber;
    hasProfit: boolean;
    deltaPercentage: BigNumber;
};
