import { ethers } from "ethers";
import * as config from "../../config";
import { DEFAULT_HLP_NETWORK } from "../../config";
import { getLiquidationPrice } from "../getLiquidationPrice";
import { getAvailabilityHlp, getHlpTokenFromPair, pairToTradePairHlpSync, } from "../tokens";
import { getLeverage } from "./getLeverage";
import { getPositionDelta } from "./getPositionDelta";
/**
 * Updates the position's derived properties using the latest market price
 * returned by the H2SO socket.
 */
export const getUpdatedPosition = (args) => {
    try {
        const hlpConfig = config.get(DEFAULT_HLP_NETWORK);
        return getUpdatedPositionWithDependencies(args, hlpConfig);
    }
    catch (error) {
        console.error("getUpdatedPosition", error);
        return args.position;
    }
};
const getUpdatedPositionWithDependencies = ({ position, indexPriceOverride }, hlpConfig) => {
    const token = getHlpTokenFromPair(position.pair);
    const tradePair = pairToTradePairHlpSync(position.pair);
    const { minProfitBasisPoints } = token;
    const shouldDeltaBeZero = position.collateral.isZero() ||
        !getAvailabilityHlp(tradePair.pair).isAvailable;
    const { delta, hasProfit } = shouldDeltaBeZero
        ? { delta: ethers.constants.Zero, hasProfit: false }
        : getPositionDelta(position, hlpConfig.minProfitTime, minProfitBasisPoints, indexPriceOverride);
    const canCalculateLeverage = !position.collateral
        .add(hasProfit ? delta : delta.mul(-1))
        .isZero();
    const leverage = canCalculateLeverage
        ? getLeverage({
            ...position,
            hasProfit,
            delta,
        }, hlpConfig.marginFeeBasisPoints)
        : ethers.constants.Zero;
    const liquidationPrice = getLiquidationPrice(position);
    return {
        ...position,
        delta,
        hasProfit,
        leverage,
        liquidationPrice,
    };
};
