import { BigNumber, ContractTransaction, PopulatedTransaction } from "ethers";
import { Reader } from "../../../../../../contracts";
import { Pair } from "../../../../../../types/trade";
import { Peg } from "../../../../../../utils/convert";
import { ApproveIncreasePositionArgs, CreateDecreasePositionOrderArgs, CreateIncreasePositionOrderArgs, DecreasePositionArgs, GetAllPositionArgs, GetPositionArgs, IncreasePositionArgs, MarketPrice, Position, SimulateDecreasePositionArgs, SimulateIncreasePositionArgs, SimulatePositionFees, SimulatePositionResult, UpdateDecreasePositionOrderArgs, UpdateIncreasePositionOrderArgs } from "../../../legacyInterface";
import { PositionGlp } from "../../../glp/internals/position";
import { GlpToken, TokenInfoGlp } from "../../../glp/internals/tokens";
import { getLeverage } from "./getLeverage";
import { getMaxWithdraw } from "./getMaxWithdraw";
import { getNextAveragePrice } from "./getNextAveragePrice";
import { getParsedPositionTokens } from "./getParsedPositionTokens";
import { getPositionDelta, getPositionDeltaForActualPosition } from "./getPositionDelta";
import { getPositionTokenList } from "./getPositionTokenList";
import { getTradeHistory } from "./getTradeHistory";
import { getUpdatedPosition } from "./getUpdatedPosition";
import { parseContractPosition } from "./parseContractPosition";
import { splitPositionArray } from "./splitPositionArray";
declare const approveIncreasePosition: ({ collateralAddress, collateralDelta, signer, overrides, maximise, }: ApproveIncreasePositionArgs) => Promise<PopulatedTransaction[]>;
declare const approveCreateIncreasePositionOrder: (args: ApproveIncreasePositionArgs) => Promise<PopulatedTransaction[]>;
declare const createIncreasePositionOrder: (args: CreateIncreasePositionOrderArgs) => Promise<ContractTransaction>;
declare const increasePosition: (args: IncreasePositionArgs) => Promise<ContractTransaction>;
declare const updateIncreasePositionOrder: (args: UpdateIncreasePositionOrderArgs) => Promise<ContractTransaction>;
declare const createDecreasePositionOrder: (args: CreateDecreasePositionOrderArgs) => Promise<ContractTransaction>;
declare const updateDecreasePositionOrder: (args: UpdateDecreasePositionOrderArgs) => Promise<ContractTransaction>;
declare const decreasePosition: ({ signer, pair, collateralAddress, receiveCollateralAddress, isLong, collateralDelta, indexDelta, receiver, overrides, slippagePercent, }: DecreasePositionArgs) => Promise<ContractTransaction>;
declare const getPosition: (args: GetPositionArgs) => Promise<Position>;
export declare const getPositionForGlpLikePlatform: ({ pair, collateralAddress, account, isLong, provider }: GetPositionArgs, getAllPositions: (args: GetAllPositionArgs) => Promise<Position[]>) => Promise<Position>;
/**
 * Retrieves all hLP positions for an account, including zero positions.
 */
export declare const getAllPositions: ({ account, provider, }: GetAllPositionArgs) => Promise<Position[]>;
export declare const getAllPositionsForGlpLikePlatform: (account: string, tokens: GlpToken[], reader: Reader, vaultAddress: string, readerPositionPropsLength: number, platformName: string, getMarketPrice: (pair: Pair) => MarketPrice) => Promise<PositionGlp[]>;
declare const simulateIncreasePosition: ({ position, input, indexPriceOverride, }: SimulateIncreasePositionArgs) => SimulatePositionResult;
declare const simulateDecreasePosition: ({ position, input, indexPriceOverride, }: SimulateDecreasePositionArgs) => SimulatePositionResult;
/**
 * Calculates position fees from increasing or decreasing a position.
 * The following fees apply:
 * - Margin fee, applied to the delta of the position size
 * - Swap fee, applied if adding or removing collateral when the input
 *   collateral address differs from the position, requiring a swap.
 * As it is a sync function, it relies on a valid cache of the hLP config,
 * or throws if it does not exist.
 */
export declare const getSimulatePositionFees: (isIncrease: boolean, sizeDelta: BigNumber, collateralDelta: BigNumber, actualCollateralAddress: string, inputCollateralAddress: string, stableSwapFeeBasisPoints: number, swapFeeBasisPoints: number, marginFeeBasisPoints: number, getTokenByAddress: (address: string) => TokenInfoGlp, hpsmPeg?: Peg) => SimulatePositionFees;
export { approveIncreasePosition, approveCreateIncreasePositionOrder, increasePosition, decreasePosition, createIncreasePositionOrder, createDecreasePositionOrder, updateDecreasePositionOrder, updateIncreasePositionOrder, getLeverage, getNextAveragePrice, getParsedPositionTokens, getPosition, getPositionDelta, getPositionDeltaForActualPosition, getPositionTokenList, getTradeHistory, parseContractPosition, splitPositionArray, getMaxWithdraw, getUpdatedPosition, simulateIncreasePosition, simulateDecreasePosition, };
