import { ethers, constants } from "ethers";
import { HLP_PLATFORM_NAME, shouldHlpPairBeReversed } from "../../config";
import { getHlpPairFromIndex } from "../getHlpPairFromIndex";
import { getReversedPair, getReversedPrice, } from "../../../../../../utils/general";
import { getFundingFee } from "../getFundingFee";
import { ETH_ADDRESS } from "../../../../utils";
const getPositionKey = (account, collateralTokenAddress, indexTokenAddress, isLong, nativeTokenAddress = ETH_ADDRESS) => {
    const tokenAddress0 = collateralTokenAddress === constants.AddressZero
        ? nativeTokenAddress
        : collateralTokenAddress;
    const tokenAddress1 = indexTokenAddress === constants.AddressZero
        ? nativeTokenAddress
        : indexTokenAddress;
    return `${account}:${tokenAddress0}:${tokenAddress1}:${isLong}`;
};
export const parseContractPosition = (contractPosition, collateralToken, indexToken, isLong, fundingRate) => {
    const [size, collateral, averagePrice, entryFundingRate, reserveAmount, realisedPnL, hasRealisedProfit, lastIncreasedTime,] = contractPosition;
    const actualPosition = {
        collateralAddress: collateralToken,
        size: size,
        collateral: collateral,
        averagePrice,
        reserveAmount,
        hasRealisedProfit,
        realisedPnL,
        lastIncreasedTime,
        isLong,
        pair: getHlpPairFromIndex(indexToken),
        fundingRatePpm: fundingRate.regular,
        fundingFee: getFundingFee(size, entryFundingRate, fundingRate.cumulative),
        uid: getPositionKey(ethers.constants.AddressZero, collateralToken, indexToken, isLong),
        platformName: HLP_PLATFORM_NAME,
        internals: {
            entryFundingRate,
            cumulativeFundingRate: fundingRate.cumulative,
        },
        // The properties below are determined by the current market price,
        // and are updated by calling getUpdated.
        hasProfit: false,
        delta: ethers.constants.Zero,
        leverage: ethers.constants.Zero,
        liquidationPrice: ethers.constants.Zero,
    };
    return getReversedPositionHlp(actualPosition);
};
/// Reverses the position if needed, according to its hLP pair.
export const getReversedPositionHlp = (position) => {
    const shouldReverse = shouldHlpPairBeReversed(position.pair) && !isPositionHlpReversed(position);
    return shouldReverse ? reversePosition(position) : position;
};
/// Un-reverses the position if needed, according to its hLP pair.
export const getActualPositionHlp = (position) => {
    const shouldReverse = !shouldHlpPairBeReversed(position.pair) && isPositionHlpReversed(position);
    return shouldReverse ? reversePosition(position) : position;
};
export const isPositionHlpReversed = (position) => position.pair.quoteSymbol !== "USD";
const reversePosition = (position) => ({
    ...position,
    isLong: !position.isLong,
    pair: getReversedPair(position.pair),
    averagePrice: getReversedPrice(position.averagePrice),
});
