import { BigNumber } from "ethers";
import { SubscriptionId } from "../../../../../types/general";
import { Network } from "../../../../../types/network";
import { Pair, PairStringified } from "../../../../../types/trade";
import { EncodedSignedQuote } from "../../../../h2so/fetcher";
import { MarketPrice, NumericSpread, SubscribeMarketPriceArgs } from "../../legacyInterface";
import { TradePairHlp } from "./tokens";
export type SignedPrices = [EncodedSignedQuote, ...MarketPrice[]];
/**
 * Gets a signed H2SO quote for all the input pairs and calculates the
 * price spread for each pair.
 * The prices follow the pair, returning the price of the base symbol
 * quoted against the quote symbol.
 * One of the symbols in each pair must be USD.
 * @example const [{ encoded }, aud] = await getQuotedPrices(pairFromString("AUD/USD"));
 */
export declare const getSignedPrices: (pairs: Pair[], network?: Network) => Promise<SignedPrices>;
/**
 * Gets (unsigned) H2SO prices for all the input pairs and calculates the
 * price spread for each pair, transforming prices to 30 decimals.
 * For hLP, all pairs must be quoted by USD.
 * If a price is not found, it is not included in the returned map.
 * @example const [aud] = await getUnsignedPrices(pairFromString("AUD/USD"));
 * @returns Mapping from stringified pair to the market price.
 */
export declare const getUnsignedPrices: (pairs: Pair[], network?: Network) => Promise<Record<PairStringified, MarketPrice | undefined>>;
export declare const fetchUnsignedMarketPriceForPair: (pair: Pair, network?: Network) => Promise<{
    pair: PairStringified;
    marketPrice: MarketPrice;
}>;
export declare const applySpread: (pair: TradePairHlp, oraclePrice: BigNumber) => NumericSpread;
export declare const getSpreadMultiplierBps: (spreadBps: BigNumber, maximise: boolean) => BigNumber;
export declare const subscribeToMarketPrice: ({ callback, pair, }: SubscribeMarketPriceArgs) => SubscriptionId;
export declare const unsubscribeFromMarketPrice: (id: SubscriptionId) => void;
export declare const getLatestMarketPrice: (pair: Pair) => MarketPrice;
export declare const getHlpMarketPriceFromIndex: (pair: Pair, indexPrice: BigNumber) => MarketPrice;
