import { BigNumber } from "ethers";
import { Network } from "../../../../..";
import { Pair } from "../../../../../types/trade";
import { Availability, GetCollateralTokensArgs, GetTradePairArgs, PositionInternal, Trade, TradePair, TradePairInternal, TokenInfoGlp } from "../../legacyInterface";
export type HlpToken = {
    address: string;
    isWhitelisted: boolean;
    tokenDecimals: number;
    tokenWeight: number;
    minProfitBasisPoints: number;
    maxUsdHlpAmount: BigNumber;
    isStable: boolean;
    isShortable: boolean;
    poolAmount: BigNumber;
    reservedAmount: BigNumber;
};
declare enum PriceAvailabilityStatus {
    Unknown = 0,
    Available = 1,
    Unavailable = 2
}
export type TradePairHlpInternals = {
    hlpToken: HlpToken;
    priceAvailabilityStatus: PriceAvailabilityStatus;
};
export type PositionHlpInternals = {
    entryFundingRate: BigNumber;
    cumulativeFundingRate: BigNumber;
};
export type TradePairHlp = TradePairInternal<TradePairHlpInternals>;
export type PositionHlp = PositionInternal<PositionHlpInternals>;
export declare const fetchTokens: () => Promise<HlpToken[]>;
export declare const getTokens: () => HlpToken[];
export declare const hlpTokenToUsdPair: ({ address }: HlpToken) => Pair;
export declare const fetchTradePairsHlp: () => Promise<TradePairHlp[]>;
export declare const fetchStablePairsHlp: () => Promise<TradePairHlp[]>;
/**
 * Fetches a stable pair from the hLP.
 * If there is more than one, this will return the first stable available.
 */
export declare const fetchStablePairHlp: () => Promise<TradePairHlp>;
export declare const getTradePairsHlp: () => TradePairHlp[];
export declare const getTradePairHlpFromPair: (pair: Pair) => TradePairHlp;
export declare const fetchTradePairsHlpUncached: () => Promise<TradePairHlp[]>;
export declare const getAvailableLiquidity: Trade["getAvailableLiquidity"];
export declare const getAvailabilityHlp: (pair: Pair) => Availability;
export declare const pairToTradePairHlp: (pair: Pair) => Promise<TradePairHlp>;
export declare const pairToTradePairHlpSync: (pair: Pair) => TradePairHlp;
export declare const getHlpTokenFromPair: (pair: Pair) => HlpToken;
export declare const getPlatformTokens: (includeEth?: boolean) => import("@uniswap/token-lists/dist/types").TokenInfo[];
export declare const getTokensInfo: (includeEth?: boolean) => TokenInfoGlp[];
export declare const getCollateralTokens: (_: GetCollateralTokensArgs) => import("@uniswap/token-lists/dist/types").TokenInfo[];
export declare const getTokenInfoByAddress: (address: string) => TokenInfoGlp;
export declare const getTradePair: ({ pair }: GetTradePairArgs) => TradePair;
export type LiquidityInfo = {
    poolAmount: BigNumber;
    reservedAmount: BigNumber;
};
export declare const fetchLiquidityInfo: (addresses: string[], network?: Network) => Promise<Map<string, LiquidityInfo>>;
export {};
