import { BigNumber } from "ethers";
import request, { gql } from "graphql-request";
import { HANDLE_SUBGRAPH_STAGING, HLP_PLATFORM_NAME } from "./config";
import { fetchTradePairsHlp } from "./internals";
const getActiveOrderQuery = (account) => gql `
	query {
		activeIncreasePositionOrders(where: { increasePositionOrder_: { account: "${account}" } }) {
			id
			increasePositionOrder {
				id
				account
				orderIndex
				purchaseToken
				purchaseTokenAmount
				collateralToken
				indexToken
				isLong
				sizeDelta
				triggerPrice
				shouldTriggerAboveThreshold
				executionFee
			}
		}
		activeDecreasePositionOrders(where: { decreasePositionOrder_: { account: "${account}" } }) {
			id
			decreasePositionOrder {
				id
				account
				orderIndex
				collateralToken
				collateralDelta
				indexToken
				sizeDelta
				isLong
				triggerPrice
				shouldTriggerAboveThreshold
				executionFee
			}
		}
	}
`;
const mapIncreaseOrder = (order, tradePairs) => {
    const { increasePositionOrder } = order;
    const tradePair = tradePairs.find((pair) => pair.indexAddress.toLowerCase() ===
        increasePositionOrder.indexToken.toLowerCase());
    if (!tradePair)
        throw new Error(`Trade pair not found for indexToken: ${increasePositionOrder.indexToken}`);
    return {
        orderId: createHlpOrderId(increasePositionOrder.account, +increasePositionOrder.orderIndex),
        pair: tradePair.pair,
        purchaseToken: increasePositionOrder.purchaseToken,
        purchaseTokenAmount: BigNumber.from(increasePositionOrder.purchaseTokenAmount),
        collateralAddress: increasePositionOrder.collateralToken,
        indexToken: increasePositionOrder.indexToken,
        isLong: increasePositionOrder.isLong,
        sizeDelta: BigNumber.from(increasePositionOrder.sizeDelta),
        triggerPrice: BigNumber.from(increasePositionOrder.triggerPrice),
        shouldTriggerAboveThreshold: increasePositionOrder.shouldTriggerAboveThreshold,
    };
};
const mapDecreaseOrder = (order, tradePairs) => {
    const { decreasePositionOrder } = order;
    const tradePair = tradePairs.find((pair) => pair.indexAddress.toLowerCase() ===
        decreasePositionOrder.indexToken.toLowerCase());
    if (!tradePair)
        throw new Error(`Trade pair not found for indexToken: ${decreasePositionOrder.indexToken}`);
    return {
        orderId: createHlpOrderId(decreasePositionOrder.account, +decreasePositionOrder.orderIndex),
        pair: tradePair.pair,
        collateralDelta: BigNumber.from(decreasePositionOrder.collateralDelta),
        collateralAddress: decreasePositionOrder.collateralToken,
        indexToken: decreasePositionOrder.indexToken,
        isLong: decreasePositionOrder.isLong,
        sizeDelta: BigNumber.from(decreasePositionOrder.sizeDelta),
        triggerPrice: BigNumber.from(decreasePositionOrder.triggerPrice),
        shouldTriggerAboveThreshold: decreasePositionOrder.shouldTriggerAboveThreshold,
    };
};
export const getActiveOrders = async (args) => {
    const response = await request(HANDLE_SUBGRAPH_STAGING, getActiveOrderQuery(args.account));
    const tradePairs = await fetchTradePairsHlp();
    const increase = response.activeIncreasePositionOrders.map((o) => mapIncreaseOrder(o, tradePairs));
    const decrease = response.activeDecreasePositionOrders.map((o) => mapDecreaseOrder(o, tradePairs));
    return {
        increase,
        decrease,
    };
};
const createHlpOrderId = (account, index) => {
    return `${HLP_PLATFORM_NAME}-${account.toLowerCase()}-${index}`;
};
