import { MarketPrice, TradeEffect, TradePairId } from "./interface";
import { ReaderPeriodicPositionFeeCollection, TradeReader } from "./reader";
import { ethers, BigNumber } from "ethers";
import { PairState } from "./pairState";
export type BigNumberState = {
    hex: string;
};
export type GetPeriodicFeesArgs = {
    accountId: number;
    reader: TradeReader;
    startTimestamp: number;
};
export declare class Position {
    pairId: TradePairId;
    size: BigNumber;
    entryPrice: BigNumber;
    snapshotSumFractionFunding: BigNumber;
    snapshotSumFractionBorrow: BigNumber;
    constructor(pairId: TradePairId, size: BigNumber, entryPrice: BigNumber, snapshotSumFractionFunding: BigNumber, snapshotSumFractionBorrow: BigNumber);
    /**
     * Creates an empty position.
     * @param pairId The position pair ID.
     * @param currentSumFractionFunding The current sum fraction for funding.
     * If not passed this defaults to zero which may result in the position
     * having an incorrect, non-zero accrued funding fee.
     * @param currentSumFractionBorrow Similar to the funding argument.
     */
    static Zero(pairId: TradePairId, currentSumFractionFunding?: ethers.BigNumber, currentSumFractionBorrow?: ethers.BigNumber): Position;
    get isLong(): boolean;
    get isShort(): boolean;
    get isZero(): boolean;
    calculateFullUnrealizedEquityToBeRealized(marketPrice: MarketPrice): BigNumber;
    calculateAccruedAccountFees(pairState: PairState, indexPrice: BigNumber): BigNumber;
    calculateAccruedFundingFee(pairState: PairState, indexPrice: BigNumber): BigNumber;
    calculateAccruedBorrowFee(pairState: PairState, indexPrice: BigNumber): BigNumber;
    calculateUnrealizedEquityToBeRealized(tradeSize: BigNumber, marketPrice: MarketPrice): BigNumber;
    calculateNewUnrealizedEquity(tradeSize: BigNumber, marketPrice: MarketPrice): BigNumber;
    private calculateRealizedPnl;
    applyTradeEffect(effect: TradeEffect, size: BigNumber): void;
    getPositionTradeSizeEffect(tradeSize: BigNumber): PositionTradeSizeEffect;
    private getNextEntryPrice;
    private getSizeDecreasing;
    getNotionalValue(markPrice: BigNumber): BigNumber;
    getMarkPrice(marketPrice: MarketPrice): BigNumber;
    getIncreasePrice(marketPrice: MarketPrice): BigNumber;
    getPeriodicFees(args: GetPeriodicFeesArgs): Promise<ReaderPeriodicPositionFeeCollection[]>;
    clone(): Position;
}
export type PositionTradeSizeEffect = {
    sizeChangeType: SizeChangeType;
    relevantTradeSize: BigNumber;
};
export declare enum SizeChangeType {
    Increase = 0,
    Decrease = 1,
    CloseAndFlipIncrease = 2
}
export type WeightedAverageInput = {
    amount: BigNumber;
    weight: BigNumber;
};
