import { TokenInfo } from "@uniswap/token-lists";
import { TradeLpPriceFeed } from "./liquidityPool";
import { TradeAdapter, OpenInterest } from ".";
import { TradeReader } from "./reader";
import { SubscriptionId } from "../../types/general";
import { GetTradePriceArgs, TradeLiquidityPool, MarketPrice, TradePairId, SubscribeMarketPriceArgs, TradePair } from "./index";
import { BigNumber } from "ethers";
interface ITradeProtocol {
    getLiquidityPools(): TradeLiquidityPool[];
    getLiquidityPool(id: string): TradeLiquidityPool;
    getTradePair(pairId: TradePairId): TradePair;
    getPrice(pairId: TradePairId, size?: BigNumber): MarketPrice;
    tryGetPrice(pairId: TradePairId, size?: BigNumber): MarketPrice | undefined;
    getTradePrice(lpId: string, args: GetTradePriceArgs): BigNumber;
    getTradePairs(): TradePair[];
    getOpenInterest(pairId: TradePairId): OpenInterest;
    subscribeToMarketPrice(args: SubscribeMarketPriceArgs, lpId: string): SubscriptionId;
    unsubscribeFromMarketPrice(id: SubscriptionId, lpId: string): void;
}
export declare class TradeProtocol implements ITradeProtocol {
    private readonly liquidityPools;
    constructor(liquidityPools: TradeLiquidityPool[]);
    static create(reader: TradeReader, adapter: TradeAdapter, usdToken: TokenInfo, priceFeed: TradeLpPriceFeed): Promise<TradeProtocol>;
    getLiquidityPools(): TradeLiquidityPool[];
    getLiquidityPoolsOfUnderlyingToken(tokenAddress: string): TradeLiquidityPool[];
    getLiquidityPool(id: string): TradeLiquidityPool;
    getTradePair(pairId: TradePairId): TradePair;
    getTradePairs(): TradePair[];
    subscribeToMarketPrice(args: SubscribeMarketPriceArgs, lpId: string): SubscriptionId;
    unsubscribeFromMarketPrice(id: SubscriptionId, lpId: string): void;
    getPrice(pairId: TradePairId, size?: BigNumber): MarketPrice;
    tryGetPrice(pairId: TradePairId, size?: BigNumber): MarketPrice | undefined;
    getTradePrice(lpId: string, args: GetTradePriceArgs): BigNumber;
    getOpenInterest(pairId: TradePairId): OpenInterest;
}
export {};
