import { ethers } from "ethers";
import { CollateralSymbolMap } from "../types/collaterals";
import { BridgeConfigByNetwork } from "../components/Bridge";
import { StableType } from "../types/tokens";
import { LpStakingName, AnyLpStaking } from "../types/lp/staking";
import { TokenInfo } from "@uniswap/token-lists";
import { MainNetwork, NetworkMap, ReferralsNetwork, SingleCollateralVaultNetwork, TokenTransferProxyNetwork, TradeNetwork } from "../types/network";
import { Provider } from "@ethersproject/providers";
import { AnyLp, LpName } from "../types/lp";
import { FxTokenSymbol } from "../types/fxTokens";
export type FxTokenAddressMap = Record<FxTokenSymbol, string>;
export type CollateralDetails = CollateralSymbolMap<{
    address: string;
    decimals: number;
}>;
export type KashiPoolConfig = {
    address: string;
    fxToken: string;
    collateral: TokenInfo;
};
export type SingleCollateralVaults = Record<SingleCollateralVaultNetwork, {
    [key: string]: KashiPoolConfig;
}>;
export type ConfigProtocol = Record<MainNetwork, ConfigProtocolMain> & Record<ReferralsNetwork, ConfigProtocolReferrals> & Record<TradeNetwork, ConfigProtocolTrade> & Record<TokenTransferProxyNetwork, ConfigProtocolRouterTransferProxy>;
export type ConfigProtocolMain = {
    protocol: ProtocolContractAddressMap;
    chainlinkFeeds: TokenSymbolToChainlinkUsdFeedAddress;
    collaterals: CollateralDetails;
};
export type ConfigProtocolReferrals = {
    referrals: string;
    rebate: string;
};
export type ConfigProtocolRouterTransferProxy = {
    tokenTransferProxy: string;
};
export type ConfigProtocolTrade = {
    tradeAccount: string;
    tradeBeacon: string;
    tradeTreasury: string;
    tradeLiquidityTokenFactory: string;
    tradeLiquidityPool: string;
    tradeApiWsUrl: string;
};
export type Config = {
    forexAddress: string;
    fxTokenAddresses: FxTokenAddressMap;
    fxTokenSymbols: FxTokenSymbol[];
    providers: NetworkMap<Provider>;
    protocol: ConfigProtocol;
    lp: {
        arbitrum: Record<LpName, AnyLp>;
    };
    lpStaking: {
        arbitrum: Record<LpStakingName, AnyLpStaking>;
    };
    theGraphEndpoints: {
        arbitrum: {
            fx: string;
            hpsm: string;
            trade: string;
            synths: string;
            balancer: string;
        };
        "arbitrum-sepolia": {
            referrals: string;
            synths: string;
        };
    };
    bridge: {
        apiBaseUrl: string;
        byNetwork: BridgeConfigByNetwork;
    };
    singleCollateralVaults: SingleCollateralVaults;
    singleCollateralVaultParams: {
        minimumMintingRatio: ethers.BigNumber;
        minimumCollateralRatio: ethers.BigNumber;
    };
    convert: {
        feeAddress: string;
        fees: {
            buyingForex: number;
            stableToStable: number;
            sameStableToStable: number;
            nonStable: number;
        };
        tokenSymbolToStableType: {
            [key: string]: StableType;
        };
        gasEstimates: {
            hpsm: number;
            hlp: number;
            curve: number;
            weth: number;
            hpsmToHlpToCurve: number;
            hlpToCurve: number;
            hpsmToHlp: number;
            balancer: number;
            hlpBalancer: number;
            hpsmHlpBalancer: number;
        };
    };
    coingecko: {
        tokenPriceUrl: string;
        networkAlias: NetworkMap<string>;
    };
    sdk: {
        printLogs: boolean;
        /**
         * Whether read requests should be redirected to the cache server
         * when available.
         * This is not used only for caching but also for some gas-less operations
         * such as permit.
         */
        shouldUseCacheServer: boolean;
    };
    api: {
        baseUrl: string;
    };
};
export type ProtocolContractAddressMap = {
    handle: string;
    vaultLibrary: string;
    comptroller: string;
    treasury: string;
    fxKeeperPool: string;
    governanceLock: string;
    governanceLockRetired: string;
    rewardPool: string;
    hpsm: string;
    rebates: string;
    routers: {
        routerHpsmHlp: string;
        routerHpsmHlpCurve: string;
        routerHlpBalancer: string;
        routerEthHlpBalancer: string;
        routerHpsmHlpBalancer: string;
        routerBalancerCurve: string;
    };
};
export type TokenSymbolToChainlinkUsdFeedAddress = Record<string, string>;
export declare const DATA_FEED_API_BASE_URL = "https://oracle.handle.fi";
export declare const DATA_FEED_API_WS_URL_QUOTES = "wss://oracle.handle.fi/quotes";
export declare const DATA_FEED_SIGNING_ADDRESS = "0xfff98D80aCC2CE312225e08eb9fA88F19D737577";
export declare const DATA_FEED_PRICE_DECIMALS = 8;
export declare const BALANCER_FXUSD_FOREX_POOL_ID = "0x4f14d06cb1661ce1dc2a2f26a10a7cd94393b29c000200000000000000000097";
export declare const BALANCER_VAULT_ADDRESS_ARBITRUM = "0xba12222222228d8ba445958a75a0704d566bf2c8";
export declare const CURRENT_INSTRUMENT_SCHEMA_VERSION = 1;
export declare const INSTRUMENTS_LIST_URL_BASE = "https://handle.blr1.cdn.digitaloceanspaces.com/instruments";
declare const config: Config;
export declare const setPrintLogs: (shouldPrintLogs: boolean) => void;
export declare const setShouldUseCacheServer: (shouldUseCacheServer: boolean) => void;
export declare const setApiBaseUrl: (apiBaseUrl: string) => void;
export declare const setTestnetTradeApiWsUrl: (apiWsUrl: string) => void;
export default config;
