import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface FxKeeperPoolInterface extends utils.Interface {
    functions: {
        "DECIMAL_PRECISION()": FunctionFragment;
        "SCALE_FACTOR()": FunctionFragment;
        "balanceOfRewards(address,address)": FunctionFragment;
        "balanceOfStake(address,address)": FunctionFragment;
        "getPoolCollateralBalance(address,address)": FunctionFragment;
        "getPoolTotalDeposit(address)": FunctionFragment;
        "handleAddress()": FunctionFragment;
        "initialize()": FunctionFragment;
        "liquidate(address,address)": FunctionFragment;
        "owner()": FunctionFragment;
        "protocolFee()": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "setHandleContract(address)": FunctionFragment;
        "setProtocolFee(uint256)": FunctionFragment;
        "shareOf(address,address)": FunctionFragment;
        "stake(uint256,address,address)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
        "unstake(uint256,address)": FunctionFragment;
        "upgradeTo(address)": FunctionFragment;
        "upgradeToAndCall(address,bytes)": FunctionFragment;
        "withdrawCollateralReward(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "DECIMAL_PRECISION", values?: undefined): string;
    encodeFunctionData(functionFragment: "SCALE_FACTOR", values?: undefined): string;
    encodeFunctionData(functionFragment: "balanceOfRewards", values: [string, string]): string;
    encodeFunctionData(functionFragment: "balanceOfStake", values: [string, string]): string;
    encodeFunctionData(functionFragment: "getPoolCollateralBalance", values: [string, string]): string;
    encodeFunctionData(functionFragment: "getPoolTotalDeposit", values: [string]): string;
    encodeFunctionData(functionFragment: "handleAddress", values?: undefined): string;
    encodeFunctionData(functionFragment: "initialize", values?: undefined): string;
    encodeFunctionData(functionFragment: "liquidate", values: [string, string]): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "protocolFee", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "setHandleContract", values: [string]): string;
    encodeFunctionData(functionFragment: "setProtocolFee", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "shareOf", values: [string, string]): string;
    encodeFunctionData(functionFragment: "stake", values: [BigNumberish, string, string]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "unstake", values: [BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "upgradeTo", values: [string]): string;
    encodeFunctionData(functionFragment: "upgradeToAndCall", values: [string, BytesLike]): string;
    encodeFunctionData(functionFragment: "withdrawCollateralReward", values: [string]): string;
    decodeFunctionResult(functionFragment: "DECIMAL_PRECISION", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "SCALE_FACTOR", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOfRewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOfStake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPoolCollateralBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPoolTotalDeposit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "handleAddress", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initialize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "liquidate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "protocolFee", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHandleContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setProtocolFee", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "shareOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "unstake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeTo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeToAndCall", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdrawCollateralReward", data: BytesLike): Result;
    events: {
        "AdminChanged(address,address)": EventFragment;
        "BeaconUpgraded(address)": EventFragment;
        "Liquidate(address,address,uint256)": EventFragment;
        "OwnershipTransferred(address,address)": EventFragment;
        "Stake(address,address,uint256)": EventFragment;
        "Unstake(address,address,uint256)": EventFragment;
        "Upgraded(address)": EventFragment;
        "Withdraw(address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "AdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "BeaconUpgraded"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Liquidate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Stake"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Unstake"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Upgraded"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Withdraw"): EventFragment;
}
export type AdminChangedEvent = TypedEvent<[
    string,
    string
], {
    previousAdmin: string;
    newAdmin: string;
}>;
export type AdminChangedEventFilter = TypedEventFilter<AdminChangedEvent>;
export type BeaconUpgradedEvent = TypedEvent<[string], {
    beacon: string;
}>;
export type BeaconUpgradedEventFilter = TypedEventFilter<BeaconUpgradedEvent>;
export type LiquidateEvent = TypedEvent<[
    string,
    string,
    BigNumber
], {
    account: string;
    token: string;
    tokenAmount: BigNumber;
}>;
export type LiquidateEventFilter = TypedEventFilter<LiquidateEvent>;
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export type StakeEvent = TypedEvent<[
    string,
    string,
    BigNumber
], {
    account: string;
    token: string;
    amount: BigNumber;
}>;
export type StakeEventFilter = TypedEventFilter<StakeEvent>;
export type UnstakeEvent = TypedEvent<[
    string,
    string,
    BigNumber
], {
    account: string;
    token: string;
    amount: BigNumber;
}>;
export type UnstakeEventFilter = TypedEventFilter<UnstakeEvent>;
export type UpgradedEvent = TypedEvent<[string], {
    implementation: string;
}>;
export type UpgradedEventFilter = TypedEventFilter<UpgradedEvent>;
export type WithdrawEvent = TypedEvent<[
    string,
    string
], {
    account: string;
    token: string;
}>;
export type WithdrawEventFilter = TypedEventFilter<WithdrawEvent>;
export interface FxKeeperPool extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: FxKeeperPoolInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        DECIMAL_PRECISION(overrides?: CallOverrides): Promise<[BigNumber]>;
        SCALE_FACTOR(overrides?: CallOverrides): Promise<[BigNumber]>;
        balanceOfRewards(account: string, fxToken: string, overrides?: CallOverrides): Promise<[
            string[],
            BigNumber[]
        ] & {
            collateralTypes: string[];
            collateralAmounts: BigNumber[];
        }>;
        balanceOfStake(account: string, fxToken: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            amount: BigNumber;
        }>;
        getPoolCollateralBalance(fxToken: string, collateral: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            amount: BigNumber;
        }>;
        getPoolTotalDeposit(fxToken: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            amount: BigNumber;
        }>;
        handleAddress(overrides?: CallOverrides): Promise<[string]>;
        initialize(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        liquidate(account: string, fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        protocolFee(overrides?: CallOverrides): Promise<[BigNumber]>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setHandleContract(_handle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setProtocolFee(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        shareOf(account: string, fxToken: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            share: BigNumber;
        }>;
        stake(amount: BigNumberish, fxToken: string, referral: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        unstake(amount: BigNumberish, fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        withdrawCollateralReward(fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    DECIMAL_PRECISION(overrides?: CallOverrides): Promise<BigNumber>;
    SCALE_FACTOR(overrides?: CallOverrides): Promise<BigNumber>;
    balanceOfRewards(account: string, fxToken: string, overrides?: CallOverrides): Promise<[
        string[],
        BigNumber[]
    ] & {
        collateralTypes: string[];
        collateralAmounts: BigNumber[];
    }>;
    balanceOfStake(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    getPoolCollateralBalance(fxToken: string, collateral: string, overrides?: CallOverrides): Promise<BigNumber>;
    getPoolTotalDeposit(fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    handleAddress(overrides?: CallOverrides): Promise<string>;
    initialize(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    liquidate(account: string, fxToken: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    owner(overrides?: CallOverrides): Promise<string>;
    protocolFee(overrides?: CallOverrides): Promise<BigNumber>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setHandleContract(_handle: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setProtocolFee(ratio: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    shareOf(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    stake(amount: BigNumberish, fxToken: string, referral: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    unstake(amount: BigNumberish, fxToken: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    upgradeTo(newImplementation: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    withdrawCollateralReward(fxToken: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        DECIMAL_PRECISION(overrides?: CallOverrides): Promise<BigNumber>;
        SCALE_FACTOR(overrides?: CallOverrides): Promise<BigNumber>;
        balanceOfRewards(account: string, fxToken: string, overrides?: CallOverrides): Promise<[
            string[],
            BigNumber[]
        ] & {
            collateralTypes: string[];
            collateralAmounts: BigNumber[];
        }>;
        balanceOfStake(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        getPoolCollateralBalance(fxToken: string, collateral: string, overrides?: CallOverrides): Promise<BigNumber>;
        getPoolTotalDeposit(fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        handleAddress(overrides?: CallOverrides): Promise<string>;
        initialize(overrides?: CallOverrides): Promise<void>;
        liquidate(account: string, fxToken: string, overrides?: CallOverrides): Promise<void>;
        owner(overrides?: CallOverrides): Promise<string>;
        protocolFee(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        setHandleContract(_handle: string, overrides?: CallOverrides): Promise<void>;
        setProtocolFee(ratio: BigNumberish, overrides?: CallOverrides): Promise<void>;
        shareOf(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        stake(amount: BigNumberish, fxToken: string, referral: string, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        unstake(amount: BigNumberish, fxToken: string, overrides?: CallOverrides): Promise<void>;
        upgradeTo(newImplementation: string, overrides?: CallOverrides): Promise<void>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: CallOverrides): Promise<void>;
        withdrawCollateralReward(fxToken: string, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "AdminChanged(address,address)"(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        AdminChanged(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        "BeaconUpgraded(address)"(beacon?: string | null): BeaconUpgradedEventFilter;
        BeaconUpgraded(beacon?: string | null): BeaconUpgradedEventFilter;
        "Liquidate(address,address,uint256)"(account?: string | null, token?: string | null, tokenAmount?: null): LiquidateEventFilter;
        Liquidate(account?: string | null, token?: string | null, tokenAmount?: null): LiquidateEventFilter;
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        "Stake(address,address,uint256)"(account?: string | null, token?: string | null, amount?: null): StakeEventFilter;
        Stake(account?: string | null, token?: string | null, amount?: null): StakeEventFilter;
        "Unstake(address,address,uint256)"(account?: string | null, token?: string | null, amount?: null): UnstakeEventFilter;
        Unstake(account?: string | null, token?: string | null, amount?: null): UnstakeEventFilter;
        "Upgraded(address)"(implementation?: string | null): UpgradedEventFilter;
        Upgraded(implementation?: string | null): UpgradedEventFilter;
        "Withdraw(address,address)"(account?: string | null, token?: string | null): WithdrawEventFilter;
        Withdraw(account?: string | null, token?: string | null): WithdrawEventFilter;
    };
    estimateGas: {
        DECIMAL_PRECISION(overrides?: CallOverrides): Promise<BigNumber>;
        SCALE_FACTOR(overrides?: CallOverrides): Promise<BigNumber>;
        balanceOfRewards(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        balanceOfStake(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        getPoolCollateralBalance(fxToken: string, collateral: string, overrides?: CallOverrides): Promise<BigNumber>;
        getPoolTotalDeposit(fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        handleAddress(overrides?: CallOverrides): Promise<BigNumber>;
        initialize(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        liquidate(account: string, fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        protocolFee(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setHandleContract(_handle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setProtocolFee(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        shareOf(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        stake(amount: BigNumberish, fxToken: string, referral: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        unstake(amount: BigNumberish, fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        withdrawCollateralReward(fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        DECIMAL_PRECISION(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        SCALE_FACTOR(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        balanceOfRewards(account: string, fxToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        balanceOfStake(account: string, fxToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPoolCollateralBalance(fxToken: string, collateral: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPoolTotalDeposit(fxToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        handleAddress(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        initialize(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        liquidate(account: string, fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        protocolFee(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setHandleContract(_handle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setProtocolFee(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        shareOf(account: string, fxToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        stake(amount: BigNumberish, fxToken: string, referral: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        unstake(amount: BigNumberish, fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        withdrawCollateralReward(fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
