import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface HPSMInterface extends utils.Interface {
    functions: {
        "accruedFees(address)": FunctionFragment;
        "areDepositsPaused()": FunctionFragment;
        "collateralCap(address)": FunctionFragment;
        "collectAccruedFees(address)": FunctionFragment;
        "deposit(address,address,uint256)": FunctionFragment;
        "fxTokenDeposits(address,address)": FunctionFragment;
        "handle()": FunctionFragment;
        "isFxTokenPegged(address,address)": FunctionFragment;
        "owner()": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "setCollateralCap(address,uint256)": FunctionFragment;
        "setFxTokenPeg(address,address,bool)": FunctionFragment;
        "setPausedDeposits(bool)": FunctionFragment;
        "setTransactionFee(uint256)": FunctionFragment;
        "transactionFee()": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
        "withdraw(address,address,uint256)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "accruedFees", values: [string]): string;
    encodeFunctionData(functionFragment: "areDepositsPaused", values?: undefined): string;
    encodeFunctionData(functionFragment: "collateralCap", values: [string]): string;
    encodeFunctionData(functionFragment: "collectAccruedFees", values: [string]): string;
    encodeFunctionData(functionFragment: "deposit", values: [string, string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "fxTokenDeposits", values: [string, string]): string;
    encodeFunctionData(functionFragment: "handle", values?: undefined): string;
    encodeFunctionData(functionFragment: "isFxTokenPegged", values: [string, string]): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "setCollateralCap", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setFxTokenPeg", values: [string, string, boolean]): string;
    encodeFunctionData(functionFragment: "setPausedDeposits", values: [boolean]): string;
    encodeFunctionData(functionFragment: "setTransactionFee", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "transactionFee", values?: undefined): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "withdraw", values: [string, string, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "accruedFees", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "areDepositsPaused", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "collateralCap", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "collectAccruedFees", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "deposit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "fxTokenDeposits", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "handle", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isFxTokenPegged", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setCollateralCap", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setFxTokenPeg", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPausedDeposits", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setTransactionFee", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transactionFee", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdraw", data: BytesLike): Result;
    events: {
        "Deposit(address,address,address,uint256,uint256)": EventFragment;
        "OwnershipTransferred(address,address)": EventFragment;
        "SetFxTokenPeg(address,address,bool)": EventFragment;
        "SetMaximumTokenDeposit(address,uint256)": EventFragment;
        "SetPauseDeposits(bool)": EventFragment;
        "SetTransactionFee(uint256)": EventFragment;
        "Withdraw(address,address,address,uint256,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "Deposit"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetFxTokenPeg"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetMaximumTokenDeposit"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetPauseDeposits"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetTransactionFee"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Withdraw"): EventFragment;
}
export type DepositEvent = TypedEvent<[
    string,
    string,
    string,
    BigNumber,
    BigNumber
], {
    fxToken: string;
    peggedToken: string;
    account: string;
    amountIn: BigNumber;
    amountOut: BigNumber;
}>;
export type DepositEventFilter = TypedEventFilter<DepositEvent>;
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export type SetFxTokenPegEvent = TypedEvent<[
    string,
    string,
    boolean
], {
    fxToken: string;
    peggedToken: string;
    isPegged: boolean;
}>;
export type SetFxTokenPegEventFilter = TypedEventFilter<SetFxTokenPegEvent>;
export type SetMaximumTokenDepositEvent = TypedEvent<[
    string,
    BigNumber
], {
    token: string;
    amount: BigNumber;
}>;
export type SetMaximumTokenDepositEventFilter = TypedEventFilter<SetMaximumTokenDepositEvent>;
export type SetPauseDepositsEvent = TypedEvent<[
    boolean
], {
    isPaused: boolean;
}>;
export type SetPauseDepositsEventFilter = TypedEventFilter<SetPauseDepositsEvent>;
export type SetTransactionFeeEvent = TypedEvent<[
    BigNumber
], {
    fee: BigNumber;
}>;
export type SetTransactionFeeEventFilter = TypedEventFilter<SetTransactionFeeEvent>;
export type WithdrawEvent = TypedEvent<[
    string,
    string,
    string,
    BigNumber,
    BigNumber
], {
    fxToken: string;
    peggedToken: string;
    account: string;
    amountIn: BigNumber;
    amountOut: BigNumber;
}>;
export type WithdrawEventFilter = TypedEventFilter<WithdrawEvent>;
export interface HPSM extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: HPSMInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        accruedFees(arg0: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        areDepositsPaused(overrides?: CallOverrides): Promise<[boolean]>;
        collateralCap(arg0: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        collectAccruedFees(collateralToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        deposit(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        fxTokenDeposits(arg0: string, arg1: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        handle(overrides?: CallOverrides): Promise<[string]>;
        isFxTokenPegged(arg0: string, arg1: string, overrides?: CallOverrides): Promise<[boolean]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setCollateralCap(peggedToken: string, capWithPeggedTokenDecimals: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setFxTokenPeg(fxTokenAddress: string, peggedTokenAddress: string, isPegged: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPausedDeposits(isPaused: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setTransactionFee(fee: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transactionFee(overrides?: CallOverrides): Promise<[BigNumber]>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        withdraw(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    accruedFees(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
    areDepositsPaused(overrides?: CallOverrides): Promise<boolean>;
    collateralCap(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
    collectAccruedFees(collateralToken: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    deposit(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    fxTokenDeposits(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
    handle(overrides?: CallOverrides): Promise<string>;
    isFxTokenPegged(arg0: string, arg1: string, overrides?: CallOverrides): Promise<boolean>;
    owner(overrides?: CallOverrides): Promise<string>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setCollateralCap(peggedToken: string, capWithPeggedTokenDecimals: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setFxTokenPeg(fxTokenAddress: string, peggedTokenAddress: string, isPegged: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPausedDeposits(isPaused: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setTransactionFee(fee: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transactionFee(overrides?: CallOverrides): Promise<BigNumber>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    withdraw(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        accruedFees(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        areDepositsPaused(overrides?: CallOverrides): Promise<boolean>;
        collateralCap(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        collectAccruedFees(collateralToken: string, overrides?: CallOverrides): Promise<void>;
        deposit(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        fxTokenDeposits(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
        handle(overrides?: CallOverrides): Promise<string>;
        isFxTokenPegged(arg0: string, arg1: string, overrides?: CallOverrides): Promise<boolean>;
        owner(overrides?: CallOverrides): Promise<string>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        setCollateralCap(peggedToken: string, capWithPeggedTokenDecimals: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setFxTokenPeg(fxTokenAddress: string, peggedTokenAddress: string, isPegged: boolean, overrides?: CallOverrides): Promise<void>;
        setPausedDeposits(isPaused: boolean, overrides?: CallOverrides): Promise<void>;
        setTransactionFee(fee: BigNumberish, overrides?: CallOverrides): Promise<void>;
        transactionFee(overrides?: CallOverrides): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        withdraw(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "Deposit(address,address,address,uint256,uint256)"(fxToken?: string | null, peggedToken?: string | null, account?: string | null, amountIn?: null, amountOut?: null): DepositEventFilter;
        Deposit(fxToken?: string | null, peggedToken?: string | null, account?: string | null, amountIn?: null, amountOut?: null): DepositEventFilter;
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        "SetFxTokenPeg(address,address,bool)"(fxToken?: string | null, peggedToken?: string | null, isPegged?: null): SetFxTokenPegEventFilter;
        SetFxTokenPeg(fxToken?: string | null, peggedToken?: string | null, isPegged?: null): SetFxTokenPegEventFilter;
        "SetMaximumTokenDeposit(address,uint256)"(token?: string | null, amount?: null): SetMaximumTokenDepositEventFilter;
        SetMaximumTokenDeposit(token?: string | null, amount?: null): SetMaximumTokenDepositEventFilter;
        "SetPauseDeposits(bool)"(isPaused?: null): SetPauseDepositsEventFilter;
        SetPauseDeposits(isPaused?: null): SetPauseDepositsEventFilter;
        "SetTransactionFee(uint256)"(fee?: null): SetTransactionFeeEventFilter;
        SetTransactionFee(fee?: null): SetTransactionFeeEventFilter;
        "Withdraw(address,address,address,uint256,uint256)"(fxToken?: string | null, peggedToken?: string | null, account?: string | null, amountIn?: null, amountOut?: null): WithdrawEventFilter;
        Withdraw(fxToken?: string | null, peggedToken?: string | null, account?: string | null, amountIn?: null, amountOut?: null): WithdrawEventFilter;
    };
    estimateGas: {
        accruedFees(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        areDepositsPaused(overrides?: CallOverrides): Promise<BigNumber>;
        collateralCap(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        collectAccruedFees(collateralToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        deposit(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        fxTokenDeposits(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
        handle(overrides?: CallOverrides): Promise<BigNumber>;
        isFxTokenPegged(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setCollateralCap(peggedToken: string, capWithPeggedTokenDecimals: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setFxTokenPeg(fxTokenAddress: string, peggedTokenAddress: string, isPegged: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPausedDeposits(isPaused: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setTransactionFee(fee: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transactionFee(overrides?: CallOverrides): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        withdraw(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        accruedFees(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        areDepositsPaused(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        collateralCap(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        collectAccruedFees(collateralToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        deposit(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        fxTokenDeposits(arg0: string, arg1: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        handle(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isFxTokenPegged(arg0: string, arg1: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setCollateralCap(peggedToken: string, capWithPeggedTokenDecimals: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setFxTokenPeg(fxTokenAddress: string, peggedTokenAddress: string, isPegged: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPausedDeposits(isPaused: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setTransactionFee(fee: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transactionFee(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        withdraw(fxTokenAddress: string, peggedTokenAddress: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
