import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export type CollateralDataStruct = {
    mintCR: BigNumberish;
    liquidationFee: BigNumberish;
    interestRate: BigNumberish;
};
export type CollateralDataStructOutput = [BigNumber, BigNumber, BigNumber] & {
    mintCR: BigNumber;
    liquidationFee: BigNumber;
    interestRate: BigNumber;
};
export interface HandleInterface extends utils.Interface {
    functions: {
        "ADMIN_ROLE()": FunctionFragment;
        "DEFAULT_ADMIN_ROLE()": FunctionFragment;
        "FeeRecipient()": FunctionFragment;
        "OPERATOR_ROLE()": FunctionFragment;
        "WETH()": FunctionFragment;
        "burnFeePerMille()": FunctionFragment;
        "comptroller()": FunctionFragment;
        "depositFeePerMille()": FunctionFragment;
        "forex()": FunctionFragment;
        "fxKeeperPool()": FunctionFragment;
        "getAllCollateralTypes()": FunctionFragment;
        "getBalance(address,address)": FunctionFragment;
        "getCollateralBalance(address,address,address)": FunctionFragment;
        "getCollateralDetails(address)": FunctionFragment;
        "getCollateralR0(address,address,address)": FunctionFragment;
        "getDebt(address,address)": FunctionFragment;
        "getPrincipalDebt(address,address)": FunctionFragment;
        "getRoleAdmin(bytes32)": FunctionFragment;
        "getTokenPrice(address)": FunctionFragment;
        "grantRole(bytes32,address)": FunctionFragment;
        "hasRole(bytes32,address)": FunctionFragment;
        "initialize(address)": FunctionFragment;
        "interest()": FunctionFragment;
        "isCollateralValid(address)": FunctionFragment;
        "isFxTokenValid(address)": FunctionFragment;
        "isPaused()": FunctionFragment;
        "liquidator()": FunctionFragment;
        "mintFeePerMille()": FunctionFragment;
        "oracles(address)": FunctionFragment;
        "pct()": FunctionFragment;
        "pctCollateralUpperBound()": FunctionFragment;
        "referral()": FunctionFragment;
        "removeCollateralToken(address)": FunctionFragment;
        "removeFxToken(address)": FunctionFragment;
        "renounceRole(bytes32,address)": FunctionFragment;
        "revokeRole(bytes32,address)": FunctionFragment;
        "rewards()": FunctionFragment;
        "setCollateralToken(address,uint256,uint256,uint256)": FunctionFragment;
        "setCollateralUpperBoundPCT(uint256)": FunctionFragment;
        "setComponents(address[])": FunctionFragment;
        "setFeeRecipient(address)": FunctionFragment;
        "setFees(uint256,uint256,uint256,uint256)": FunctionFragment;
        "setFxToken(address)": FunctionFragment;
        "setOracle(address,address)": FunctionFragment;
        "setPaused(bool)": FunctionFragment;
        "supportsInterface(bytes4)": FunctionFragment;
        "totalBalances(address)": FunctionFragment;
        "treasury()": FunctionFragment;
        "updateCollateralBalance(address,uint256,address,address,bool)": FunctionFragment;
        "updateDebtPosition(address,uint256,address,bool)": FunctionFragment;
        "upgradeTo(address)": FunctionFragment;
        "upgradeToAndCall(address,bytes)": FunctionFragment;
        "vaultLibrary()": FunctionFragment;
        "vaults(address,address)": FunctionFragment;
        "withdrawFeePerMille()": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "ADMIN_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "DEFAULT_ADMIN_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "FeeRecipient", values?: undefined): string;
    encodeFunctionData(functionFragment: "OPERATOR_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "WETH", values?: undefined): string;
    encodeFunctionData(functionFragment: "burnFeePerMille", values?: undefined): string;
    encodeFunctionData(functionFragment: "comptroller", values?: undefined): string;
    encodeFunctionData(functionFragment: "depositFeePerMille", values?: undefined): string;
    encodeFunctionData(functionFragment: "forex", values?: undefined): string;
    encodeFunctionData(functionFragment: "fxKeeperPool", values?: undefined): string;
    encodeFunctionData(functionFragment: "getAllCollateralTypes", values?: undefined): string;
    encodeFunctionData(functionFragment: "getBalance", values: [string, string]): string;
    encodeFunctionData(functionFragment: "getCollateralBalance", values: [string, string, string]): string;
    encodeFunctionData(functionFragment: "getCollateralDetails", values: [string]): string;
    encodeFunctionData(functionFragment: "getCollateralR0", values: [string, string, string]): string;
    encodeFunctionData(functionFragment: "getDebt", values: [string, string]): string;
    encodeFunctionData(functionFragment: "getPrincipalDebt", values: [string, string]): string;
    encodeFunctionData(functionFragment: "getRoleAdmin", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getTokenPrice", values: [string]): string;
    encodeFunctionData(functionFragment: "grantRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "hasRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "initialize", values: [string]): string;
    encodeFunctionData(functionFragment: "interest", values?: undefined): string;
    encodeFunctionData(functionFragment: "isCollateralValid", values: [string]): string;
    encodeFunctionData(functionFragment: "isFxTokenValid", values: [string]): string;
    encodeFunctionData(functionFragment: "isPaused", values?: undefined): string;
    encodeFunctionData(functionFragment: "liquidator", values?: undefined): string;
    encodeFunctionData(functionFragment: "mintFeePerMille", values?: undefined): string;
    encodeFunctionData(functionFragment: "oracles", values: [string]): string;
    encodeFunctionData(functionFragment: "pct", values?: undefined): string;
    encodeFunctionData(functionFragment: "pctCollateralUpperBound", values?: undefined): string;
    encodeFunctionData(functionFragment: "referral", values?: undefined): string;
    encodeFunctionData(functionFragment: "removeCollateralToken", values: [string]): string;
    encodeFunctionData(functionFragment: "removeFxToken", values: [string]): string;
    encodeFunctionData(functionFragment: "renounceRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "revokeRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "rewards", values?: undefined): string;
    encodeFunctionData(functionFragment: "setCollateralToken", values: [string, BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setCollateralUpperBoundPCT", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setComponents", values: [string[]]): string;
    encodeFunctionData(functionFragment: "setFeeRecipient", values: [string]): string;
    encodeFunctionData(functionFragment: "setFees", values: [BigNumberish, BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setFxToken", values: [string]): string;
    encodeFunctionData(functionFragment: "setOracle", values: [string, string]): string;
    encodeFunctionData(functionFragment: "setPaused", values: [boolean]): string;
    encodeFunctionData(functionFragment: "supportsInterface", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "totalBalances", values: [string]): string;
    encodeFunctionData(functionFragment: "treasury", values?: undefined): string;
    encodeFunctionData(functionFragment: "updateCollateralBalance", values: [string, BigNumberish, string, string, boolean]): string;
    encodeFunctionData(functionFragment: "updateDebtPosition", values: [string, BigNumberish, string, boolean]): string;
    encodeFunctionData(functionFragment: "upgradeTo", values: [string]): string;
    encodeFunctionData(functionFragment: "upgradeToAndCall", values: [string, BytesLike]): string;
    encodeFunctionData(functionFragment: "vaultLibrary", values?: undefined): string;
    encodeFunctionData(functionFragment: "vaults", values: [string, string]): string;
    encodeFunctionData(functionFragment: "withdrawFeePerMille", values?: undefined): string;
    decodeFunctionResult(functionFragment: "ADMIN_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "DEFAULT_ADMIN_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "FeeRecipient", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "OPERATOR_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "WETH", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "burnFeePerMille", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "comptroller", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "depositFeePerMille", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "forex", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "fxKeeperPool", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAllCollateralTypes", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getCollateralBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getCollateralDetails", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getCollateralR0", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getDebt", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPrincipalDebt", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleAdmin", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getTokenPrice", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "grantRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hasRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initialize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "interest", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isCollateralValid", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isFxTokenValid", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "isPaused", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "liquidator", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "mintFeePerMille", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "oracles", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pct", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pctCollateralUpperBound", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "referral", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeCollateralToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeFxToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "revokeRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rewards", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setCollateralToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setCollateralUpperBoundPCT", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setComponents", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setFeeRecipient", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setFees", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setFxToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setOracle", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPaused", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supportsInterface", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "totalBalances", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "treasury", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateCollateralBalance", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateDebtPosition", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeTo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeToAndCall", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "vaultLibrary", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "vaults", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdrawFeePerMille", data: BytesLike): Result;
    events: {
        "AdminChanged(address,address)": EventFragment;
        "BeaconUpgraded(address)": EventFragment;
        "ConfigureCollateralToken(address)": EventFragment;
        "ConfigureFxToken(address,bool)": EventFragment;
        "RoleAdminChanged(bytes32,bytes32,bytes32)": EventFragment;
        "RoleGranted(bytes32,address,address)": EventFragment;
        "RoleRevoked(bytes32,address,address)": EventFragment;
        "UpdateCollateral(address,address,address)": EventFragment;
        "UpdateDebt(address,address)": EventFragment;
        "Upgraded(address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "AdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "BeaconUpgraded"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ConfigureCollateralToken"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ConfigureFxToken"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleAdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleGranted"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleRevoked"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UpdateCollateral"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UpdateDebt"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Upgraded"): EventFragment;
}
export type AdminChangedEvent = TypedEvent<[
    string,
    string
], {
    previousAdmin: string;
    newAdmin: string;
}>;
export type AdminChangedEventFilter = TypedEventFilter<AdminChangedEvent>;
export type BeaconUpgradedEvent = TypedEvent<[string], {
    beacon: string;
}>;
export type BeaconUpgradedEventFilter = TypedEventFilter<BeaconUpgradedEvent>;
export type ConfigureCollateralTokenEvent = TypedEvent<[
    string
], {
    collateralToken: string;
}>;
export type ConfigureCollateralTokenEventFilter = TypedEventFilter<ConfigureCollateralTokenEvent>;
export type ConfigureFxTokenEvent = TypedEvent<[
    string,
    boolean
], {
    fxToken: string;
    removed: boolean;
}>;
export type ConfigureFxTokenEventFilter = TypedEventFilter<ConfigureFxTokenEvent>;
export type RoleAdminChangedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    previousAdminRole: string;
    newAdminRole: string;
}>;
export type RoleAdminChangedEventFilter = TypedEventFilter<RoleAdminChangedEvent>;
export type RoleGrantedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
export type RoleGrantedEventFilter = TypedEventFilter<RoleGrantedEvent>;
export type RoleRevokedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
export type RoleRevokedEventFilter = TypedEventFilter<RoleRevokedEvent>;
export type UpdateCollateralEvent = TypedEvent<[
    string,
    string,
    string
], {
    account: string;
    fxToken: string;
    collateralToken: string;
}>;
export type UpdateCollateralEventFilter = TypedEventFilter<UpdateCollateralEvent>;
export type UpdateDebtEvent = TypedEvent<[
    string,
    string
], {
    account: string;
    fxToken: string;
}>;
export type UpdateDebtEventFilter = TypedEventFilter<UpdateDebtEvent>;
export type UpgradedEvent = TypedEvent<[string], {
    implementation: string;
}>;
export type UpgradedEventFilter = TypedEventFilter<UpgradedEvent>;
export interface Handle extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: HandleInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        ADMIN_ROLE(overrides?: CallOverrides): Promise<[string]>;
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<[string]>;
        FeeRecipient(overrides?: CallOverrides): Promise<[string]>;
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<[string]>;
        WETH(overrides?: CallOverrides): Promise<[string]>;
        burnFeePerMille(overrides?: CallOverrides): Promise<[BigNumber]>;
        comptroller(overrides?: CallOverrides): Promise<[string]>;
        depositFeePerMille(overrides?: CallOverrides): Promise<[BigNumber]>;
        forex(overrides?: CallOverrides): Promise<[string]>;
        fxKeeperPool(overrides?: CallOverrides): Promise<[string]>;
        getAllCollateralTypes(overrides?: CallOverrides): Promise<[string[]] & {
            collateral: string[];
        }>;
        getBalance(account: string, fxToken: string, overrides?: CallOverrides): Promise<[
            string[],
            BigNumber[]
        ] & {
            collateral: string[];
            balances: BigNumber[];
        }>;
        getCollateralBalance(account: string, collateralType: string, fxToken: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            balance: BigNumber;
        }>;
        getCollateralDetails(collateral: string, overrides?: CallOverrides): Promise<[CollateralDataStructOutput]>;
        getCollateralR0(account: string, fxToken: string, collateral: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            R0: BigNumber;
        }>;
        getDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        getPrincipalDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<[string]>;
        getTokenPrice(token: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            quote: BigNumber;
        }>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<[boolean]>;
        initialize(weth: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        interest(overrides?: CallOverrides): Promise<[string]>;
        isCollateralValid(arg0: string, overrides?: CallOverrides): Promise<[boolean]>;
        isFxTokenValid(arg0: string, overrides?: CallOverrides): Promise<[boolean]>;
        isPaused(overrides?: CallOverrides): Promise<[boolean]>;
        liquidator(overrides?: CallOverrides): Promise<[string]>;
        mintFeePerMille(overrides?: CallOverrides): Promise<[BigNumber]>;
        oracles(arg0: string, overrides?: CallOverrides): Promise<[string]>;
        pct(overrides?: CallOverrides): Promise<[string]>;
        pctCollateralUpperBound(overrides?: CallOverrides): Promise<[BigNumber]>;
        referral(overrides?: CallOverrides): Promise<[string]>;
        removeCollateralToken(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        removeFxToken(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        rewards(overrides?: CallOverrides): Promise<[string]>;
        setCollateralToken(token: string, mintCR: BigNumberish, liquidationFee: BigNumberish, interestRatePerMille: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setCollateralUpperBoundPCT(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setComponents(components: string[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setFeeRecipient(feeRecipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setFees(_withdrawFeePerMille: BigNumberish, _depositFeePerMille: BigNumberish, _mintFeePerMille: BigNumberish, _burnFeePerMille: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setFxToken(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setOracle(token: string, oracle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPaused(value: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<[boolean]>;
        totalBalances(arg0: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        treasury(overrides?: CallOverrides): Promise<[string]>;
        updateCollateralBalance(account: string, amount: BigNumberish, fxToken: string, collateralToken: string, increase: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        updateDebtPosition(account: string, amount: BigNumberish, fxToken: string, increase: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        vaultLibrary(overrides?: CallOverrides): Promise<[string]>;
        vaults(arg0: string, arg1: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            debt: BigNumber;
        }>;
        withdrawFeePerMille(overrides?: CallOverrides): Promise<[BigNumber]>;
    };
    ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
    DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
    FeeRecipient(overrides?: CallOverrides): Promise<string>;
    OPERATOR_ROLE(overrides?: CallOverrides): Promise<string>;
    WETH(overrides?: CallOverrides): Promise<string>;
    burnFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
    comptroller(overrides?: CallOverrides): Promise<string>;
    depositFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
    forex(overrides?: CallOverrides): Promise<string>;
    fxKeeperPool(overrides?: CallOverrides): Promise<string>;
    getAllCollateralTypes(overrides?: CallOverrides): Promise<string[]>;
    getBalance(account: string, fxToken: string, overrides?: CallOverrides): Promise<[
        string[],
        BigNumber[]
    ] & {
        collateral: string[];
        balances: BigNumber[];
    }>;
    getCollateralBalance(account: string, collateralType: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    getCollateralDetails(collateral: string, overrides?: CallOverrides): Promise<CollateralDataStructOutput>;
    getCollateralR0(account: string, fxToken: string, collateral: string, overrides?: CallOverrides): Promise<BigNumber>;
    getDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    getPrincipalDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
    getTokenPrice(token: string, overrides?: CallOverrides): Promise<BigNumber>;
    grantRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
    initialize(weth: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    interest(overrides?: CallOverrides): Promise<string>;
    isCollateralValid(arg0: string, overrides?: CallOverrides): Promise<boolean>;
    isFxTokenValid(arg0: string, overrides?: CallOverrides): Promise<boolean>;
    isPaused(overrides?: CallOverrides): Promise<boolean>;
    liquidator(overrides?: CallOverrides): Promise<string>;
    mintFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
    oracles(arg0: string, overrides?: CallOverrides): Promise<string>;
    pct(overrides?: CallOverrides): Promise<string>;
    pctCollateralUpperBound(overrides?: CallOverrides): Promise<BigNumber>;
    referral(overrides?: CallOverrides): Promise<string>;
    removeCollateralToken(token: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    removeFxToken(token: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    rewards(overrides?: CallOverrides): Promise<string>;
    setCollateralToken(token: string, mintCR: BigNumberish, liquidationFee: BigNumberish, interestRatePerMille: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setCollateralUpperBoundPCT(ratio: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setComponents(components: string[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setFeeRecipient(feeRecipient: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setFees(_withdrawFeePerMille: BigNumberish, _depositFeePerMille: BigNumberish, _mintFeePerMille: BigNumberish, _burnFeePerMille: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setFxToken(token: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setOracle(token: string, oracle: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPaused(value: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
    totalBalances(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
    treasury(overrides?: CallOverrides): Promise<string>;
    updateCollateralBalance(account: string, amount: BigNumberish, fxToken: string, collateralToken: string, increase: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    updateDebtPosition(account: string, amount: BigNumberish, fxToken: string, increase: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    upgradeTo(newImplementation: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    vaultLibrary(overrides?: CallOverrides): Promise<string>;
    vaults(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
    withdrawFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
    callStatic: {
        ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
        FeeRecipient(overrides?: CallOverrides): Promise<string>;
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<string>;
        WETH(overrides?: CallOverrides): Promise<string>;
        burnFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
        comptroller(overrides?: CallOverrides): Promise<string>;
        depositFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
        forex(overrides?: CallOverrides): Promise<string>;
        fxKeeperPool(overrides?: CallOverrides): Promise<string>;
        getAllCollateralTypes(overrides?: CallOverrides): Promise<string[]>;
        getBalance(account: string, fxToken: string, overrides?: CallOverrides): Promise<[
            string[],
            BigNumber[]
        ] & {
            collateral: string[];
            balances: BigNumber[];
        }>;
        getCollateralBalance(account: string, collateralType: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        getCollateralDetails(collateral: string, overrides?: CallOverrides): Promise<CollateralDataStructOutput>;
        getCollateralR0(account: string, fxToken: string, collateral: string, overrides?: CallOverrides): Promise<BigNumber>;
        getDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        getPrincipalDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
        getTokenPrice(token: string, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
        initialize(weth: string, overrides?: CallOverrides): Promise<void>;
        interest(overrides?: CallOverrides): Promise<string>;
        isCollateralValid(arg0: string, overrides?: CallOverrides): Promise<boolean>;
        isFxTokenValid(arg0: string, overrides?: CallOverrides): Promise<boolean>;
        isPaused(overrides?: CallOverrides): Promise<boolean>;
        liquidator(overrides?: CallOverrides): Promise<string>;
        mintFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
        oracles(arg0: string, overrides?: CallOverrides): Promise<string>;
        pct(overrides?: CallOverrides): Promise<string>;
        pctCollateralUpperBound(overrides?: CallOverrides): Promise<BigNumber>;
        referral(overrides?: CallOverrides): Promise<string>;
        removeCollateralToken(token: string, overrides?: CallOverrides): Promise<void>;
        removeFxToken(token: string, overrides?: CallOverrides): Promise<void>;
        renounceRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        revokeRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        rewards(overrides?: CallOverrides): Promise<string>;
        setCollateralToken(token: string, mintCR: BigNumberish, liquidationFee: BigNumberish, interestRatePerMille: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setCollateralUpperBoundPCT(ratio: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setComponents(components: string[], overrides?: CallOverrides): Promise<void>;
        setFeeRecipient(feeRecipient: string, overrides?: CallOverrides): Promise<void>;
        setFees(_withdrawFeePerMille: BigNumberish, _depositFeePerMille: BigNumberish, _mintFeePerMille: BigNumberish, _burnFeePerMille: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setFxToken(token: string, overrides?: CallOverrides): Promise<void>;
        setOracle(token: string, oracle: string, overrides?: CallOverrides): Promise<void>;
        setPaused(value: boolean, overrides?: CallOverrides): Promise<void>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
        totalBalances(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        treasury(overrides?: CallOverrides): Promise<string>;
        updateCollateralBalance(account: string, amount: BigNumberish, fxToken: string, collateralToken: string, increase: boolean, overrides?: CallOverrides): Promise<void>;
        updateDebtPosition(account: string, amount: BigNumberish, fxToken: string, increase: boolean, overrides?: CallOverrides): Promise<void>;
        upgradeTo(newImplementation: string, overrides?: CallOverrides): Promise<void>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: CallOverrides): Promise<void>;
        vaultLibrary(overrides?: CallOverrides): Promise<string>;
        vaults(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
        withdrawFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {
        "AdminChanged(address,address)"(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        AdminChanged(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        "BeaconUpgraded(address)"(beacon?: string | null): BeaconUpgradedEventFilter;
        BeaconUpgraded(beacon?: string | null): BeaconUpgradedEventFilter;
        "ConfigureCollateralToken(address)"(collateralToken?: string | null): ConfigureCollateralTokenEventFilter;
        ConfigureCollateralToken(collateralToken?: string | null): ConfigureCollateralTokenEventFilter;
        "ConfigureFxToken(address,bool)"(fxToken?: string | null, removed?: null): ConfigureFxTokenEventFilter;
        ConfigureFxToken(fxToken?: string | null, removed?: null): ConfigureFxTokenEventFilter;
        "RoleAdminChanged(bytes32,bytes32,bytes32)"(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        RoleAdminChanged(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        "RoleGranted(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        RoleGranted(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        "RoleRevoked(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        RoleRevoked(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        "UpdateCollateral(address,address,address)"(account?: string | null, fxToken?: string | null, collateralToken?: string | null): UpdateCollateralEventFilter;
        UpdateCollateral(account?: string | null, fxToken?: string | null, collateralToken?: string | null): UpdateCollateralEventFilter;
        "UpdateDebt(address,address)"(account?: string | null, fxToken?: string | null): UpdateDebtEventFilter;
        UpdateDebt(account?: string | null, fxToken?: string | null): UpdateDebtEventFilter;
        "Upgraded(address)"(implementation?: string | null): UpgradedEventFilter;
        Upgraded(implementation?: string | null): UpgradedEventFilter;
    };
    estimateGas: {
        ADMIN_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        FeeRecipient(overrides?: CallOverrides): Promise<BigNumber>;
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        WETH(overrides?: CallOverrides): Promise<BigNumber>;
        burnFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
        comptroller(overrides?: CallOverrides): Promise<BigNumber>;
        depositFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
        forex(overrides?: CallOverrides): Promise<BigNumber>;
        fxKeeperPool(overrides?: CallOverrides): Promise<BigNumber>;
        getAllCollateralTypes(overrides?: CallOverrides): Promise<BigNumber>;
        getBalance(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        getCollateralBalance(account: string, collateralType: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        getCollateralDetails(collateral: string, overrides?: CallOverrides): Promise<BigNumber>;
        getCollateralR0(account: string, fxToken: string, collateral: string, overrides?: CallOverrides): Promise<BigNumber>;
        getDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        getPrincipalDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        getTokenPrice(token: string, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<BigNumber>;
        initialize(weth: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        interest(overrides?: CallOverrides): Promise<BigNumber>;
        isCollateralValid(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        isFxTokenValid(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        isPaused(overrides?: CallOverrides): Promise<BigNumber>;
        liquidator(overrides?: CallOverrides): Promise<BigNumber>;
        mintFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
        oracles(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        pct(overrides?: CallOverrides): Promise<BigNumber>;
        pctCollateralUpperBound(overrides?: CallOverrides): Promise<BigNumber>;
        referral(overrides?: CallOverrides): Promise<BigNumber>;
        removeCollateralToken(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        removeFxToken(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        rewards(overrides?: CallOverrides): Promise<BigNumber>;
        setCollateralToken(token: string, mintCR: BigNumberish, liquidationFee: BigNumberish, interestRatePerMille: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setCollateralUpperBoundPCT(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setComponents(components: string[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setFeeRecipient(feeRecipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setFees(_withdrawFeePerMille: BigNumberish, _depositFeePerMille: BigNumberish, _mintFeePerMille: BigNumberish, _burnFeePerMille: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setFxToken(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setOracle(token: string, oracle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPaused(value: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        totalBalances(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        treasury(overrides?: CallOverrides): Promise<BigNumber>;
        updateCollateralBalance(account: string, amount: BigNumberish, fxToken: string, collateralToken: string, increase: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        updateDebtPosition(account: string, amount: BigNumberish, fxToken: string, increase: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        vaultLibrary(overrides?: CallOverrides): Promise<BigNumber>;
        vaults(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
        withdrawFeePerMille(overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        ADMIN_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        FeeRecipient(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        WETH(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        burnFeePerMille(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        comptroller(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        depositFeePerMille(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        forex(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        fxKeeperPool(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getAllCollateralTypes(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getBalance(account: string, fxToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getCollateralBalance(account: string, collateralType: string, fxToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getCollateralDetails(collateral: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getCollateralR0(account: string, fxToken: string, collateral: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPrincipalDebt(account: string, fxToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getTokenPrice(token: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        initialize(weth: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        interest(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isCollateralValid(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isFxTokenValid(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        isPaused(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        liquidator(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        mintFeePerMille(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        oracles(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        pct(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        pctCollateralUpperBound(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        referral(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        removeCollateralToken(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        removeFxToken(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        rewards(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setCollateralToken(token: string, mintCR: BigNumberish, liquidationFee: BigNumberish, interestRatePerMille: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setCollateralUpperBoundPCT(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setComponents(components: string[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setFeeRecipient(feeRecipient: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setFees(_withdrawFeePerMille: BigNumberish, _depositFeePerMille: BigNumberish, _mintFeePerMille: BigNumberish, _burnFeePerMille: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setFxToken(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setOracle(token: string, oracle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPaused(value: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        totalBalances(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        treasury(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        updateCollateralBalance(account: string, amount: BigNumberish, fxToken: string, collateralToken: string, increase: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        updateDebtPosition(account: string, amount: BigNumberish, fxToken: string, increase: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        vaultLibrary(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        vaults(arg0: string, arg1: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        withdrawFeePerMille(overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
