import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface HlpRewardRouterInterface extends utils.Interface {
    functions: {
        "addStakedLiquidity(address,uint256,uint256,uint256,address,bytes)": FunctionFragment;
        "addStakedLiquidityEth(uint256,uint256,address,bytes)": FunctionFragment;
        "hlp()": FunctionFragment;
        "hlpManager()": FunctionFragment;
        "owner()": FunctionFragment;
        "referral()": FunctionFragment;
        "removeStakedLiquidity(address,uint256,uint256,address,bytes)": FunctionFragment;
        "removeStakedLiquidityEth(uint256,uint256,address,bytes)": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "rewardPool()": FunctionFragment;
        "rewardPoolAlias()": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
        "weth()": FunctionFragment;
        "withdrawToken(address,address,uint256)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "addStakedLiquidity", values: [
        string,
        BigNumberish,
        BigNumberish,
        BigNumberish,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "addStakedLiquidityEth", values: [BigNumberish, BigNumberish, string, BytesLike]): string;
    encodeFunctionData(functionFragment: "hlp", values?: undefined): string;
    encodeFunctionData(functionFragment: "hlpManager", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "referral", values?: undefined): string;
    encodeFunctionData(functionFragment: "removeStakedLiquidity", values: [string, BigNumberish, BigNumberish, string, BytesLike]): string;
    encodeFunctionData(functionFragment: "removeStakedLiquidityEth", values: [BigNumberish, BigNumberish, string, BytesLike]): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "rewardPool", values?: undefined): string;
    encodeFunctionData(functionFragment: "rewardPoolAlias", values?: undefined): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "weth", values?: undefined): string;
    encodeFunctionData(functionFragment: "withdrawToken", values: [string, string, BigNumberish]): string;
    decodeFunctionResult(functionFragment: "addStakedLiquidity", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "addStakedLiquidityEth", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hlp", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hlpManager", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "referral", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeStakedLiquidity", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "removeStakedLiquidityEth", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rewardPool", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rewardPoolAlias", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "weth", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "withdrawToken", data: BytesLike): Result;
    events: {
        "OwnershipTransferred(address,address)": EventFragment;
        "StakeHlp(address,uint256)": EventFragment;
        "UnstakeHlp(address,uint256)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "StakeHlp"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "UnstakeHlp"): EventFragment;
}
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export type StakeHlpEvent = TypedEvent<[
    string,
    BigNumber
], {
    account: string;
    amount: BigNumber;
}>;
export type StakeHlpEventFilter = TypedEventFilter<StakeHlpEvent>;
export type UnstakeHlpEvent = TypedEvent<[
    string,
    BigNumber
], {
    account: string;
    amount: BigNumber;
}>;
export type UnstakeHlpEventFilter = TypedEventFilter<UnstakeHlpEvent>;
export interface HlpRewardRouter extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: HlpRewardRouterInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        addStakedLiquidity(token: string, amount: BigNumberish, minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        addStakedLiquidityEth(minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        hlp(overrides?: CallOverrides): Promise<[string]>;
        hlpManager(overrides?: CallOverrides): Promise<[string]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        referral(overrides?: CallOverrides): Promise<[string]>;
        removeStakedLiquidity(tokenOut: string, hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        removeStakedLiquidityEth(hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        rewardPool(overrides?: CallOverrides): Promise<[string]>;
        rewardPoolAlias(overrides?: CallOverrides): Promise<[string]>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        weth(overrides?: CallOverrides): Promise<[string]>;
        withdrawToken(token: string, account: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    addStakedLiquidity(token: string, amount: BigNumberish, minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    addStakedLiquidityEth(minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    hlp(overrides?: CallOverrides): Promise<string>;
    hlpManager(overrides?: CallOverrides): Promise<string>;
    owner(overrides?: CallOverrides): Promise<string>;
    referral(overrides?: CallOverrides): Promise<string>;
    removeStakedLiquidity(tokenOut: string, hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    removeStakedLiquidityEth(hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    rewardPool(overrides?: CallOverrides): Promise<string>;
    rewardPoolAlias(overrides?: CallOverrides): Promise<string>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    weth(overrides?: CallOverrides): Promise<string>;
    withdrawToken(token: string, account: string, amount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        addStakedLiquidity(token: string, amount: BigNumberish, minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        addStakedLiquidityEth(minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        hlp(overrides?: CallOverrides): Promise<string>;
        hlpManager(overrides?: CallOverrides): Promise<string>;
        owner(overrides?: CallOverrides): Promise<string>;
        referral(overrides?: CallOverrides): Promise<string>;
        removeStakedLiquidity(tokenOut: string, hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        removeStakedLiquidityEth(hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        rewardPool(overrides?: CallOverrides): Promise<string>;
        rewardPoolAlias(overrides?: CallOverrides): Promise<string>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        weth(overrides?: CallOverrides): Promise<string>;
        withdrawToken(token: string, account: string, amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        "StakeHlp(address,uint256)"(account?: string | null, amount?: null): StakeHlpEventFilter;
        StakeHlp(account?: string | null, amount?: null): StakeHlpEventFilter;
        "UnstakeHlp(address,uint256)"(account?: string | null, amount?: null): UnstakeHlpEventFilter;
        UnstakeHlp(account?: string | null, amount?: null): UnstakeHlpEventFilter;
    };
    estimateGas: {
        addStakedLiquidity(token: string, amount: BigNumberish, minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        addStakedLiquidityEth(minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        hlp(overrides?: CallOverrides): Promise<BigNumber>;
        hlpManager(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        referral(overrides?: CallOverrides): Promise<BigNumber>;
        removeStakedLiquidity(tokenOut: string, hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        removeStakedLiquidityEth(hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        rewardPool(overrides?: CallOverrides): Promise<BigNumber>;
        rewardPoolAlias(overrides?: CallOverrides): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        weth(overrides?: CallOverrides): Promise<BigNumber>;
        withdrawToken(token: string, account: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        addStakedLiquidity(token: string, amount: BigNumberish, minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        addStakedLiquidityEth(minUsdhlp: BigNumberish, minHlp: BigNumberish, referral: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        hlp(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        hlpManager(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        referral(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        removeStakedLiquidity(tokenOut: string, hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        removeStakedLiquidityEth(hlpAmount: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        rewardPool(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        rewardPoolAlias(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        weth(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        withdrawToken(token: string, account: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
