import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface LiquidatorInterface extends utils.Interface {
    functions: {
        "buyCollateral(uint256,address,address,uint256,address)": FunctionFragment;
        "buyCollateralFromManyVaults(uint256,address,address[],uint256,address)": FunctionFragment;
        "crScalar()": FunctionFragment;
        "getAllowedBuyCollateralFromTokenAmount(address,address)": FunctionFragment;
        "getLiquidationRatio(address,address)": FunctionFragment;
        "handleAddress()": FunctionFragment;
        "initialize()": FunctionFragment;
        "keeperPoolThreshold()": FunctionFragment;
        "liquidate(address,address)": FunctionFragment;
        "owner()": FunctionFragment;
        "protocolRedemptionFeeRatio()": FunctionFragment;
        "redemptionFeeRatio()": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "setCrScalar(uint256)": FunctionFragment;
        "setHandleContract(address)": FunctionFragment;
        "setKeeperPoolThreshold(uint256)": FunctionFragment;
        "setProtocolRedemptionFeeRatio(uint256)": FunctionFragment;
        "setRedemptionFeeRatio(uint256)": FunctionFragment;
        "tokensRequiredForCrIncrease(uint256,uint256,uint256,uint256)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
        "upgradeTo(address)": FunctionFragment;
        "upgradeToAndCall(address,bytes)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "buyCollateral", values: [BigNumberish, string, string, BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "buyCollateralFromManyVaults", values: [BigNumberish, string, string[], BigNumberish, string]): string;
    encodeFunctionData(functionFragment: "crScalar", values?: undefined): string;
    encodeFunctionData(functionFragment: "getAllowedBuyCollateralFromTokenAmount", values: [string, string]): string;
    encodeFunctionData(functionFragment: "getLiquidationRatio", values: [string, string]): string;
    encodeFunctionData(functionFragment: "handleAddress", values?: undefined): string;
    encodeFunctionData(functionFragment: "initialize", values?: undefined): string;
    encodeFunctionData(functionFragment: "keeperPoolThreshold", values?: undefined): string;
    encodeFunctionData(functionFragment: "liquidate", values: [string, string]): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "protocolRedemptionFeeRatio", values?: undefined): string;
    encodeFunctionData(functionFragment: "redemptionFeeRatio", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "setCrScalar", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setHandleContract", values: [string]): string;
    encodeFunctionData(functionFragment: "setKeeperPoolThreshold", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setProtocolRedemptionFeeRatio", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setRedemptionFeeRatio", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "tokensRequiredForCrIncrease", values: [BigNumberish, BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "upgradeTo", values: [string]): string;
    encodeFunctionData(functionFragment: "upgradeToAndCall", values: [string, BytesLike]): string;
    decodeFunctionResult(functionFragment: "buyCollateral", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "buyCollateralFromManyVaults", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "crScalar", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getAllowedBuyCollateralFromTokenAmount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getLiquidationRatio", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "handleAddress", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initialize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "keeperPoolThreshold", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "liquidate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "protocolRedemptionFeeRatio", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "redemptionFeeRatio", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setCrScalar", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHandleContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setKeeperPoolThreshold", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setProtocolRedemptionFeeRatio", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRedemptionFeeRatio", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "tokensRequiredForCrIncrease", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeTo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeToAndCall", data: BytesLike): Result;
    events: {
        "AdminChanged(address,address)": EventFragment;
        "BeaconUpgraded(address)": EventFragment;
        "Liquidate(address,address,uint256,uint256[],address[])": EventFragment;
        "OwnershipTransferred(address,address)": EventFragment;
        "Redeem(address,address,uint256,uint256[],address[])": EventFragment;
        "Upgraded(address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "AdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "BeaconUpgraded"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Liquidate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Redeem"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Upgraded"): EventFragment;
}
export type AdminChangedEvent = TypedEvent<[
    string,
    string
], {
    previousAdmin: string;
    newAdmin: string;
}>;
export type AdminChangedEventFilter = TypedEventFilter<AdminChangedEvent>;
export type BeaconUpgradedEvent = TypedEvent<[string], {
    beacon: string;
}>;
export type BeaconUpgradedEventFilter = TypedEventFilter<BeaconUpgradedEvent>;
export type LiquidateEvent = TypedEvent<[
    string,
    string,
    BigNumber,
    BigNumber[],
    string[]
], {
    from: string;
    token: string;
    tokenAmount: BigNumber;
    collateralAmounts: BigNumber[];
    collateralTypes: string[];
}>;
export type LiquidateEventFilter = TypedEventFilter<LiquidateEvent>;
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export type RedeemEvent = TypedEvent<[
    string,
    string,
    BigNumber,
    BigNumber[],
    string[]
], {
    from: string;
    token: string;
    tokenAmount: BigNumber;
    collateralAmounts: BigNumber[];
    collateralTypes: string[];
}>;
export type RedeemEventFilter = TypedEventFilter<RedeemEvent>;
export type UpgradedEvent = TypedEvent<[string], {
    implementation: string;
}>;
export type UpgradedEventFilter = TypedEventFilter<UpgradedEvent>;
export interface Liquidator extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: LiquidatorInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        buyCollateral(amount: BigNumberish, token: string, from: string, deadline: BigNumberish, referral: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        buyCollateralFromManyVaults(amount: BigNumberish, token: string, from: string[], deadline: BigNumberish, referral: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        crScalar(overrides?: CallOverrides): Promise<[BigNumber]>;
        getAllowedBuyCollateralFromTokenAmount(token: string, from: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean
        ] & {
            allowedAmount: BigNumber;
            isLiquidation: boolean;
        }>;
        getLiquidationRatio(account: string, fxToken: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            ratio: BigNumber;
        }>;
        handleAddress(overrides?: CallOverrides): Promise<[string]>;
        initialize(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        keeperPoolThreshold(overrides?: CallOverrides): Promise<[BigNumber]>;
        liquidate(account: string, fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        protocolRedemptionFeeRatio(overrides?: CallOverrides): Promise<[BigNumber]>;
        redemptionFeeRatio(overrides?: CallOverrides): Promise<[BigNumber]>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setCrScalar(value: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setHandleContract(_handle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setKeeperPoolThreshold(amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setProtocolRedemptionFeeRatio(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setRedemptionFeeRatio(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        tokensRequiredForCrIncrease(crTarget: BigNumberish, debt: BigNumberish, collateral: BigNumberish, returnRatio: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber] & {
            amount: BigNumber;
        }>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    buyCollateral(amount: BigNumberish, token: string, from: string, deadline: BigNumberish, referral: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    buyCollateralFromManyVaults(amount: BigNumberish, token: string, from: string[], deadline: BigNumberish, referral: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    crScalar(overrides?: CallOverrides): Promise<BigNumber>;
    getAllowedBuyCollateralFromTokenAmount(token: string, from: string, overrides?: CallOverrides): Promise<[
        BigNumber,
        boolean
    ] & {
        allowedAmount: BigNumber;
        isLiquidation: boolean;
    }>;
    getLiquidationRatio(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
    handleAddress(overrides?: CallOverrides): Promise<string>;
    initialize(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    keeperPoolThreshold(overrides?: CallOverrides): Promise<BigNumber>;
    liquidate(account: string, fxToken: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    owner(overrides?: CallOverrides): Promise<string>;
    protocolRedemptionFeeRatio(overrides?: CallOverrides): Promise<BigNumber>;
    redemptionFeeRatio(overrides?: CallOverrides): Promise<BigNumber>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setCrScalar(value: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setHandleContract(_handle: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setKeeperPoolThreshold(amount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setProtocolRedemptionFeeRatio(ratio: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setRedemptionFeeRatio(ratio: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    tokensRequiredForCrIncrease(crTarget: BigNumberish, debt: BigNumberish, collateral: BigNumberish, returnRatio: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    upgradeTo(newImplementation: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        buyCollateral(amount: BigNumberish, token: string, from: string, deadline: BigNumberish, referral: string, overrides?: CallOverrides): Promise<[
            BigNumber[],
            string[],
            BigNumber
        ] & {
            collateralAmounts: BigNumber[];
            collateralTypes: string[];
            etherAmount: BigNumber;
        }>;
        buyCollateralFromManyVaults(amount: BigNumberish, token: string, from: string[], deadline: BigNumberish, referral: string, overrides?: CallOverrides): Promise<[
            BigNumber[],
            string[],
            BigNumber
        ] & {
            collateralAmounts: BigNumber[];
            collateralTypes: string[];
            etherAmount: BigNumber;
        }>;
        crScalar(overrides?: CallOverrides): Promise<BigNumber>;
        getAllowedBuyCollateralFromTokenAmount(token: string, from: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            boolean
        ] & {
            allowedAmount: BigNumber;
            isLiquidation: boolean;
        }>;
        getLiquidationRatio(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        handleAddress(overrides?: CallOverrides): Promise<string>;
        initialize(overrides?: CallOverrides): Promise<void>;
        keeperPoolThreshold(overrides?: CallOverrides): Promise<BigNumber>;
        liquidate(account: string, fxToken: string, overrides?: CallOverrides): Promise<[
            BigNumber,
            string[],
            BigNumber[]
        ] & {
            fxAmount: BigNumber;
            collateralTypes: string[];
            collateralAmounts: BigNumber[];
        }>;
        owner(overrides?: CallOverrides): Promise<string>;
        protocolRedemptionFeeRatio(overrides?: CallOverrides): Promise<BigNumber>;
        redemptionFeeRatio(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        setCrScalar(value: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setHandleContract(_handle: string, overrides?: CallOverrides): Promise<void>;
        setKeeperPoolThreshold(amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setProtocolRedemptionFeeRatio(ratio: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setRedemptionFeeRatio(ratio: BigNumberish, overrides?: CallOverrides): Promise<void>;
        tokensRequiredForCrIncrease(crTarget: BigNumberish, debt: BigNumberish, collateral: BigNumberish, returnRatio: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        upgradeTo(newImplementation: string, overrides?: CallOverrides): Promise<void>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "AdminChanged(address,address)"(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        AdminChanged(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        "BeaconUpgraded(address)"(beacon?: string | null): BeaconUpgradedEventFilter;
        BeaconUpgraded(beacon?: string | null): BeaconUpgradedEventFilter;
        "Liquidate(address,address,uint256,uint256[],address[])"(from?: null, token?: null, tokenAmount?: null, collateralAmounts?: null, collateralTypes?: null): LiquidateEventFilter;
        Liquidate(from?: null, token?: null, tokenAmount?: null, collateralAmounts?: null, collateralTypes?: null): LiquidateEventFilter;
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        "Redeem(address,address,uint256,uint256[],address[])"(from?: null, token?: null, tokenAmount?: null, collateralAmounts?: null, collateralTypes?: null): RedeemEventFilter;
        Redeem(from?: null, token?: null, tokenAmount?: null, collateralAmounts?: null, collateralTypes?: null): RedeemEventFilter;
        "Upgraded(address)"(implementation?: string | null): UpgradedEventFilter;
        Upgraded(implementation?: string | null): UpgradedEventFilter;
    };
    estimateGas: {
        buyCollateral(amount: BigNumberish, token: string, from: string, deadline: BigNumberish, referral: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        buyCollateralFromManyVaults(amount: BigNumberish, token: string, from: string[], deadline: BigNumberish, referral: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        crScalar(overrides?: CallOverrides): Promise<BigNumber>;
        getAllowedBuyCollateralFromTokenAmount(token: string, from: string, overrides?: CallOverrides): Promise<BigNumber>;
        getLiquidationRatio(account: string, fxToken: string, overrides?: CallOverrides): Promise<BigNumber>;
        handleAddress(overrides?: CallOverrides): Promise<BigNumber>;
        initialize(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        keeperPoolThreshold(overrides?: CallOverrides): Promise<BigNumber>;
        liquidate(account: string, fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        protocolRedemptionFeeRatio(overrides?: CallOverrides): Promise<BigNumber>;
        redemptionFeeRatio(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setCrScalar(value: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setHandleContract(_handle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setKeeperPoolThreshold(amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setProtocolRedemptionFeeRatio(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setRedemptionFeeRatio(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        tokensRequiredForCrIncrease(crTarget: BigNumberish, debt: BigNumberish, collateral: BigNumberish, returnRatio: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        buyCollateral(amount: BigNumberish, token: string, from: string, deadline: BigNumberish, referral: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        buyCollateralFromManyVaults(amount: BigNumberish, token: string, from: string[], deadline: BigNumberish, referral: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        crScalar(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getAllowedBuyCollateralFromTokenAmount(token: string, from: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getLiquidationRatio(account: string, fxToken: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        handleAddress(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        initialize(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        keeperPoolThreshold(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        liquidate(account: string, fxToken: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        protocolRedemptionFeeRatio(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        redemptionFeeRatio(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setCrScalar(value: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setHandleContract(_handle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setKeeperPoolThreshold(amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setProtocolRedemptionFeeRatio(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setRedemptionFeeRatio(ratio: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        tokensRequiredForCrIncrease(crTarget: BigNumberish, debt: BigNumberish, collateral: BigNumberish, returnRatio: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
