import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface RebatesInterface extends utils.Interface {
    functions: {
        "NO_HANDLER()": FunctionFragment;
        "canInitiateRebate(address)": FunctionFragment;
        "claim(address)": FunctionFragment;
        "claimFor(address,address)": FunctionFragment;
        "initiateRebate(bytes32,bytes)": FunctionFragment;
        "owner()": FunctionFragment;
        "ownerWithdraw(address,uint256)": FunctionFragment;
        "rebateHandler(bytes32)": FunctionFragment;
        "registerRebate(address,address,uint256,bytes32)": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "setCanInitiateRebate(address,bool)": FunctionFragment;
        "setRebateHandler(bytes32,address)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
        "userTokenRebates(address,address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "NO_HANDLER", values?: undefined): string;
    encodeFunctionData(functionFragment: "canInitiateRebate", values: [string]): string;
    encodeFunctionData(functionFragment: "claim", values: [string]): string;
    encodeFunctionData(functionFragment: "claimFor", values: [string, string]): string;
    encodeFunctionData(functionFragment: "initiateRebate", values: [BytesLike, BytesLike]): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "ownerWithdraw", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "rebateHandler", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "registerRebate", values: [string, string, BigNumberish, BytesLike]): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "setCanInitiateRebate", values: [string, boolean]): string;
    encodeFunctionData(functionFragment: "setRebateHandler", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    encodeFunctionData(functionFragment: "userTokenRebates", values: [string, string]): string;
    decodeFunctionResult(functionFragment: "NO_HANDLER", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "canInitiateRebate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "claim", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "claimFor", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initiateRebate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "ownerWithdraw", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "rebateHandler", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "registerRebate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setCanInitiateRebate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRebateHandler", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "userTokenRebates", data: BytesLike): Result;
    events: {
        "ClaimRebate(address,address,address,uint256)": EventFragment;
        "OwnershipTransferred(address,address)": EventFragment;
        "Rebate(address,address,uint256)": EventFragment;
        "SetCanRebate(address,bool)": EventFragment;
        "SetRebateHandler(bytes32,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ClaimRebate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Rebate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetCanRebate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetRebateHandler"): EventFragment;
}
export type ClaimRebateEvent = TypedEvent<[
    string,
    string,
    string,
    BigNumber
], {
    token: string;
    user: string;
    receiver: string;
    amount: BigNumber;
}>;
export type ClaimRebateEventFilter = TypedEventFilter<ClaimRebateEvent>;
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export type RebateEvent = TypedEvent<[
    string,
    string,
    BigNumber
], {
    receiver: string;
    token: string;
    amount: BigNumber;
}>;
export type RebateEventFilter = TypedEventFilter<RebateEvent>;
export type SetCanRebateEvent = TypedEvent<[
    string,
    boolean
], {
    rebater: string;
    canRebate: boolean;
}>;
export type SetCanRebateEventFilter = TypedEventFilter<SetCanRebateEvent>;
export type SetRebateHandlerEvent = TypedEvent<[
    string,
    string
], {
    action: string;
    handler: string;
}>;
export type SetRebateHandlerEventFilter = TypedEventFilter<SetRebateHandlerEvent>;
export interface Rebates extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: RebatesInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        NO_HANDLER(overrides?: CallOverrides): Promise<[string]>;
        canInitiateRebate(arg0: string, overrides?: CallOverrides): Promise<[boolean]>;
        claim(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        claimFor(token: string, receiver: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        initiateRebate(action: BytesLike, params: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        ownerWithdraw(token: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        rebateHandler(arg0: BytesLike, overrides?: CallOverrides): Promise<[string]>;
        registerRebate(rebateReceiver: string, token: string, amount: BigNumberish, action: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setCanInitiateRebate(rebater: string, _canRebate: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setRebateHandler(action: BytesLike, handler: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        userTokenRebates(arg0: string, arg1: string, overrides?: CallOverrides): Promise<[BigNumber]>;
    };
    NO_HANDLER(overrides?: CallOverrides): Promise<string>;
    canInitiateRebate(arg0: string, overrides?: CallOverrides): Promise<boolean>;
    claim(token: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    claimFor(token: string, receiver: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    initiateRebate(action: BytesLike, params: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    owner(overrides?: CallOverrides): Promise<string>;
    ownerWithdraw(token: string, amount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    rebateHandler(arg0: BytesLike, overrides?: CallOverrides): Promise<string>;
    registerRebate(rebateReceiver: string, token: string, amount: BigNumberish, action: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setCanInitiateRebate(rebater: string, _canRebate: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setRebateHandler(action: BytesLike, handler: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    userTokenRebates(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
    callStatic: {
        NO_HANDLER(overrides?: CallOverrides): Promise<string>;
        canInitiateRebate(arg0: string, overrides?: CallOverrides): Promise<boolean>;
        claim(token: string, overrides?: CallOverrides): Promise<void>;
        claimFor(token: string, receiver: string, overrides?: CallOverrides): Promise<void>;
        initiateRebate(action: BytesLike, params: BytesLike, overrides?: CallOverrides): Promise<void>;
        owner(overrides?: CallOverrides): Promise<string>;
        ownerWithdraw(token: string, amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        rebateHandler(arg0: BytesLike, overrides?: CallOverrides): Promise<string>;
        registerRebate(rebateReceiver: string, token: string, amount: BigNumberish, action: BytesLike, overrides?: CallOverrides): Promise<void>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        setCanInitiateRebate(rebater: string, _canRebate: boolean, overrides?: CallOverrides): Promise<void>;
        setRebateHandler(action: BytesLike, handler: string, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
        userTokenRebates(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
    };
    filters: {
        "ClaimRebate(address,address,address,uint256)"(token?: string | null, user?: string | null, receiver?: string | null, amount?: null): ClaimRebateEventFilter;
        ClaimRebate(token?: string | null, user?: string | null, receiver?: string | null, amount?: null): ClaimRebateEventFilter;
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        "Rebate(address,address,uint256)"(receiver?: string | null, token?: string | null, amount?: null): RebateEventFilter;
        Rebate(receiver?: string | null, token?: string | null, amount?: null): RebateEventFilter;
        "SetCanRebate(address,bool)"(rebater?: string | null, canRebate?: null): SetCanRebateEventFilter;
        SetCanRebate(rebater?: string | null, canRebate?: null): SetCanRebateEventFilter;
        "SetRebateHandler(bytes32,address)"(action?: BytesLike | null, handler?: string | null): SetRebateHandlerEventFilter;
        SetRebateHandler(action?: BytesLike | null, handler?: string | null): SetRebateHandlerEventFilter;
    };
    estimateGas: {
        NO_HANDLER(overrides?: CallOverrides): Promise<BigNumber>;
        canInitiateRebate(arg0: string, overrides?: CallOverrides): Promise<BigNumber>;
        claim(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        claimFor(token: string, receiver: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        initiateRebate(action: BytesLike, params: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        ownerWithdraw(token: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        rebateHandler(arg0: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        registerRebate(rebateReceiver: string, token: string, amount: BigNumberish, action: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setCanInitiateRebate(rebater: string, _canRebate: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setRebateHandler(action: BytesLike, handler: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        userTokenRebates(arg0: string, arg1: string, overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        NO_HANDLER(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        canInitiateRebate(arg0: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        claim(token: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        claimFor(token: string, receiver: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        initiateRebate(action: BytesLike, params: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        ownerWithdraw(token: string, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        rebateHandler(arg0: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        registerRebate(rebateReceiver: string, token: string, amount: BigNumberish, action: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setCanInitiateRebate(rebater: string, _canRebate: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setRebateHandler(action: BytesLike, handler: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        userTokenRebates(arg0: string, arg1: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
