import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export type DepositStruct = {
    amount: BigNumberish;
    S: BigNumberish;
    boostWeight: BigNumberish;
};
export type DepositStructOutput = [BigNumber, BigNumber, BigNumber] & {
    amount: BigNumber;
    S: BigNumber;
    boostWeight: BigNumber;
};
export interface RewardPoolInterface extends utils.Interface {
    functions: {
        "ADMIN_ROLE()": FunctionFragment;
        "DEFAULT_ADMIN_ROLE()": FunctionFragment;
        "OPERATOR_ROLE()": FunctionFragment;
        "allowNonWhitelistedStakingActions(uint256)": FunctionFragment;
        "balanceOf(address)": FunctionFragment;
        "claim()": FunctionFragment;
        "claimFromPool(uint256)": FunctionFragment;
        "createPool(uint256,uint8,address,uint256[],uint256[])": FunctionFragment;
        "distribute()": FunctionFragment;
        "distributeDirectlyForPool(uint256,uint256)": FunctionFragment;
        "enabledPools(uint256)": FunctionFragment;
        "enabledPoolsLength()": FunctionFragment;
        "forex()": FunctionFragment;
        "forexDistributionRate()": FunctionFragment;
        "getDeposit(address,uint256)": FunctionFragment;
        "getEnabledPoolsData()": FunctionFragment;
        "getFxTokenPoolAlias(address,uint256)": FunctionFragment;
        "getPool(uint256)": FunctionFragment;
        "getPoolIdByAlias(bytes32)": FunctionFragment;
        "getRoleAdmin(bytes32)": FunctionFragment;
        "getUserBoostedStake(uint256,uint256,uint256)": FunctionFragment;
        "grantRole(bytes32,address)": FunctionFragment;
        "handleAddress()": FunctionFragment;
        "hasRole(bytes32,address)": FunctionFragment;
        "initialize()": FunctionFragment;
        "lastDistributionDate()": FunctionFragment;
        "poolBalanceOf(address,uint256)": FunctionFragment;
        "poolCount()": FunctionFragment;
        "renounceRole(bytes32,address)": FunctionFragment;
        "revokeRole(bytes32,address)": FunctionFragment;
        "setAllowNonWhitelistedStakingActions(uint256,bool)": FunctionFragment;
        "setForexDistributionRate(uint256)": FunctionFragment;
        "setGovernanceLock(address)": FunctionFragment;
        "setHandleContract(address)": FunctionFragment;
        "setPoolAlias(bytes32,uint256)": FunctionFragment;
        "setPools(uint256[],uint256[])": FunctionFragment;
        "setWhitelistedStaker(address,uint256,bool)": FunctionFragment;
        "setupPools(uint8[],address[],uint256[],bytes32[])": FunctionFragment;
        "stake(address,uint256,uint256)": FunctionFragment;
        "supportsInterface(bytes4)": FunctionFragment;
        "syncTotalRealDeposits()": FunctionFragment;
        "unstake(address,uint256,uint256)": FunctionFragment;
        "updateAccountBoost(address,uint256[])": FunctionFragment;
        "upgradeTo(address)": FunctionFragment;
        "upgradeToAndCall(address,bytes)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "ADMIN_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "DEFAULT_ADMIN_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "OPERATOR_ROLE", values?: undefined): string;
    encodeFunctionData(functionFragment: "allowNonWhitelistedStakingActions", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "balanceOf", values: [string]): string;
    encodeFunctionData(functionFragment: "claim", values?: undefined): string;
    encodeFunctionData(functionFragment: "claimFromPool", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "createPool", values: [BigNumberish, BigNumberish, string, BigNumberish[], BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "distribute", values?: undefined): string;
    encodeFunctionData(functionFragment: "distributeDirectlyForPool", values: [BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "enabledPools", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "enabledPoolsLength", values?: undefined): string;
    encodeFunctionData(functionFragment: "forex", values?: undefined): string;
    encodeFunctionData(functionFragment: "forexDistributionRate", values?: undefined): string;
    encodeFunctionData(functionFragment: "getDeposit", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getEnabledPoolsData", values?: undefined): string;
    encodeFunctionData(functionFragment: "getFxTokenPoolAlias", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getPool", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "getPoolIdByAlias", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getRoleAdmin", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "getUserBoostedStake", values: [BigNumberish, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "grantRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "handleAddress", values?: undefined): string;
    encodeFunctionData(functionFragment: "hasRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "initialize", values?: undefined): string;
    encodeFunctionData(functionFragment: "lastDistributionDate", values?: undefined): string;
    encodeFunctionData(functionFragment: "poolBalanceOf", values: [string, BigNumberish]): string;
    encodeFunctionData(functionFragment: "poolCount", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "revokeRole", values: [BytesLike, string]): string;
    encodeFunctionData(functionFragment: "setAllowNonWhitelistedStakingActions", values: [BigNumberish, boolean]): string;
    encodeFunctionData(functionFragment: "setForexDistributionRate", values: [BigNumberish]): string;
    encodeFunctionData(functionFragment: "setGovernanceLock", values: [string]): string;
    encodeFunctionData(functionFragment: "setHandleContract", values: [string]): string;
    encodeFunctionData(functionFragment: "setPoolAlias", values: [BytesLike, BigNumberish]): string;
    encodeFunctionData(functionFragment: "setPools", values: [BigNumberish[], BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "setWhitelistedStaker", values: [string, BigNumberish, boolean]): string;
    encodeFunctionData(functionFragment: "setupPools", values: [BigNumberish[], string[], BigNumberish[], BytesLike[]]): string;
    encodeFunctionData(functionFragment: "stake", values: [string, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "supportsInterface", values: [BytesLike]): string;
    encodeFunctionData(functionFragment: "syncTotalRealDeposits", values?: undefined): string;
    encodeFunctionData(functionFragment: "unstake", values: [string, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "updateAccountBoost", values: [string, BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "upgradeTo", values: [string]): string;
    encodeFunctionData(functionFragment: "upgradeToAndCall", values: [string, BytesLike]): string;
    decodeFunctionResult(functionFragment: "ADMIN_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "DEFAULT_ADMIN_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "OPERATOR_ROLE", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "allowNonWhitelistedStakingActions", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "balanceOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "claim", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "claimFromPool", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "createPool", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "distribute", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "distributeDirectlyForPool", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "enabledPools", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "enabledPoolsLength", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "forex", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "forexDistributionRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getDeposit", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getEnabledPoolsData", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getFxTokenPoolAlias", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPool", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPoolIdByAlias", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getRoleAdmin", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getUserBoostedStake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "grantRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "handleAddress", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hasRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "initialize", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "lastDistributionDate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "poolBalanceOf", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "poolCount", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "revokeRole", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setAllowNonWhitelistedStakingActions", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setForexDistributionRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setGovernanceLock", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHandleContract", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPoolAlias", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setPools", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setWhitelistedStaker", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setupPools", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "stake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "supportsInterface", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "syncTotalRealDeposits", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "unstake", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "updateAccountBoost", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeTo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "upgradeToAndCall", data: BytesLike): Result;
    events: {
        "AdminChanged(address,address)": EventFragment;
        "AllowNonWhitelistStakingActionChanged(uint256,bool)": EventFragment;
        "BeaconUpgraded(address)": EventFragment;
        "Claim(address,uint256,uint256[],uint256[])": EventFragment;
        "CreatePool(uint256,uint8,address,uint256)": EventFragment;
        "ForexDistributed(uint256,uint256,uint256,uint256[],uint256[])": EventFragment;
        "ForexDistributedDirectly(uint256,uint256)": EventFragment;
        "PoolAliasChanged(uint256,bytes32)": EventFragment;
        "RoleAdminChanged(bytes32,bytes32,bytes32)": EventFragment;
        "RoleGranted(bytes32,address,address)": EventFragment;
        "RoleRevoked(bytes32,address,address)": EventFragment;
        "SetForexDistributionRate(uint256)": EventFragment;
        "SetFxTokenWeights(address[],uint256[])": EventFragment;
        "SetPoolWeights(uint256[],uint256[])": EventFragment;
        "Stake(address,uint256,uint256)": EventFragment;
        "Unstake(address,uint256,uint256)": EventFragment;
        "Upgraded(address)": EventFragment;
        "WhitelistChanged(address,uint256,bool)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "AdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "AllowNonWhitelistStakingActionChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "BeaconUpgraded"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Claim"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "CreatePool"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ForexDistributed"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ForexDistributedDirectly"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "PoolAliasChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleAdminChanged"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleGranted"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "RoleRevoked"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetForexDistributionRate"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetFxTokenWeights"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "SetPoolWeights"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Stake"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Unstake"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "Upgraded"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "WhitelistChanged"): EventFragment;
}
export type AdminChangedEvent = TypedEvent<[
    string,
    string
], {
    previousAdmin: string;
    newAdmin: string;
}>;
export type AdminChangedEventFilter = TypedEventFilter<AdminChangedEvent>;
export type AllowNonWhitelistStakingActionChangedEvent = TypedEvent<[
    BigNumber,
    boolean
], {
    poolId: BigNumber;
    ignoreWhitelist: boolean;
}>;
export type AllowNonWhitelistStakingActionChangedEventFilter = TypedEventFilter<AllowNonWhitelistStakingActionChangedEvent>;
export type BeaconUpgradedEvent = TypedEvent<[string], {
    beacon: string;
}>;
export type BeaconUpgradedEventFilter = TypedEventFilter<BeaconUpgradedEvent>;
export type ClaimEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber[],
    BigNumber[]
], {
    acount: string;
    amount: BigNumber;
    poolIds: BigNumber[];
    amounts: BigNumber[];
}>;
export type ClaimEventFilter = TypedEventFilter<ClaimEvent>;
export type CreatePoolEvent = TypedEvent<[
    BigNumber,
    number,
    string,
    BigNumber
], {
    id: BigNumber;
    assetType: number;
    asset: string;
    weight: BigNumber;
}>;
export type CreatePoolEventFilter = TypedEventFilter<CreatePoolEvent>;
export type ForexDistributedEvent = TypedEvent<[
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber[],
    BigNumber[]
], {
    duration: BigNumber;
    rate: BigNumber;
    totalAmount: BigNumber;
    poolIds: BigNumber[];
    amounts: BigNumber[];
}>;
export type ForexDistributedEventFilter = TypedEventFilter<ForexDistributedEvent>;
export type ForexDistributedDirectlyEvent = TypedEvent<[
    BigNumber,
    BigNumber
], {
    poolId: BigNumber;
    amount: BigNumber;
}>;
export type ForexDistributedDirectlyEventFilter = TypedEventFilter<ForexDistributedDirectlyEvent>;
export type PoolAliasChangedEvent = TypedEvent<[
    BigNumber,
    string
], {
    poolId: BigNumber;
    aliasHash: string;
}>;
export type PoolAliasChangedEventFilter = TypedEventFilter<PoolAliasChangedEvent>;
export type RoleAdminChangedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    previousAdminRole: string;
    newAdminRole: string;
}>;
export type RoleAdminChangedEventFilter = TypedEventFilter<RoleAdminChangedEvent>;
export type RoleGrantedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
export type RoleGrantedEventFilter = TypedEventFilter<RoleGrantedEvent>;
export type RoleRevokedEvent = TypedEvent<[
    string,
    string,
    string
], {
    role: string;
    account: string;
    sender: string;
}>;
export type RoleRevokedEventFilter = TypedEventFilter<RoleRevokedEvent>;
export type SetForexDistributionRateEvent = TypedEvent<[
    BigNumber
], {
    ratePerSecond: BigNumber;
}>;
export type SetForexDistributionRateEventFilter = TypedEventFilter<SetForexDistributionRateEvent>;
export type SetFxTokenWeightsEvent = TypedEvent<[
    string[],
    BigNumber[]
], {
    fxTokens: string[];
    weights: BigNumber[];
}>;
export type SetFxTokenWeightsEventFilter = TypedEventFilter<SetFxTokenWeightsEvent>;
export type SetPoolWeightsEvent = TypedEvent<[
    BigNumber[],
    BigNumber[]
], {
    poolIds: BigNumber[];
    weights: BigNumber[];
}>;
export type SetPoolWeightsEventFilter = TypedEventFilter<SetPoolWeightsEvent>;
export type StakeEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], {
    account: string;
    poolId: BigNumber;
    amount: BigNumber;
}>;
export type StakeEventFilter = TypedEventFilter<StakeEvent>;
export type UnstakeEvent = TypedEvent<[
    string,
    BigNumber,
    BigNumber
], {
    account: string;
    poolId: BigNumber;
    amount: BigNumber;
}>;
export type UnstakeEventFilter = TypedEventFilter<UnstakeEvent>;
export type UpgradedEvent = TypedEvent<[string], {
    implementation: string;
}>;
export type UpgradedEventFilter = TypedEventFilter<UpgradedEvent>;
export type WhitelistChangedEvent = TypedEvent<[
    string,
    BigNumber,
    boolean
], {
    staker: string;
    poolId: BigNumber;
    whitelisted: boolean;
}>;
export type WhitelistChangedEventFilter = TypedEventFilter<WhitelistChangedEvent>;
export interface RewardPool extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: RewardPoolInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        ADMIN_ROLE(overrides?: CallOverrides): Promise<[string]>;
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<[string]>;
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<[string]>;
        allowNonWhitelistedStakingActions(arg0: BigNumberish, overrides?: CallOverrides): Promise<[boolean]>;
        balanceOf(account: string, overrides?: CallOverrides): Promise<[BigNumber] & {
            balance: BigNumber;
        }>;
        claim(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        claimFromPool(poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        createPool(weight: BigNumberish, assetType: BigNumberish, assetAddress: string, poolIds: BigNumberish[], weights: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        distribute(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        distributeDirectlyForPool(poolId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        enabledPools(arg0: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        enabledPoolsLength(overrides?: CallOverrides): Promise<[BigNumber]>;
        forex(overrides?: CallOverrides): Promise<[string]>;
        forexDistributionRate(overrides?: CallOverrides): Promise<[BigNumber]>;
        getDeposit(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<[DepositStructOutput]>;
        getEnabledPoolsData(overrides?: CallOverrides): Promise<[
            BigNumber[],
            BigNumber[],
            BigNumber[],
            BigNumber[]
        ] & {
            poolRatios: BigNumber[];
            accruedAmounts: BigNumber[];
            deltaS: BigNumber[];
            poolIds: BigNumber[];
        }>;
        getFxTokenPoolAlias(token: string, category: BigNumberish, overrides?: CallOverrides): Promise<[string]>;
        getPool(poolId: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            number,
            string,
            BigNumber,
            BigNumber,
            BigNumber
        ] & {
            weight: BigNumber;
            assetType: number;
            assetAddress: string;
            totalDeposits: BigNumber;
            S: BigNumber;
            totalRealDeposits: BigNumber;
        }>;
        getPoolIdByAlias(hash: BytesLike, overrides?: CallOverrides): Promise<[boolean, BigNumber] & {
            found: boolean;
            poolId: BigNumber;
        }>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<[string]>;
        getUserBoostedStake(value: BigNumberish, totalRealDeposits: BigNumberish, boostWeight: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber]>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        handleAddress(overrides?: CallOverrides): Promise<[string]>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<[boolean]>;
        initialize(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        lastDistributionDate(overrides?: CallOverrides): Promise<[BigNumber]>;
        poolBalanceOf(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<[BigNumber] & {
            balance: BigNumber;
        }>;
        poolCount(overrides?: CallOverrides): Promise<[BigNumber]>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setAllowNonWhitelistedStakingActions(poolId: BigNumberish, allow: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setForexDistributionRate(rate: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setGovernanceLock(_governanceLock: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setHandleContract(_handle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPoolAlias(hash: BytesLike, poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setPools(poolIds: BigNumberish[], weights: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setWhitelistedStaker(staker: string, poolId: BigNumberish, isWhitelisted: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setupPools(assetTypes: BigNumberish[], assetAddresses: string[], weights: BigNumberish[], aliases: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        stake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<[boolean]>;
        syncTotalRealDeposits(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        unstake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        updateAccountBoost(account: string, poolIds: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
    DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
    OPERATOR_ROLE(overrides?: CallOverrides): Promise<string>;
    allowNonWhitelistedStakingActions(arg0: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
    balanceOf(account: string, overrides?: CallOverrides): Promise<BigNumber>;
    claim(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    claimFromPool(poolId: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    createPool(weight: BigNumberish, assetType: BigNumberish, assetAddress: string, poolIds: BigNumberish[], weights: BigNumberish[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    distribute(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    distributeDirectlyForPool(poolId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    enabledPools(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    enabledPoolsLength(overrides?: CallOverrides): Promise<BigNumber>;
    forex(overrides?: CallOverrides): Promise<string>;
    forexDistributionRate(overrides?: CallOverrides): Promise<BigNumber>;
    getDeposit(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<DepositStructOutput>;
    getEnabledPoolsData(overrides?: CallOverrides): Promise<[
        BigNumber[],
        BigNumber[],
        BigNumber[],
        BigNumber[]
    ] & {
        poolRatios: BigNumber[];
        accruedAmounts: BigNumber[];
        deltaS: BigNumber[];
        poolIds: BigNumber[];
    }>;
    getFxTokenPoolAlias(token: string, category: BigNumberish, overrides?: CallOverrides): Promise<string>;
    getPool(poolId: BigNumberish, overrides?: CallOverrides): Promise<[
        BigNumber,
        number,
        string,
        BigNumber,
        BigNumber,
        BigNumber
    ] & {
        weight: BigNumber;
        assetType: number;
        assetAddress: string;
        totalDeposits: BigNumber;
        S: BigNumber;
        totalRealDeposits: BigNumber;
    }>;
    getPoolIdByAlias(hash: BytesLike, overrides?: CallOverrides): Promise<[boolean, BigNumber] & {
        found: boolean;
        poolId: BigNumber;
    }>;
    getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
    getUserBoostedStake(value: BigNumberish, totalRealDeposits: BigNumberish, boostWeight: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    grantRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    handleAddress(overrides?: CallOverrides): Promise<string>;
    hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
    initialize(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    lastDistributionDate(overrides?: CallOverrides): Promise<BigNumber>;
    poolBalanceOf(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
    poolCount(overrides?: CallOverrides): Promise<BigNumber>;
    renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setAllowNonWhitelistedStakingActions(poolId: BigNumberish, allow: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setForexDistributionRate(rate: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setGovernanceLock(_governanceLock: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setHandleContract(_handle: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPoolAlias(hash: BytesLike, poolId: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setPools(poolIds: BigNumberish[], weights: BigNumberish[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setWhitelistedStaker(staker: string, poolId: BigNumberish, isWhitelisted: boolean, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setupPools(assetTypes: BigNumberish[], assetAddresses: string[], weights: BigNumberish[], aliases: BytesLike[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    stake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
    syncTotalRealDeposits(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    unstake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    updateAccountBoost(account: string, poolIds: BigNumberish[], overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    upgradeTo(newImplementation: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<string>;
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<string>;
        allowNonWhitelistedStakingActions(arg0: BigNumberish, overrides?: CallOverrides): Promise<boolean>;
        balanceOf(account: string, overrides?: CallOverrides): Promise<BigNumber>;
        claim(overrides?: CallOverrides): Promise<void>;
        claimFromPool(poolId: BigNumberish, overrides?: CallOverrides): Promise<void>;
        createPool(weight: BigNumberish, assetType: BigNumberish, assetAddress: string, poolIds: BigNumberish[], weights: BigNumberish[], overrides?: CallOverrides): Promise<void>;
        distribute(overrides?: CallOverrides): Promise<void>;
        distributeDirectlyForPool(poolId: BigNumberish, amount: BigNumberish, overrides?: CallOverrides): Promise<void>;
        enabledPools(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        enabledPoolsLength(overrides?: CallOverrides): Promise<BigNumber>;
        forex(overrides?: CallOverrides): Promise<string>;
        forexDistributionRate(overrides?: CallOverrides): Promise<BigNumber>;
        getDeposit(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<DepositStructOutput>;
        getEnabledPoolsData(overrides?: CallOverrides): Promise<[
            BigNumber[],
            BigNumber[],
            BigNumber[],
            BigNumber[]
        ] & {
            poolRatios: BigNumber[];
            accruedAmounts: BigNumber[];
            deltaS: BigNumber[];
            poolIds: BigNumber[];
        }>;
        getFxTokenPoolAlias(token: string, category: BigNumberish, overrides?: CallOverrides): Promise<string>;
        getPool(poolId: BigNumberish, overrides?: CallOverrides): Promise<[
            BigNumber,
            number,
            string,
            BigNumber,
            BigNumber,
            BigNumber
        ] & {
            weight: BigNumber;
            assetType: number;
            assetAddress: string;
            totalDeposits: BigNumber;
            S: BigNumber;
            totalRealDeposits: BigNumber;
        }>;
        getPoolIdByAlias(hash: BytesLike, overrides?: CallOverrides): Promise<[boolean, BigNumber] & {
            found: boolean;
            poolId: BigNumber;
        }>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<string>;
        getUserBoostedStake(value: BigNumberish, totalRealDeposits: BigNumberish, boostWeight: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        handleAddress(overrides?: CallOverrides): Promise<string>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<boolean>;
        initialize(overrides?: CallOverrides): Promise<void>;
        lastDistributionDate(overrides?: CallOverrides): Promise<BigNumber>;
        poolBalanceOf(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        poolCount(overrides?: CallOverrides): Promise<BigNumber>;
        renounceRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        revokeRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<void>;
        setAllowNonWhitelistedStakingActions(poolId: BigNumberish, allow: boolean, overrides?: CallOverrides): Promise<void>;
        setForexDistributionRate(rate: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setGovernanceLock(_governanceLock: string, overrides?: CallOverrides): Promise<void>;
        setHandleContract(_handle: string, overrides?: CallOverrides): Promise<void>;
        setPoolAlias(hash: BytesLike, poolId: BigNumberish, overrides?: CallOverrides): Promise<void>;
        setPools(poolIds: BigNumberish[], weights: BigNumberish[], overrides?: CallOverrides): Promise<void>;
        setWhitelistedStaker(staker: string, poolId: BigNumberish, isWhitelisted: boolean, overrides?: CallOverrides): Promise<void>;
        setupPools(assetTypes: BigNumberish[], assetAddresses: string[], weights: BigNumberish[], aliases: BytesLike[], overrides?: CallOverrides): Promise<void>;
        stake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<boolean>;
        syncTotalRealDeposits(overrides?: CallOverrides): Promise<void>;
        unstake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        updateAccountBoost(account: string, poolIds: BigNumberish[], overrides?: CallOverrides): Promise<void>;
        upgradeTo(newImplementation: string, overrides?: CallOverrides): Promise<void>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "AdminChanged(address,address)"(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        AdminChanged(previousAdmin?: null, newAdmin?: null): AdminChangedEventFilter;
        "AllowNonWhitelistStakingActionChanged(uint256,bool)"(poolId?: BigNumberish | null, ignoreWhitelist?: null): AllowNonWhitelistStakingActionChangedEventFilter;
        AllowNonWhitelistStakingActionChanged(poolId?: BigNumberish | null, ignoreWhitelist?: null): AllowNonWhitelistStakingActionChangedEventFilter;
        "BeaconUpgraded(address)"(beacon?: string | null): BeaconUpgradedEventFilter;
        BeaconUpgraded(beacon?: string | null): BeaconUpgradedEventFilter;
        "Claim(address,uint256,uint256[],uint256[])"(acount?: string | null, amount?: null, poolIds?: null, amounts?: null): ClaimEventFilter;
        Claim(acount?: string | null, amount?: null, poolIds?: null, amounts?: null): ClaimEventFilter;
        "CreatePool(uint256,uint8,address,uint256)"(id?: null, assetType?: null, asset?: null, weight?: null): CreatePoolEventFilter;
        CreatePool(id?: null, assetType?: null, asset?: null, weight?: null): CreatePoolEventFilter;
        "ForexDistributed(uint256,uint256,uint256,uint256[],uint256[])"(duration?: null, rate?: null, totalAmount?: null, poolIds?: null, amounts?: null): ForexDistributedEventFilter;
        ForexDistributed(duration?: null, rate?: null, totalAmount?: null, poolIds?: null, amounts?: null): ForexDistributedEventFilter;
        "ForexDistributedDirectly(uint256,uint256)"(poolId?: null, amount?: null): ForexDistributedDirectlyEventFilter;
        ForexDistributedDirectly(poolId?: null, amount?: null): ForexDistributedDirectlyEventFilter;
        "PoolAliasChanged(uint256,bytes32)"(poolId?: null, aliasHash?: null): PoolAliasChangedEventFilter;
        PoolAliasChanged(poolId?: null, aliasHash?: null): PoolAliasChangedEventFilter;
        "RoleAdminChanged(bytes32,bytes32,bytes32)"(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        RoleAdminChanged(role?: BytesLike | null, previousAdminRole?: BytesLike | null, newAdminRole?: BytesLike | null): RoleAdminChangedEventFilter;
        "RoleGranted(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        RoleGranted(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleGrantedEventFilter;
        "RoleRevoked(bytes32,address,address)"(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        RoleRevoked(role?: BytesLike | null, account?: string | null, sender?: string | null): RoleRevokedEventFilter;
        "SetForexDistributionRate(uint256)"(ratePerSecond?: null): SetForexDistributionRateEventFilter;
        SetForexDistributionRate(ratePerSecond?: null): SetForexDistributionRateEventFilter;
        "SetFxTokenWeights(address[],uint256[])"(fxTokens?: null, weights?: null): SetFxTokenWeightsEventFilter;
        SetFxTokenWeights(fxTokens?: null, weights?: null): SetFxTokenWeightsEventFilter;
        "SetPoolWeights(uint256[],uint256[])"(poolIds?: null, weights?: null): SetPoolWeightsEventFilter;
        SetPoolWeights(poolIds?: null, weights?: null): SetPoolWeightsEventFilter;
        "Stake(address,uint256,uint256)"(account?: string | null, poolId?: null, amount?: null): StakeEventFilter;
        Stake(account?: string | null, poolId?: null, amount?: null): StakeEventFilter;
        "Unstake(address,uint256,uint256)"(account?: string | null, poolId?: null, amount?: null): UnstakeEventFilter;
        Unstake(account?: string | null, poolId?: null, amount?: null): UnstakeEventFilter;
        "Upgraded(address)"(implementation?: string | null): UpgradedEventFilter;
        Upgraded(implementation?: string | null): UpgradedEventFilter;
        "WhitelistChanged(address,uint256,bool)"(staker?: null, poolId?: null, whitelisted?: null): WhitelistChangedEventFilter;
        WhitelistChanged(staker?: null, poolId?: null, whitelisted?: null): WhitelistChangedEventFilter;
    };
    estimateGas: {
        ADMIN_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<BigNumber>;
        allowNonWhitelistedStakingActions(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        balanceOf(account: string, overrides?: CallOverrides): Promise<BigNumber>;
        claim(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        claimFromPool(poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        createPool(weight: BigNumberish, assetType: BigNumberish, assetAddress: string, poolIds: BigNumberish[], weights: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        distribute(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        distributeDirectlyForPool(poolId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        enabledPools(arg0: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        enabledPoolsLength(overrides?: CallOverrides): Promise<BigNumber>;
        forex(overrides?: CallOverrides): Promise<BigNumber>;
        forexDistributionRate(overrides?: CallOverrides): Promise<BigNumber>;
        getDeposit(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getEnabledPoolsData(overrides?: CallOverrides): Promise<BigNumber>;
        getFxTokenPoolAlias(token: string, category: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getPool(poolId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getPoolIdByAlias(hash: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        getUserBoostedStake(value: BigNumberish, totalRealDeposits: BigNumberish, boostWeight: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        handleAddress(overrides?: CallOverrides): Promise<BigNumber>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<BigNumber>;
        initialize(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        lastDistributionDate(overrides?: CallOverrides): Promise<BigNumber>;
        poolBalanceOf(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        poolCount(overrides?: CallOverrides): Promise<BigNumber>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setAllowNonWhitelistedStakingActions(poolId: BigNumberish, allow: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setForexDistributionRate(rate: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setGovernanceLock(_governanceLock: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setHandleContract(_handle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPoolAlias(hash: BytesLike, poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setPools(poolIds: BigNumberish[], weights: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setWhitelistedStaker(staker: string, poolId: BigNumberish, isWhitelisted: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setupPools(assetTypes: BigNumberish[], assetAddresses: string[], weights: BigNumberish[], aliases: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        stake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<BigNumber>;
        syncTotalRealDeposits(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        unstake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        updateAccountBoost(account: string, poolIds: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        ADMIN_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        DEFAULT_ADMIN_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        OPERATOR_ROLE(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        allowNonWhitelistedStakingActions(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        balanceOf(account: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        claim(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        claimFromPool(poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        createPool(weight: BigNumberish, assetType: BigNumberish, assetAddress: string, poolIds: BigNumberish[], weights: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        distribute(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        distributeDirectlyForPool(poolId: BigNumberish, amount: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        enabledPools(arg0: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        enabledPoolsLength(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        forex(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        forexDistributionRate(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getDeposit(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getEnabledPoolsData(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getFxTokenPoolAlias(token: string, category: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPool(poolId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPoolIdByAlias(hash: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getRoleAdmin(role: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getUserBoostedStake(value: BigNumberish, totalRealDeposits: BigNumberish, boostWeight: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        grantRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        handleAddress(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        hasRole(role: BytesLike, account: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        initialize(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        lastDistributionDate(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        poolBalanceOf(account: string, poolId: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        poolCount(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        revokeRole(role: BytesLike, account: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setAllowNonWhitelistedStakingActions(poolId: BigNumberish, allow: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setForexDistributionRate(rate: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setGovernanceLock(_governanceLock: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setHandleContract(_handle: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPoolAlias(hash: BytesLike, poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setPools(poolIds: BigNumberish[], weights: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setWhitelistedStaker(staker: string, poolId: BigNumberish, isWhitelisted: boolean, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setupPools(assetTypes: BigNumberish[], assetAddresses: string[], weights: BigNumberish[], aliases: BytesLike[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        stake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        supportsInterface(interfaceId: BytesLike, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        syncTotalRealDeposits(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        unstake(account: string, value: BigNumberish, poolId: BigNumberish, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        updateAccountBoost(account: string, poolIds: BigNumberish[], overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        upgradeTo(newImplementation: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        upgradeToAndCall(newImplementation: string, data: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
