import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface RouterBalancerCurveInterface extends utils.Interface {
    functions: {
        "swapBalancerToCurve(address,address,address,address,address,bytes32,uint256,uint256,address)": FunctionFragment;
        "swapCurveToBalancer(address,address,address,address,address,bytes32,uint256,uint256,address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "swapBalancerToCurve", values: [
        string,
        string,
        string,
        string,
        string,
        BytesLike,
        BigNumberish,
        BigNumberish,
        string
    ]): string;
    encodeFunctionData(functionFragment: "swapCurveToBalancer", values: [
        string,
        string,
        string,
        string,
        string,
        BytesLike,
        BigNumberish,
        BigNumberish,
        string
    ]): string;
    decodeFunctionResult(functionFragment: "swapBalancerToCurve", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapCurveToBalancer", data: BytesLike): Result;
    events: {};
}
export interface RouterBalancerCurve extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: RouterBalancerCurveInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        swapBalancerToCurve(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapCurveToBalancer(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    swapBalancerToCurve(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapCurveToBalancer(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        swapBalancerToCurve(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: CallOverrides): Promise<void>;
        swapCurveToBalancer(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: CallOverrides): Promise<void>;
    };
    filters: {};
    estimateGas: {
        swapBalancerToCurve(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapCurveToBalancer(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        swapBalancerToCurve(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapCurveToBalancer(tokenIn: string, intermediateToken: string, tokenOut: string, curveFactory: string, curvePool: string, balancerPoolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
