import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface RouterEthHlpBalancerInterface extends utils.Interface {
    functions: {
        "hlpRouter()": FunctionFragment;
        "owner()": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "routerHlpBalancer()": FunctionFragment;
        "setHlpRouter(address)": FunctionFragment;
        "swapBalancerToEth(address,address,bytes32,uint256,uint256,address,bytes)": FunctionFragment;
        "swapEthToBalancer(address,address,bytes32,uint256,address,bytes)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "hlpRouter", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "routerHlpBalancer", values?: undefined): string;
    encodeFunctionData(functionFragment: "setHlpRouter", values: [string]): string;
    encodeFunctionData(functionFragment: "swapBalancerToEth", values: [
        string,
        string,
        BytesLike,
        BigNumberish,
        BigNumberish,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "swapEthToBalancer", values: [string, string, BytesLike, BigNumberish, string, BytesLike]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    decodeFunctionResult(functionFragment: "hlpRouter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "routerHlpBalancer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHlpRouter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapBalancerToEth", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapEthToBalancer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    events: {
        "ChangeHlpRouter(address)": EventFragment;
        "OwnershipTransferred(address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ChangeHlpRouter"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
}
export type ChangeHlpRouterEvent = TypedEvent<[
    string
], {
    newHlpRouter: string;
}>;
export type ChangeHlpRouterEventFilter = TypedEventFilter<ChangeHlpRouterEvent>;
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export interface RouterEthHlpBalancer extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: RouterEthHlpBalancerInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        hlpRouter(overrides?: CallOverrides): Promise<[string]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        routerHlpBalancer(overrides?: CallOverrides): Promise<[string]>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapBalancerToEth(tokenIn: string, hlpBalancerToken: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapEthToBalancer(hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    hlpRouter(overrides?: CallOverrides): Promise<string>;
    owner(overrides?: CallOverrides): Promise<string>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    routerHlpBalancer(overrides?: CallOverrides): Promise<string>;
    setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapBalancerToEth(tokenIn: string, hlpBalancerToken: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapEthToBalancer(hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        hlpRouter(overrides?: CallOverrides): Promise<string>;
        owner(overrides?: CallOverrides): Promise<string>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        routerHlpBalancer(overrides?: CallOverrides): Promise<string>;
        setHlpRouter(_hlpRouter: string, overrides?: CallOverrides): Promise<void>;
        swapBalancerToEth(tokenIn: string, hlpBalancerToken: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        swapEthToBalancer(hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "ChangeHlpRouter(address)"(newHlpRouter?: null): ChangeHlpRouterEventFilter;
        ChangeHlpRouter(newHlpRouter?: null): ChangeHlpRouterEventFilter;
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
    };
    estimateGas: {
        hlpRouter(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        routerHlpBalancer(overrides?: CallOverrides): Promise<BigNumber>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapBalancerToEth(tokenIn: string, hlpBalancerToken: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapEthToBalancer(hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        hlpRouter(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        routerHlpBalancer(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapBalancerToEth(tokenIn: string, hlpBalancerToken: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapEthToBalancer(hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
