import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface RouterHlpBalancerInterface extends utils.Interface {
    functions: {
        "balancerVault()": FunctionFragment;
        "hlpRouter()": FunctionFragment;
        "owner()": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "setHlpRouter(address)": FunctionFragment;
        "swapBalancerToHlp(address,address,address,bytes32,uint256,uint256,address,bytes)": FunctionFragment;
        "swapHlpToBalancer(address,address,address,bytes32,uint256,uint256,address,bytes)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "balancerVault", values?: undefined): string;
    encodeFunctionData(functionFragment: "hlpRouter", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "setHlpRouter", values: [string]): string;
    encodeFunctionData(functionFragment: "swapBalancerToHlp", values: [
        string,
        string,
        string,
        BytesLike,
        BigNumberish,
        BigNumberish,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "swapHlpToBalancer", values: [
        string,
        string,
        string,
        BytesLike,
        BigNumberish,
        BigNumberish,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    decodeFunctionResult(functionFragment: "balancerVault", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hlpRouter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHlpRouter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapBalancerToHlp", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapHlpToBalancer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    events: {
        "ChangeHlpRouter(address)": EventFragment;
        "OwnershipTransferred(address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ChangeHlpRouter"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
}
export type ChangeHlpRouterEvent = TypedEvent<[
    string
], {
    newHlpRouter: string;
}>;
export type ChangeHlpRouterEventFilter = TypedEventFilter<ChangeHlpRouterEvent>;
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export interface RouterHlpBalancer extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: RouterHlpBalancerInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        balancerVault(overrides?: CallOverrides): Promise<[string]>;
        hlpRouter(overrides?: CallOverrides): Promise<[string]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapBalancerToHlp(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapHlpToBalancer(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    balancerVault(overrides?: CallOverrides): Promise<string>;
    hlpRouter(overrides?: CallOverrides): Promise<string>;
    owner(overrides?: CallOverrides): Promise<string>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapBalancerToHlp(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapHlpToBalancer(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        balancerVault(overrides?: CallOverrides): Promise<string>;
        hlpRouter(overrides?: CallOverrides): Promise<string>;
        owner(overrides?: CallOverrides): Promise<string>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        setHlpRouter(_hlpRouter: string, overrides?: CallOverrides): Promise<void>;
        swapBalancerToHlp(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        swapHlpToBalancer(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "ChangeHlpRouter(address)"(newHlpRouter?: null): ChangeHlpRouterEventFilter;
        ChangeHlpRouter(newHlpRouter?: null): ChangeHlpRouterEventFilter;
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
    };
    estimateGas: {
        balancerVault(overrides?: CallOverrides): Promise<BigNumber>;
        hlpRouter(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapBalancerToHlp(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapHlpToBalancer(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        balancerVault(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        hlpRouter(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapBalancerToHlp(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapHlpToBalancer(tokenIn: string, hlpBalancerToken: string, tokenOut: string, poolId: BytesLike, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
