import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface RouterHpsmHlpBalancerInterface extends utils.Interface {
    functions: {
        "hpsm()": FunctionFragment;
        "owner()": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "routerHlpBalancer()": FunctionFragment;
        "setHpsm(address)": FunctionFragment;
        "swapBalancerToPeggedToken(address,address,address,address,uint256,uint256,bytes32,address,bytes)": FunctionFragment;
        "swapPeggedTokenToBalancer(address,address,address,address,uint256,uint256,bytes32,address,bytes)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "hpsm", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "routerHlpBalancer", values?: undefined): string;
    encodeFunctionData(functionFragment: "setHpsm", values: [string]): string;
    encodeFunctionData(functionFragment: "swapBalancerToPeggedToken", values: [
        string,
        string,
        string,
        string,
        BigNumberish,
        BigNumberish,
        BytesLike,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "swapPeggedTokenToBalancer", values: [
        string,
        string,
        string,
        string,
        BigNumberish,
        BigNumberish,
        BytesLike,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    decodeFunctionResult(functionFragment: "hpsm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "routerHlpBalancer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHpsm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapBalancerToPeggedToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapPeggedTokenToBalancer", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    events: {
        "ChangeHpsm(address)": EventFragment;
        "OwnershipTransferred(address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ChangeHpsm"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
}
export type ChangeHpsmEvent = TypedEvent<[string], {
    newPsm: string;
}>;
export type ChangeHpsmEventFilter = TypedEventFilter<ChangeHpsmEvent>;
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export interface RouterHpsmHlpBalancer extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: RouterHpsmHlpBalancerInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        hpsm(overrides?: CallOverrides): Promise<[string]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        routerHlpBalancer(overrides?: CallOverrides): Promise<[string]>;
        setHpsm(_hpsm: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapBalancerToPeggedToken(tokenIn: string, hlpBalancerToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapPeggedTokenToBalancer(peggedToken: string, fxToken: string, hlpBalancerToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    hpsm(overrides?: CallOverrides): Promise<string>;
    owner(overrides?: CallOverrides): Promise<string>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    routerHlpBalancer(overrides?: CallOverrides): Promise<string>;
    setHpsm(_hpsm: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapBalancerToPeggedToken(tokenIn: string, hlpBalancerToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapPeggedTokenToBalancer(peggedToken: string, fxToken: string, hlpBalancerToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        hpsm(overrides?: CallOverrides): Promise<string>;
        owner(overrides?: CallOverrides): Promise<string>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        routerHlpBalancer(overrides?: CallOverrides): Promise<string>;
        setHpsm(_hpsm: string, overrides?: CallOverrides): Promise<void>;
        swapBalancerToPeggedToken(tokenIn: string, hlpBalancerToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        swapPeggedTokenToBalancer(peggedToken: string, fxToken: string, hlpBalancerToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "ChangeHpsm(address)"(newPsm?: null): ChangeHpsmEventFilter;
        ChangeHpsm(newPsm?: null): ChangeHpsmEventFilter;
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
    };
    estimateGas: {
        hpsm(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        routerHlpBalancer(overrides?: CallOverrides): Promise<BigNumber>;
        setHpsm(_hpsm: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapBalancerToPeggedToken(tokenIn: string, hlpBalancerToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapPeggedTokenToBalancer(peggedToken: string, fxToken: string, hlpBalancerToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        hpsm(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        routerHlpBalancer(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setHpsm(_hpsm: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapBalancerToPeggedToken(tokenIn: string, hlpBalancerToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapPeggedTokenToBalancer(peggedToken: string, fxToken: string, hlpBalancerToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, poolId: BytesLike, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
