import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface RouterHpsmHlpCurveV2Interface extends utils.Interface {
    functions: {
        "hlpRouter()": FunctionFragment;
        "hpsm()": FunctionFragment;
        "owner()": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "routerHpsmHlp()": FunctionFragment;
        "setHlpRouter(address)": FunctionFragment;
        "setHpsm(address)": FunctionFragment;
        "setRouterHpsmHlp(address)": FunctionFragment;
        "swapEthToCurveToken(address,address,address,uint256,address,address,bytes)": FunctionFragment;
        "swapHlpTokenToCurveToken(address,address,address,uint256,address,uint256,address,address,bytes)": FunctionFragment;
        "swapPeggedTokenToCurveToken(address,address,address,address,uint256,address,uint256,address,address,bytes)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "hlpRouter", values?: undefined): string;
    encodeFunctionData(functionFragment: "hpsm", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "routerHpsmHlp", values?: undefined): string;
    encodeFunctionData(functionFragment: "setHlpRouter", values: [string]): string;
    encodeFunctionData(functionFragment: "setHpsm", values: [string]): string;
    encodeFunctionData(functionFragment: "setRouterHpsmHlp", values: [string]): string;
    encodeFunctionData(functionFragment: "swapEthToCurveToken", values: [string, string, string, BigNumberish, string, string, BytesLike]): string;
    encodeFunctionData(functionFragment: "swapHlpTokenToCurveToken", values: [
        string,
        string,
        string,
        BigNumberish,
        string,
        BigNumberish,
        string,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "swapPeggedTokenToCurveToken", values: [
        string,
        string,
        string,
        string,
        BigNumberish,
        string,
        BigNumberish,
        string,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    decodeFunctionResult(functionFragment: "hlpRouter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hpsm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "routerHpsmHlp", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHlpRouter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHpsm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setRouterHpsmHlp", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapEthToCurveToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapHlpTokenToCurveToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapPeggedTokenToCurveToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    events: {
        "ChangeHlpRouter(address)": EventFragment;
        "ChangeHpsm(address)": EventFragment;
        "ChangeRouterHpsmHlp(address)": EventFragment;
        "OwnershipTransferred(address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ChangeHlpRouter"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ChangeHpsm"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ChangeRouterHpsmHlp"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
}
export type ChangeHlpRouterEvent = TypedEvent<[
    string
], {
    newHlpRouter: string;
}>;
export type ChangeHlpRouterEventFilter = TypedEventFilter<ChangeHlpRouterEvent>;
export type ChangeHpsmEvent = TypedEvent<[string], {
    newPsm: string;
}>;
export type ChangeHpsmEventFilter = TypedEventFilter<ChangeHpsmEvent>;
export type ChangeRouterHpsmHlpEvent = TypedEvent<[
    string
], {
    routerHpsmHlp: string;
}>;
export type ChangeRouterHpsmHlpEventFilter = TypedEventFilter<ChangeRouterHpsmHlpEvent>;
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export interface RouterHpsmHlpCurveV2 extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: RouterHpsmHlpCurveV2Interface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        hlpRouter(overrides?: CallOverrides): Promise<[string]>;
        hpsm(overrides?: CallOverrides): Promise<[string]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        routerHpsmHlp(overrides?: CallOverrides): Promise<[string]>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setHpsm(_hpsm: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setRouterHpsmHlp(_routerHpsmHlp: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapEthToCurveToken(hlpCurveToken: string, tokenOut: string, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapHlpTokenToCurveToken(hlpToken: string, hlpCurveToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapPeggedTokenToCurveToken(peggedToken: string, fxToken: string, hlpToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    hlpRouter(overrides?: CallOverrides): Promise<string>;
    hpsm(overrides?: CallOverrides): Promise<string>;
    owner(overrides?: CallOverrides): Promise<string>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    routerHpsmHlp(overrides?: CallOverrides): Promise<string>;
    setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setHpsm(_hpsm: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setRouterHpsmHlp(_routerHpsmHlp: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapEthToCurveToken(hlpCurveToken: string, tokenOut: string, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapHlpTokenToCurveToken(hlpToken: string, hlpCurveToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapPeggedTokenToCurveToken(peggedToken: string, fxToken: string, hlpToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        hlpRouter(overrides?: CallOverrides): Promise<string>;
        hpsm(overrides?: CallOverrides): Promise<string>;
        owner(overrides?: CallOverrides): Promise<string>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        routerHpsmHlp(overrides?: CallOverrides): Promise<string>;
        setHlpRouter(_hlpRouter: string, overrides?: CallOverrides): Promise<void>;
        setHpsm(_hpsm: string, overrides?: CallOverrides): Promise<void>;
        setRouterHpsmHlp(_routerHpsmHlp: string, overrides?: CallOverrides): Promise<void>;
        swapEthToCurveToken(hlpCurveToken: string, tokenOut: string, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        swapHlpTokenToCurveToken(hlpToken: string, hlpCurveToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        swapPeggedTokenToCurveToken(peggedToken: string, fxToken: string, hlpToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "ChangeHlpRouter(address)"(newHlpRouter?: null): ChangeHlpRouterEventFilter;
        ChangeHlpRouter(newHlpRouter?: null): ChangeHlpRouterEventFilter;
        "ChangeHpsm(address)"(newPsm?: null): ChangeHpsmEventFilter;
        ChangeHpsm(newPsm?: null): ChangeHpsmEventFilter;
        "ChangeRouterHpsmHlp(address)"(routerHpsmHlp?: string | null): ChangeRouterHpsmHlpEventFilter;
        ChangeRouterHpsmHlp(routerHpsmHlp?: string | null): ChangeRouterHpsmHlpEventFilter;
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
    };
    estimateGas: {
        hlpRouter(overrides?: CallOverrides): Promise<BigNumber>;
        hpsm(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        routerHpsmHlp(overrides?: CallOverrides): Promise<BigNumber>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setHpsm(_hpsm: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setRouterHpsmHlp(_routerHpsmHlp: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapEthToCurveToken(hlpCurveToken: string, tokenOut: string, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapHlpTokenToCurveToken(hlpToken: string, hlpCurveToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapPeggedTokenToCurveToken(peggedToken: string, fxToken: string, hlpToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        hlpRouter(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        hpsm(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        routerHpsmHlp(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setHpsm(_hpsm: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setRouterHpsmHlp(_routerHpsmHlp: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapEthToCurveToken(hlpCurveToken: string, tokenOut: string, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapHlpTokenToCurveToken(hlpToken: string, hlpCurveToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapPeggedTokenToCurveToken(peggedToken: string, fxToken: string, hlpToken: string, tokenOut: string, amountIn: BigNumberish, receiver: string, minOut: BigNumberish, metapoolFactory: string, pool: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
