import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PayableOverrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result, EventFragment } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export interface RouterHpsmHlpV2Interface extends utils.Interface {
    functions: {
        "hlpRouter()": FunctionFragment;
        "hpsm()": FunctionFragment;
        "owner()": FunctionFragment;
        "renounceOwnership()": FunctionFragment;
        "setHlpRouter(address)": FunctionFragment;
        "setHpsm(address)": FunctionFragment;
        "swapEthToPeggedToken(address,address,uint256,address,bytes)": FunctionFragment;
        "swapHlpTokenToPeggedToken(address,address,address,uint256,uint256,address,bytes)": FunctionFragment;
        "swapPeggedTokenToEth(address,address,uint256,uint256,address,bytes)": FunctionFragment;
        "swapPeggedTokenToHlpToken(address,address,address,uint256,uint256,address,bytes)": FunctionFragment;
        "transferOwnership(address)": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "hlpRouter", values?: undefined): string;
    encodeFunctionData(functionFragment: "hpsm", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "renounceOwnership", values?: undefined): string;
    encodeFunctionData(functionFragment: "setHlpRouter", values: [string]): string;
    encodeFunctionData(functionFragment: "setHpsm", values: [string]): string;
    encodeFunctionData(functionFragment: "swapEthToPeggedToken", values: [string, string, BigNumberish, string, BytesLike]): string;
    encodeFunctionData(functionFragment: "swapHlpTokenToPeggedToken", values: [
        string,
        string,
        string,
        BigNumberish,
        BigNumberish,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "swapPeggedTokenToEth", values: [string, string, BigNumberish, BigNumberish, string, BytesLike]): string;
    encodeFunctionData(functionFragment: "swapPeggedTokenToHlpToken", values: [
        string,
        string,
        string,
        BigNumberish,
        BigNumberish,
        string,
        BytesLike
    ]): string;
    encodeFunctionData(functionFragment: "transferOwnership", values: [string]): string;
    decodeFunctionResult(functionFragment: "hlpRouter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "hpsm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "renounceOwnership", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHlpRouter", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setHpsm", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapEthToPeggedToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapHlpTokenToPeggedToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapPeggedTokenToEth", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "swapPeggedTokenToHlpToken", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "transferOwnership", data: BytesLike): Result;
    events: {
        "ChangeHlpRouter(address)": EventFragment;
        "ChangeHpsm(address)": EventFragment;
        "OwnershipTransferred(address,address)": EventFragment;
    };
    getEvent(nameOrSignatureOrTopic: "ChangeHlpRouter"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "ChangeHpsm"): EventFragment;
    getEvent(nameOrSignatureOrTopic: "OwnershipTransferred"): EventFragment;
}
export type ChangeHlpRouterEvent = TypedEvent<[
    string
], {
    newHlpRouter: string;
}>;
export type ChangeHlpRouterEventFilter = TypedEventFilter<ChangeHlpRouterEvent>;
export type ChangeHpsmEvent = TypedEvent<[string], {
    newPsm: string;
}>;
export type ChangeHpsmEventFilter = TypedEventFilter<ChangeHpsmEvent>;
export type OwnershipTransferredEvent = TypedEvent<[
    string,
    string
], {
    previousOwner: string;
    newOwner: string;
}>;
export type OwnershipTransferredEventFilter = TypedEventFilter<OwnershipTransferredEvent>;
export interface RouterHpsmHlpV2 extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: RouterHpsmHlpV2Interface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        hlpRouter(overrides?: CallOverrides): Promise<[string]>;
        hpsm(overrides?: CallOverrides): Promise<[string]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        setHpsm(_hpsm: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapEthToPeggedToken(fxToken: string, tokenOut: string, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapHlpTokenToPeggedToken(hlpToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapPeggedTokenToEth(peggedToken: string, fxToken: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        swapPeggedTokenToHlpToken(peggedToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
    };
    hlpRouter(overrides?: CallOverrides): Promise<string>;
    hpsm(overrides?: CallOverrides): Promise<string>;
    owner(overrides?: CallOverrides): Promise<string>;
    renounceOwnership(overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    setHpsm(_hpsm: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapEthToPeggedToken(fxToken: string, tokenOut: string, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapHlpTokenToPeggedToken(hlpToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapPeggedTokenToEth(peggedToken: string, fxToken: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    swapPeggedTokenToHlpToken(peggedToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    transferOwnership(newOwner: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    callStatic: {
        hlpRouter(overrides?: CallOverrides): Promise<string>;
        hpsm(overrides?: CallOverrides): Promise<string>;
        owner(overrides?: CallOverrides): Promise<string>;
        renounceOwnership(overrides?: CallOverrides): Promise<void>;
        setHlpRouter(_hlpRouter: string, overrides?: CallOverrides): Promise<void>;
        setHpsm(_hpsm: string, overrides?: CallOverrides): Promise<void>;
        swapEthToPeggedToken(fxToken: string, tokenOut: string, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        swapHlpTokenToPeggedToken(hlpToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        swapPeggedTokenToEth(peggedToken: string, fxToken: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        swapPeggedTokenToHlpToken(peggedToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: CallOverrides): Promise<void>;
        transferOwnership(newOwner: string, overrides?: CallOverrides): Promise<void>;
    };
    filters: {
        "ChangeHlpRouter(address)"(newHlpRouter?: null): ChangeHlpRouterEventFilter;
        ChangeHlpRouter(newHlpRouter?: null): ChangeHlpRouterEventFilter;
        "ChangeHpsm(address)"(newPsm?: null): ChangeHpsmEventFilter;
        ChangeHpsm(newPsm?: null): ChangeHpsmEventFilter;
        "OwnershipTransferred(address,address)"(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
        OwnershipTransferred(previousOwner?: string | null, newOwner?: string | null): OwnershipTransferredEventFilter;
    };
    estimateGas: {
        hlpRouter(overrides?: CallOverrides): Promise<BigNumber>;
        hpsm(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        setHpsm(_hpsm: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapEthToPeggedToken(fxToken: string, tokenOut: string, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapHlpTokenToPeggedToken(hlpToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapPeggedTokenToEth(peggedToken: string, fxToken: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        swapPeggedTokenToHlpToken(peggedToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
    };
    populateTransaction: {
        hlpRouter(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        hpsm(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        renounceOwnership(overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setHlpRouter(_hlpRouter: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        setHpsm(_hpsm: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapEthToPeggedToken(fxToken: string, tokenOut: string, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: PayableOverrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapHlpTokenToPeggedToken(hlpToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapPeggedTokenToEth(peggedToken: string, fxToken: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        swapPeggedTokenToHlpToken(peggedToken: string, fxToken: string, tokenOut: string, amountIn: BigNumberish, minOut: BigNumberish, receiver: string, signedQuoteData: BytesLike, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        transferOwnership(newOwner: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
    };
}
