import { BaseContract, BigNumber, BigNumberish, BytesLike, CallOverrides, ContractTransaction, Overrides, PopulatedTransaction, Signer, utils } from "ethers";
import { FunctionFragment, Result } from "@ethersproject/abi";
import { Listener, Provider } from "@ethersproject/providers";
import { TypedEventFilter, TypedEvent, TypedListener, OnEvent } from "./common";
export type BalanceStruct = {
    token: string;
    balance: BigNumberish;
    bentoBalance: BigNumberish;
};
export type BalanceStructOutput = [string, BigNumber, BigNumber] & {
    token: string;
    balance: BigNumber;
    bentoBalance: BigNumber;
};
export type PoolFoundStruct = {
    pid: BigNumberish;
    balance: BigNumberish;
};
export type PoolFoundStructOutput = [BigNumber, BigNumber] & {
    pid: BigNumber;
    balance: BigNumber;
};
export type BalanceFullStruct = {
    token: string;
    totalSupply: BigNumberish;
    balance: BigNumberish;
    bentoBalance: BigNumberish;
    bentoAllowance: BigNumberish;
    nonce: BigNumberish;
    bentoAmount: BigNumberish;
    bentoShare: BigNumberish;
    rate: BigNumberish;
};
export type BalanceFullStructOutput = [
    string,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber
] & {
    token: string;
    totalSupply: BigNumber;
    balance: BigNumber;
    bentoBalance: BigNumber;
    bentoAllowance: BigNumber;
    nonce: BigNumber;
    bentoAmount: BigNumber;
    bentoShare: BigNumber;
    rate: BigNumber;
};
export type PairBaseStruct = {
    token: string;
    token0: string;
    token1: string;
    totalSupply: BigNumberish;
};
export type PairBaseStructOutput = [string, string, string, BigNumber] & {
    token: string;
    token0: string;
    token1: string;
    totalSupply: BigNumber;
};
export type PoolsInfoStruct = {
    totalAllocPoint: BigNumberish;
    poolLength: BigNumberish;
};
export type PoolsInfoStructOutput = [BigNumber, BigNumber] & {
    totalAllocPoint: BigNumber;
    poolLength: BigNumber;
};
export type PoolInfoStruct = {
    pid: BigNumberish;
    lpToken: string;
    allocPoint: BigNumberish;
    isPair: boolean;
    factory: string;
    token0: string;
    token1: string;
    name: string;
    symbol: string;
    decimals: BigNumberish;
};
export type PoolInfoStructOutput = [
    BigNumber,
    string,
    BigNumber,
    boolean,
    string,
    string,
    string,
    string,
    string,
    number
] & {
    pid: BigNumber;
    lpToken: string;
    allocPoint: BigNumber;
    isPair: boolean;
    factory: string;
    token0: string;
    token1: string;
    name: string;
    symbol: string;
    decimals: number;
};
export type TokenInfoStruct = {
    token: string;
    decimals: BigNumberish;
    name: string;
    symbol: string;
    DOMAIN_SEPARATOR: BytesLike;
};
export type TokenInfoStructOutput = [
    string,
    BigNumber,
    string,
    string,
    string
] & {
    token: string;
    decimals: BigNumber;
    name: string;
    symbol: string;
    DOMAIN_SEPARATOR: string;
};
export type FactoryStruct = {
    factory: string;
    allPairsLength: BigNumberish;
};
export type FactoryStructOutput = [string, BigNumber] & {
    factory: string;
    allPairsLength: BigNumber;
};
export type UIInfoStruct = {
    ethBalance: BigNumberish;
    sushiBalance: BigNumberish;
    sushiBarBalance: BigNumberish;
    xsushiBalance: BigNumberish;
    xsushiSupply: BigNumberish;
    sushiBarAllowance: BigNumberish;
    factories: FactoryStruct[];
    ethRate: BigNumberish;
    sushiRate: BigNumberish;
    btcRate: BigNumberish;
    pendingSushi: BigNumberish;
    blockTimeStamp: BigNumberish;
    masterContractApproved: boolean[];
};
export type UIInfoStructOutput = [
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    FactoryStructOutput[],
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    boolean[]
] & {
    ethBalance: BigNumber;
    sushiBalance: BigNumber;
    sushiBarBalance: BigNumber;
    xsushiBalance: BigNumber;
    xsushiSupply: BigNumber;
    sushiBarAllowance: BigNumber;
    factories: FactoryStructOutput[];
    ethRate: BigNumber;
    sushiRate: BigNumber;
    btcRate: BigNumber;
    pendingSushi: BigNumber;
    blockTimeStamp: BigNumber;
    masterContractApproved: boolean[];
};
export type RebaseStruct = {
    elastic: BigNumberish;
    base: BigNumberish;
};
export type RebaseStructOutput = [BigNumber, BigNumber] & {
    elastic: BigNumber;
    base: BigNumber;
};
export type AccrueInfoStruct = {
    interestPerSecond: BigNumberish;
    lastAccrued: BigNumberish;
    feesEarnedFraction: BigNumberish;
};
export type AccrueInfoStructOutput = [BigNumber, BigNumber, BigNumber] & {
    interestPerSecond: BigNumber;
    lastAccrued: BigNumber;
    feesEarnedFraction: BigNumber;
};
export type KashiPairPollStruct = {
    collateral: string;
    asset: string;
    oracle: string;
    oracleData: BytesLike;
    totalCollateralShare: BigNumberish;
    userCollateralShare: BigNumberish;
    totalAsset: RebaseStruct;
    userAssetFraction: BigNumberish;
    totalBorrow: RebaseStruct;
    userBorrowPart: BigNumberish;
    currentExchangeRate: BigNumberish;
    spotExchangeRate: BigNumberish;
    oracleExchangeRate: BigNumberish;
    accrueInfo: AccrueInfoStruct;
};
export type KashiPairPollStructOutput = [
    string,
    string,
    string,
    string,
    BigNumber,
    BigNumber,
    RebaseStructOutput,
    BigNumber,
    RebaseStructOutput,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    AccrueInfoStructOutput
] & {
    collateral: string;
    asset: string;
    oracle: string;
    oracleData: string;
    totalCollateralShare: BigNumber;
    userCollateralShare: BigNumber;
    totalAsset: RebaseStructOutput;
    userAssetFraction: BigNumber;
    totalBorrow: RebaseStructOutput;
    userBorrowPart: BigNumber;
    currentExchangeRate: BigNumber;
    spotExchangeRate: BigNumber;
    oracleExchangeRate: BigNumber;
    accrueInfo: AccrueInfoStructOutput;
};
export type PairPollStruct = {
    token: string;
    reserve0: BigNumberish;
    reserve1: BigNumberish;
    totalSupply: BigNumberish;
    balance: BigNumberish;
};
export type PairPollStructOutput = [
    string,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber
] & {
    token: string;
    reserve0: BigNumber;
    reserve1: BigNumber;
    totalSupply: BigNumber;
    balance: BigNumber;
};
export type UserPoolInfoStruct = {
    pid: BigNumberish;
    balance: BigNumberish;
    totalSupply: BigNumberish;
    lpBalance: BigNumberish;
    lpTotalSupply: BigNumberish;
    lpAllowance: BigNumberish;
    reserve0: BigNumberish;
    reserve1: BigNumberish;
    rewardDebt: BigNumberish;
    pending: BigNumberish;
};
export type UserPoolInfoStructOutput = [
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber,
    BigNumber
] & {
    pid: BigNumber;
    balance: BigNumber;
    totalSupply: BigNumber;
    lpBalance: BigNumber;
    lpTotalSupply: BigNumber;
    lpAllowance: BigNumber;
    reserve0: BigNumber;
    reserve1: BigNumber;
    rewardDebt: BigNumber;
    pending: BigNumber;
};
export interface SushiBoringHelpersInterface extends utils.Interface {
    functions: {
        "WBTC()": FunctionFragment;
        "WETH()": FunctionFragment;
        "bar()": FunctionFragment;
        "bentoBox()": FunctionFragment;
        "chef()": FunctionFragment;
        "findBalances(address,address[])": FunctionFragment;
        "findPools(address,uint256[])": FunctionFragment;
        "getBalances(address,address[])": FunctionFragment;
        "getETHRate(address)": FunctionFragment;
        "getPairs(address,uint256,uint256)": FunctionFragment;
        "getPools(uint256[])": FunctionFragment;
        "getTokenInfo(address[])": FunctionFragment;
        "getUIInfo(address,address[],address,address[])": FunctionFragment;
        "maker()": FunctionFragment;
        "owner()": FunctionFragment;
        "pollKashiPairs(address,address[])": FunctionFragment;
        "pollPairs(address,address[])": FunctionFragment;
        "pollPools(address,uint256[])": FunctionFragment;
        "setContracts(address,address,address,address,address,address,address,address,address)": FunctionFragment;
        "sushi()": FunctionFragment;
        "sushiFactory()": FunctionFragment;
        "uniV2Factory()": FunctionFragment;
    };
    encodeFunctionData(functionFragment: "WBTC", values?: undefined): string;
    encodeFunctionData(functionFragment: "WETH", values?: undefined): string;
    encodeFunctionData(functionFragment: "bar", values?: undefined): string;
    encodeFunctionData(functionFragment: "bentoBox", values?: undefined): string;
    encodeFunctionData(functionFragment: "chef", values?: undefined): string;
    encodeFunctionData(functionFragment: "findBalances", values: [string, string[]]): string;
    encodeFunctionData(functionFragment: "findPools", values: [string, BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "getBalances", values: [string, string[]]): string;
    encodeFunctionData(functionFragment: "getETHRate", values: [string]): string;
    encodeFunctionData(functionFragment: "getPairs", values: [string, BigNumberish, BigNumberish]): string;
    encodeFunctionData(functionFragment: "getPools", values: [BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "getTokenInfo", values: [string[]]): string;
    encodeFunctionData(functionFragment: "getUIInfo", values: [string, string[], string, string[]]): string;
    encodeFunctionData(functionFragment: "maker", values?: undefined): string;
    encodeFunctionData(functionFragment: "owner", values?: undefined): string;
    encodeFunctionData(functionFragment: "pollKashiPairs", values: [string, string[]]): string;
    encodeFunctionData(functionFragment: "pollPairs", values: [string, string[]]): string;
    encodeFunctionData(functionFragment: "pollPools", values: [string, BigNumberish[]]): string;
    encodeFunctionData(functionFragment: "setContracts", values: [
        string,
        string,
        string,
        string,
        string,
        string,
        string,
        string,
        string
    ]): string;
    encodeFunctionData(functionFragment: "sushi", values?: undefined): string;
    encodeFunctionData(functionFragment: "sushiFactory", values?: undefined): string;
    encodeFunctionData(functionFragment: "uniV2Factory", values?: undefined): string;
    decodeFunctionResult(functionFragment: "WBTC", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "WETH", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "bar", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "bentoBox", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "chef", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "findBalances", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "findPools", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getBalances", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getETHRate", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPairs", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getPools", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getTokenInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "getUIInfo", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "maker", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "owner", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pollKashiPairs", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pollPairs", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "pollPools", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "setContracts", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sushi", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "sushiFactory", data: BytesLike): Result;
    decodeFunctionResult(functionFragment: "uniV2Factory", data: BytesLike): Result;
    events: {};
}
export interface SushiBoringHelpers extends BaseContract {
    connect(signerOrProvider: Signer | Provider | string): this;
    attach(addressOrName: string): this;
    deployed(): Promise<this>;
    interface: SushiBoringHelpersInterface;
    queryFilter<TEvent extends TypedEvent>(event: TypedEventFilter<TEvent>, fromBlockOrBlockhash?: string | number | undefined, toBlock?: string | number | undefined): Promise<Array<TEvent>>;
    listeners<TEvent extends TypedEvent>(eventFilter?: TypedEventFilter<TEvent>): Array<TypedListener<TEvent>>;
    listeners(eventName?: string): Array<Listener>;
    removeAllListeners<TEvent extends TypedEvent>(eventFilter: TypedEventFilter<TEvent>): this;
    removeAllListeners(eventName?: string): this;
    off: OnEvent<this>;
    on: OnEvent<this>;
    once: OnEvent<this>;
    removeListener: OnEvent<this>;
    functions: {
        WBTC(overrides?: CallOverrides): Promise<[string]>;
        WETH(overrides?: CallOverrides): Promise<[string]>;
        bar(overrides?: CallOverrides): Promise<[string]>;
        bentoBox(overrides?: CallOverrides): Promise<[string]>;
        chef(overrides?: CallOverrides): Promise<[string]>;
        findBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<[BalanceStructOutput[]]>;
        findPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<[PoolFoundStructOutput[]]>;
        getBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<[BalanceFullStructOutput[]]>;
        getETHRate(token: string, overrides?: CallOverrides): Promise<[BigNumber]>;
        getPairs(factory: string, fromID: BigNumberish, toID: BigNumberish, overrides?: CallOverrides): Promise<[PairBaseStructOutput[]]>;
        getPools(pids: BigNumberish[], overrides?: CallOverrides): Promise<[PoolsInfoStructOutput, PoolInfoStructOutput[]]>;
        getTokenInfo(addresses: string[], overrides?: CallOverrides): Promise<[TokenInfoStructOutput[]]>;
        getUIInfo(who: string, factoryAddresses: string[], currency: string, masterContracts: string[], overrides?: CallOverrides): Promise<[UIInfoStructOutput]>;
        maker(overrides?: CallOverrides): Promise<[string]>;
        owner(overrides?: CallOverrides): Promise<[string]>;
        pollKashiPairs(who: string, pairsIn: string[], overrides?: CallOverrides): Promise<[KashiPairPollStructOutput[]]>;
        pollPairs(who: string, addresses: string[], overrides?: CallOverrides): Promise<[PairPollStructOutput[]]>;
        pollPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<[UserPoolInfoStructOutput[]]>;
        setContracts(chef_: string, maker_: string, sushi_: string, WETH_: string, WBTC_: string, sushiFactory_: string, uniV2Factory_: string, bar_: string, bentoBox_: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<ContractTransaction>;
        sushi(overrides?: CallOverrides): Promise<[string]>;
        sushiFactory(overrides?: CallOverrides): Promise<[string]>;
        uniV2Factory(overrides?: CallOverrides): Promise<[string]>;
    };
    WBTC(overrides?: CallOverrides): Promise<string>;
    WETH(overrides?: CallOverrides): Promise<string>;
    bar(overrides?: CallOverrides): Promise<string>;
    bentoBox(overrides?: CallOverrides): Promise<string>;
    chef(overrides?: CallOverrides): Promise<string>;
    findBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<BalanceStructOutput[]>;
    findPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<PoolFoundStructOutput[]>;
    getBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<BalanceFullStructOutput[]>;
    getETHRate(token: string, overrides?: CallOverrides): Promise<BigNumber>;
    getPairs(factory: string, fromID: BigNumberish, toID: BigNumberish, overrides?: CallOverrides): Promise<PairBaseStructOutput[]>;
    getPools(pids: BigNumberish[], overrides?: CallOverrides): Promise<[PoolsInfoStructOutput, PoolInfoStructOutput[]]>;
    getTokenInfo(addresses: string[], overrides?: CallOverrides): Promise<TokenInfoStructOutput[]>;
    getUIInfo(who: string, factoryAddresses: string[], currency: string, masterContracts: string[], overrides?: CallOverrides): Promise<UIInfoStructOutput>;
    maker(overrides?: CallOverrides): Promise<string>;
    owner(overrides?: CallOverrides): Promise<string>;
    pollKashiPairs(who: string, pairsIn: string[], overrides?: CallOverrides): Promise<KashiPairPollStructOutput[]>;
    pollPairs(who: string, addresses: string[], overrides?: CallOverrides): Promise<PairPollStructOutput[]>;
    pollPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<UserPoolInfoStructOutput[]>;
    setContracts(chef_: string, maker_: string, sushi_: string, WETH_: string, WBTC_: string, sushiFactory_: string, uniV2Factory_: string, bar_: string, bentoBox_: string, overrides?: Overrides & {
        from?: string | Promise<string>;
    }): Promise<ContractTransaction>;
    sushi(overrides?: CallOverrides): Promise<string>;
    sushiFactory(overrides?: CallOverrides): Promise<string>;
    uniV2Factory(overrides?: CallOverrides): Promise<string>;
    callStatic: {
        WBTC(overrides?: CallOverrides): Promise<string>;
        WETH(overrides?: CallOverrides): Promise<string>;
        bar(overrides?: CallOverrides): Promise<string>;
        bentoBox(overrides?: CallOverrides): Promise<string>;
        chef(overrides?: CallOverrides): Promise<string>;
        findBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<BalanceStructOutput[]>;
        findPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<PoolFoundStructOutput[]>;
        getBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<BalanceFullStructOutput[]>;
        getETHRate(token: string, overrides?: CallOverrides): Promise<BigNumber>;
        getPairs(factory: string, fromID: BigNumberish, toID: BigNumberish, overrides?: CallOverrides): Promise<PairBaseStructOutput[]>;
        getPools(pids: BigNumberish[], overrides?: CallOverrides): Promise<[PoolsInfoStructOutput, PoolInfoStructOutput[]]>;
        getTokenInfo(addresses: string[], overrides?: CallOverrides): Promise<TokenInfoStructOutput[]>;
        getUIInfo(who: string, factoryAddresses: string[], currency: string, masterContracts: string[], overrides?: CallOverrides): Promise<UIInfoStructOutput>;
        maker(overrides?: CallOverrides): Promise<string>;
        owner(overrides?: CallOverrides): Promise<string>;
        pollKashiPairs(who: string, pairsIn: string[], overrides?: CallOverrides): Promise<KashiPairPollStructOutput[]>;
        pollPairs(who: string, addresses: string[], overrides?: CallOverrides): Promise<PairPollStructOutput[]>;
        pollPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<UserPoolInfoStructOutput[]>;
        setContracts(chef_: string, maker_: string, sushi_: string, WETH_: string, WBTC_: string, sushiFactory_: string, uniV2Factory_: string, bar_: string, bentoBox_: string, overrides?: CallOverrides): Promise<void>;
        sushi(overrides?: CallOverrides): Promise<string>;
        sushiFactory(overrides?: CallOverrides): Promise<string>;
        uniV2Factory(overrides?: CallOverrides): Promise<string>;
    };
    filters: {};
    estimateGas: {
        WBTC(overrides?: CallOverrides): Promise<BigNumber>;
        WETH(overrides?: CallOverrides): Promise<BigNumber>;
        bar(overrides?: CallOverrides): Promise<BigNumber>;
        bentoBox(overrides?: CallOverrides): Promise<BigNumber>;
        chef(overrides?: CallOverrides): Promise<BigNumber>;
        findBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<BigNumber>;
        findPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<BigNumber>;
        getBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<BigNumber>;
        getETHRate(token: string, overrides?: CallOverrides): Promise<BigNumber>;
        getPairs(factory: string, fromID: BigNumberish, toID: BigNumberish, overrides?: CallOverrides): Promise<BigNumber>;
        getPools(pids: BigNumberish[], overrides?: CallOverrides): Promise<BigNumber>;
        getTokenInfo(addresses: string[], overrides?: CallOverrides): Promise<BigNumber>;
        getUIInfo(who: string, factoryAddresses: string[], currency: string, masterContracts: string[], overrides?: CallOverrides): Promise<BigNumber>;
        maker(overrides?: CallOverrides): Promise<BigNumber>;
        owner(overrides?: CallOverrides): Promise<BigNumber>;
        pollKashiPairs(who: string, pairsIn: string[], overrides?: CallOverrides): Promise<BigNumber>;
        pollPairs(who: string, addresses: string[], overrides?: CallOverrides): Promise<BigNumber>;
        pollPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<BigNumber>;
        setContracts(chef_: string, maker_: string, sushi_: string, WETH_: string, WBTC_: string, sushiFactory_: string, uniV2Factory_: string, bar_: string, bentoBox_: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<BigNumber>;
        sushi(overrides?: CallOverrides): Promise<BigNumber>;
        sushiFactory(overrides?: CallOverrides): Promise<BigNumber>;
        uniV2Factory(overrides?: CallOverrides): Promise<BigNumber>;
    };
    populateTransaction: {
        WBTC(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        WETH(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        bar(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        bentoBox(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        chef(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        findBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        findPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getBalances(who: string, addresses: string[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getETHRate(token: string, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPairs(factory: string, fromID: BigNumberish, toID: BigNumberish, overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getPools(pids: BigNumberish[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getTokenInfo(addresses: string[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        getUIInfo(who: string, factoryAddresses: string[], currency: string, masterContracts: string[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        maker(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        owner(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        pollKashiPairs(who: string, pairsIn: string[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        pollPairs(who: string, addresses: string[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        pollPools(who: string, pids: BigNumberish[], overrides?: CallOverrides): Promise<PopulatedTransaction>;
        setContracts(chef_: string, maker_: string, sushi_: string, WETH_: string, WBTC_: string, sushiFactory_: string, uniV2Factory_: string, bar_: string, bentoBox_: string, overrides?: Overrides & {
            from?: string | Promise<string>;
        }): Promise<PopulatedTransaction>;
        sushi(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        sushiFactory(overrides?: CallOverrides): Promise<PopulatedTransaction>;
        uniV2Factory(overrides?: CallOverrides): Promise<PopulatedTransaction>;
    };
}
