import { ethers } from "ethers";
import { WNATIVE, KASHI_ADDRESS } from "@sushiswap/core-sdk";
import { SushiKashi__factory } from "../contracts";
// This file is a simplied version of
// https://github.com/sushiswap/sushiswap-interface/blob/canary/src/entities/KashiCooker.ts
var Action;
(function (Action) {
    Action[Action["ADD_ASSET"] = 1] = "ADD_ASSET";
    Action[Action["REPAY"] = 2] = "REPAY";
    Action[Action["REMOVE_COLLATERAL"] = 4] = "REMOVE_COLLATERAL";
    Action[Action["BORROW"] = 5] = "BORROW";
    Action[Action["GET_REPAY_PART"] = 7] = "GET_REPAY_PART";
    Action[Action["ADD_COLLATERAL"] = 10] = "ADD_COLLATERAL";
    Action[Action["BENTO_DEPOSIT"] = 20] = "BENTO_DEPOSIT";
    Action[Action["BENTO_WITHDRAW"] = 21] = "BENTO_WITHDRAW";
    Action[Action["BENTO_SETAPPROVAL"] = 24] = "BENTO_SETAPPROVAL";
})(Action || (Action = {}));
export default class KashiCooker {
    constructor(pool, // add this back in once moved to sdk
    account, fxToken, chainId) {
        this.pool = pool;
        this.account = account;
        this.fxToken = fxToken;
        this.chainId = chainId;
        this.actions = [];
        this.values = [];
        this.datas = [];
        this.addCollateral = (amount) => {
            // we currently only support depositing collateral from users wallet
            // (dont allow users to use collateral already in Bento Box).
            // SHARE will need to be adjusted when adding the ability to
            // add collateral from Bento Box.
            const SHARE = ethers.BigNumber.from("-2");
            this.addAction(Action.BENTO_DEPOSIT, ethers.utils.defaultAbiCoder.encode(["address", "address", "int256", "int256"], [
                this.useNativeCollateral
                    ? ethers.constants.AddressZero
                    : this.pool.collateral.address,
                this.account,
                amount,
                0,
            ]), this.useNativeCollateral ? amount : ethers.constants.Zero);
            this.addAction(Action.ADD_COLLATERAL, ethers.utils.defaultAbiCoder.encode(["int256", "address", "bool"], [SHARE, this.account, false]), ethers.constants.Zero);
        };
        this.removeCollateral = (share) => {
            this.addAction(Action.REMOVE_COLLATERAL, ethers.utils.defaultAbiCoder.encode(["int256", "address"], [share, this.account]), ethers.constants.Zero);
            this.addAction(Action.BENTO_WITHDRAW, ethers.utils.defaultAbiCoder.encode(["address", "address", "int256", "int256"], [
                this.useNativeCollateral
                    ? ethers.constants.AddressZero
                    : this.pool.collateral.address,
                this.account,
                0,
                share,
            ]), ethers.constants.Zero);
        };
        this.borrow = (amount) => {
            this.addAction(Action.BORROW, ethers.utils.defaultAbiCoder.encode(["int256", "address"], [amount, this.account]), ethers.constants.Zero);
            // we currently dont allow the user to keep their borrowed funds in Bento Box
            // To add this functionality make the following conditional.
            this.addAction(Action.BENTO_WITHDRAW, ethers.utils.defaultAbiCoder.encode(["address", "address", "int256", "int256"], [this.fxToken.address, this.account, amount, 0]), ethers.constants.Zero);
        };
        this.repay = (amount) => {
            // we currently only support depositing collateral from users wallet
            // (dont allow users to use collateral already in Bento Box).
            this.addAction(Action.BENTO_DEPOSIT, ethers.utils.defaultAbiCoder.encode(["address", "address", "int256", "int256"], [this.fxToken.address, this.account, amount, 0]), ethers.constants.Zero);
            this.addAction(Action.GET_REPAY_PART, ethers.utils.defaultAbiCoder.encode(["int256"], [-1]), ethers.constants.Zero);
            this.addAction(Action.REPAY, ethers.utils.defaultAbiCoder.encode(["int256", "address", "bool"], [-1, this.account, false]), ethers.constants.Zero);
        };
        this.addAsset = (amount) => {
            this.addAction(Action.BENTO_DEPOSIT, ethers.utils.defaultAbiCoder.encode(["address", "address", "int256", "int256"], [this.fxToken.address, this.account, amount, 0]), ethers.constants.Zero);
            this.addAction(Action.ADD_ASSET, ethers.utils.defaultAbiCoder.encode(["int256", "address", "bool"], [-2, this.account, false]), ethers.constants.Zero);
        };
        this.cook = (signer, options) => {
            const kashiPairContract = SushiKashi__factory.connect(this.pool.address, signer);
            return kashiPairContract.cook(this.actions, this.values, this.datas, {
                ...options,
                value: this.values.reduce((sum, next) => sum.add(next), ethers.constants.Zero),
            });
        };
        this.addAction = (action, data, value) => {
            this.actions.push(action);
            this.datas.push(data);
            this.values.push(value);
        };
        this.useNativeCollateral =
            pool.collateral.address === WNATIVE[this.chainId].address;
    }
    approve(signature) {
        this.addAction(Action.BENTO_SETAPPROVAL, ethers.utils.defaultAbiCoder.encode(["address", "address", "bool", "uint8", "bytes32", "bytes32"], [
            this.account,
            KASHI_ADDRESS[this.chainId],
            true,
            signature.v,
            signature.r,
            signature.s,
        ]), ethers.constants.Zero);
    }
}
