import { BigNumber, Signer, ethers, ContractTransaction, Signature } from "ethers";
import { SingleCollateralVaultNetwork } from "../types/network";
import { ERC2612 } from "../contracts";
import { TokenInfo } from "../index";
import { Provider } from "@ethersproject/providers";
declare const PERMIT_IMPLEMENTATION_NAMES: readonly ["ERC2612"];
type PermitImplementation = typeof PERMIT_IMPLEMENTATION_NAMES[number];
type PermitHandler = (token: ERC2612, allowanceTarget: string, signer: Signer, provider: Provider, minimumAllowance: BigNumber) => Promise<void>;
export type AllowanceResult = {
    didAlreadyHaveEnough: boolean;
    getApprovalTxToExecute?: () => Promise<ContractTransaction>;
};
/**
 * Checks if the account has enough allowance for the given ERC20 token.
 * If not, it will request the allowance.
 * This will try to use permits if the contract supports ERC2612.
 * @param account The account to ensure allowance for.
 * @param tokenInfo The ERC20 to approve.
 * @param allowanceTarget The spender (EOA or contract) address for the allowance.
 * @param signer The signer of the account.
 * @param minimumAllowance The minimum amount that must be approved.
 * @param currentAllowance If provided, it will skip the allowance check and use this value instead.
 * @returns an AllowanceResult struct.
 */
export declare const ensureHasAllowance: (account: string, tokenInfo: TokenInfo, allowanceTarget: string, signer: Signer, minimumAllowance: BigNumber, currentAllowance?: BigNumber) => Promise<AllowanceResult>;
export declare const PERMIT_HANDLERS: Record<PermitImplementation, PermitHandler>;
export type PermitExecutionArgs = {
    tokenAddress: string;
    tokenHolderAddress: string;
    signature: Signature;
    allowanceTarget: string;
    minimumAllowance: BigNumber;
    deadline: number;
    signer: Signer;
};
export type PermitExecutionArgsRemote = {
    tokenAddress: string;
    tokenHolderAddress: string;
    signature: Signature;
    allowanceTarget: string;
    minimumAllowanceHex: string;
    deadline: number;
    chainId: number;
};
export declare const executePermitLocally: (args: PermitExecutionArgs) => Promise<ContractTransaction>;
export declare const getIsKashiApproved: (account: string, network: SingleCollateralVaultNetwork, signer: ethers.Signer) => Promise<boolean>;
export declare const signKashiApproval: (account: string, network: SingleCollateralVaultNetwork, signer: ethers.Signer) => Promise<ethers.Signature>;
export {};
