export const CACHE_DURATION_INFINITE = -1;
class CachedObject {
    constructor(duration) {
        this.lastFetchedTime = 0;
        this.duration = duration;
    }
    get isExpired() {
        return (Date.now() > this.lastFetchedTime + this.duration &&
            this.duration !== CACHE_DURATION_INFINITE);
    }
    get isAvailable() {
        return !!this.value && !this.isExpired;
    }
    async fetch(fetcher, forceFetch = false) {
        if (!forceFetch && !this.isExpired && !!this.value) {
            return this.value;
        }
        // Update the value.
        this.value = await fetcher();
        this.lastFetchedTime = Date.now();
        return this.value;
    }
    /// Returns cached value, even if expired; throws if empty.
    get() {
        if (!this.value)
            throw new Error("CachedObject: unavailable");
        return this.value;
    }
}
export { CachedObject };
