import { BigNumber } from "ethers";
import { Network, TokenTransferProxyNetwork } from "../types/network";
import { CachedObject } from "./cachedObject";
export type Peg = {
    fxToken: string;
    peggedToken: string;
};
export declare const cachedArbitrumPegs: CachedObject<Peg[]>;
type PsmFeeCache = Record<string, {
    deposit?: number;
    withdraw?: number;
}>;
export declare const cachedArbitrumFees: CachedObject<PsmFeeCache>;
export declare const fetchPsmFeesBasisPoints: () => Promise<PsmFeeCache>;
export declare const getPsmFeeBasisPoints: (token: string, isDeposit: boolean, force?: boolean) => Promise<number | undefined>;
export declare const getPsmFeeBasisPointsFromCache: (token: string, isDeposit: boolean) => number | undefined;
export declare const getTokenPegs: (network: Network, force?: boolean) => Promise<Peg[]>;
export declare const isTokenPegged: (fxToken: string, peggedToken: string, network: Network) => Promise<boolean>;
/**
 * Combines fees and returns the total fee in basis points.
 * @note this only works if the fees are compounded on the same amount,
 * e.g amount -> fee collected -> fee collected again.
 */
export declare const combineFees: (fee1: number, fee2: number, fee1Divisor?: number, fee2Divisor?: number) => number;
/**
 * Returns a new amount accounting for slippage.
 * @param amount The amount to calculate the slippage-tolerant amount for.
 * @param slippage The slippage as a percentage.
 */
export declare const getMinOut: (amount: BigNumber, slippage: number) => BigNumber;
export declare const getTokenTransferProxyAddress: (network: TokenTransferProxyNetwork) => string;
export {};
