import { BigNumber, ethers } from "ethers";
import { Network } from "../types/network";
import { Pair } from "../types/trade";
import { MarketPrice as LegacyMarketPrice } from "../components/trade/platforms/legacyInterface";
export type SignerOrProvider = ethers.Signer | ethers.providers.Provider;
export declare const getDeadline: (deadline?: number) => number;
export declare const getCurrentUnixTimestamp: () => number;
/**
 * Adjusts a BigNumber by the difference between the current and desired decimals
 * @param value The value to transform
 * @param fromDecimals the current decimals of the number
 * @param toDecimals the desired decimals of the number
 * @returns the transformed value
 */
export declare const transformDecimals: (value: BigNumber, fromDecimals: number, toDecimals: number) => BigNumber;
export declare function mustExist<Type>(value: Type | undefined | null, name: string): Type;
export declare const getNetworkFromSignerOrProvider: (signerOrProvider: SignerOrProvider) => Promise<Network>;
export declare const pairToString: (pair: Pair) => string;
export declare const pairFromString: (value: string) => Pair;
export declare const pairToBaseTokenAddress: (pair: Pair, network?: Network) => string;
export declare const pairToQuoteTokenAddress: (pair: Pair, network?: Network) => string;
export declare const getUsdQuotedPair: (baseSymbol: string) => Pair;
export declare const isSamePair: (a: Pair, b: Pair) => boolean;
export declare const getReversedPair: (pair: Pair) => Pair;
/**
 * Reverses a market price or legacy market price object by calculating the
 * inverse of its index, best ask, and best bid values. If the input is a
 * legacy market price object, the calculation is done using `BigNumber` with
 * `LEGACY_PRICE_UNIT` precision.
 * @param price The market price or legacy market price object to reverse
 * @returns The reversed market price or legacy market price object
 */
export declare const getReversedMarketPriceLegacy: (price: LegacyMarketPrice) => LegacyMarketPrice;
export declare const getReversedPrice: (price: BigNumber) => BigNumber;
/**
 * @param percentage the percent to be turned to bps
 * @example percentageToBasisPoints(1) // 100
 */
export declare const percentageToBasisPoints: (percentage: number) => number;
export declare const removeArrayDuplicates: <T>(array: T[]) => T[];
export declare const allSettledResults: <T>(promises: Promise<T>[]) => Promise<T[]>;
export declare const bnToNumber: (bn: BigNumber, decimals: number) => number;
export declare const isSameAddress: (a: string | undefined | null, b: string | undefined | null) => boolean;
export declare const replaceWrappedSymbolForNative: (symbol: string) => string;
