import { TokenInfo } from "@uniswap/token-lists";
import { BigNumber } from "ethers";
import { Network } from "../types/network";
export declare const getCoingeckoPrices: (tokens: string[], network: Network) => Promise<Record<string, number | undefined>>;
/**
 * Gets the usd price of a token
 * @param token the token for which to get the usd value
 * @returns the usd price of a token, or undefined if it cannot be fetched
 */
export declare const getUsdPrice: (token: TokenInfo) => Promise<number | undefined>;
/**
 * Gets the usd value for an amount of a token
 * @param token the token for which to get the usd value
 * @param amount the amount of token for which to get the value of
 * @returns the usd value of the amount of token, or undefined if a price cannot be fetched
 */
export declare const getUsdValue: (token: TokenInfo, amount: BigNumber) => Promise<number | undefined>;
/**
 * Returns the usd value difference as a ratio.
 * @param usdValueIn the usd value initially
 * @param usdValueOut the usd value output
 * @returns usd value difference as a ratio
 */
export declare const getPriceImpact: (usdValueIn: number, usdValueOut: number) => number;
