import { ethers } from "ethers";
import { SECONDS_IN_A_YEAR_BN } from "../constants";
import { BENTOBOX_ADDRESS } from "@sushiswap/core-sdk";
import { createMultiCallContract } from "./contract";
import sushiKashiAbi from "../abis/sushi/SushiKashi.json";
import sushiBentoAbi from "../abis/sushi/SushiBento.json";
const e10 = (exponent) => {
    return ethers.BigNumber.from("10").pow(ethers.BigNumber.from(exponent));
};
const accrue = (amount, accrueInfo, includePrincipal = false) => {
    const elapsedSeconds = ethers.BigNumber.from(Date.now())
        .div("1000")
        .sub(accrueInfo.lastAccrued);
    return amount
        .mul(accrueInfo.interestPerSecond)
        .mul(elapsedSeconds)
        .div(e10(18))
        .add(includePrincipal ? amount : ethers.constants.Zero);
};
export const getKashiPoolMulticall = (account, pool, chainId) => {
    const bentoBoxAddress = BENTOBOX_ADDRESS[chainId];
    const kashiMultiCall = createMultiCallContract(pool.address, sushiKashiAbi);
    const bentoBoxMutiCall = createMultiCallContract(bentoBoxAddress, sushiBentoAbi);
    const kashiCalls = {
        accureInfo: kashiMultiCall.accrueInfo(),
        totalAsset: kashiMultiCall.totalAsset(),
        totalBorrow: kashiMultiCall.totalBorrow(),
        totalCollateralShare: kashiMultiCall.totalCollateralShare(),
        userBorrowPart: kashiMultiCall.userBorrowPart(account),
        userCollateralShare: kashiMultiCall.userCollateralShare(account),
        exchangeRate: kashiMultiCall.exchangeRate(),
        collateralTotals: bentoBoxMutiCall.totals(pool.collateral.address),
    };
    return kashiCalls;
};
export const kashiMulticallResultToSingleCollateralVaultData = (account, config, data) => {
    const { accureInfo, totalAsset, totalBorrow, totalCollateralShare, userBorrowPart, userCollateralShare, exchangeRate, collateralTotals, } = data;
    const interestPerYear = accureInfo.interestPerSecond.mul(SECONDS_IN_A_YEAR_BN);
    const userCollateralAmount = userCollateralShare
        .mul(collateralTotals.elastic)
        .div(collateralTotals.base);
    const currentBorrowAmount = accrue(totalBorrow.elastic, accureInfo, true);
    const debt = totalBorrow.base.isZero()
        ? userBorrowPart?.mul(currentBorrowAmount)
        : userBorrowPart?.mul(currentBorrowAmount).div(totalBorrow.base);
    return {
        account,
        debt,
        collateral: {
            ...config.collateral,
            amount: userCollateralAmount,
        },
        interestPerYear,
        currentBorrowAmount,
        availableToBorrow: totalAsset.elastic,
        totalCollateralShare,
        exchangeRate,
    };
};
