import { ethers } from "ethers";
import { ProtocolParameters } from "../components/Protocol";
import { Collateral, CollateralSymbol } from "../types/collaterals";
import { FxToken } from "../types/fxTokens";
import { VaultCollateralToken } from "../types/vaults";
import { VaultData, Vault, SingleCollateralVault, SingleCollateralVaultData } from "../types/vaults";
export declare const calculateCollateralAsEth: (vault: VaultData, collaterals: Collateral[]) => ethers.BigNumber;
export declare const calculateMinimumMintingRatio: (vault: VaultData, collaterals: Collateral[]) => ethers.BigNumber;
export declare const calculateInterestRate: (vault: VaultData, collaterals: Collateral[]) => ethers.BigNumber;
export declare const calculateLiquidationFee: (vault: VaultData, collaterals: Collateral[]) => ethers.BigNumber;
export declare const calculateCollateralShares: (vault: VaultData, collaterals: Collateral[]) => {
    symbol: CollateralSymbol;
    share: ethers.BigNumber;
}[];
export declare const calculateDebtAsEth: (vault: VaultData, fxToken: FxToken) => ethers.BigNumber;
export declare const calculateCollateralAsFxToken: (vault: VaultData, collaterals: Collateral[], fxToken: FxToken) => ethers.BigNumber;
export declare const calculateCollateralRatio: (vault: VaultData, collaterals: Collateral[], fxToken: FxToken) => ethers.BigNumber;
export declare const calculateReedmable: (vault: VaultData, collaterals: Collateral[], fxToken: FxToken) => {
    isRedeemable: boolean;
    redeemableTokens: ethers.BigNumber;
};
export declare const createVault: (vault: VaultData, protocolParamters: ProtocolParameters, fxToken: FxToken, collaterals: Collateral[]) => Vault;
export declare const createSingleCollateralVault: (vaultData: SingleCollateralVaultData, fxToken: FxToken) => SingleCollateralVault;
export declare const calculateSingleCollateralVaultLiquidationPrice: (debt: ethers.BigNumber, collateral: VaultCollateralToken<string>, collateralValueInFx: ethers.BigNumber, minCollateralRatio: ethers.BigNumber) => ethers.BigNumber;
export declare const vaultUtils: {
    calculateWithdrawableCollateral: (vault: Vault, collateral: Collateral) => ethers.BigNumber;
    calculateAdditionalCollateralRequired: (vault: Vault, collateralSymbol: CollateralSymbol, collaterals: Collateral[], fxToken: FxToken, _protocolParams: ProtocolParameters) => ethers.BigNumber;
    calculateLiquidationPriceOfVaultWithOneCollateral: (vault: Vault, collateral: Collateral) => ethers.BigNumber;
};
