import { NETWORK_NAME_TO_CHAIN_ID } from "../constants";
import { ethers } from "ethers";
const RECONNECT_WAIT_TIME = 500;
const connections = {};
export const openPersistentWebsocketRpcConnection = (url, network, shouldLogStdout = true, connectionId) => {
    if (!connectionId) {
        connectionId = Object.keys(connections).length + 1;
    }
    const provider = new ethers.providers.WebSocketProvider(url, {
        name: network,
        chainId: NETWORK_NAME_TO_CHAIN_ID[network],
    });
    let hasRequestedCloseConnection = false;
    const closeConnection = () => {
        if (!connections[connectionId]) {
            // Already closed.
            return;
        }
        hasRequestedCloseConnection = true;
        provider._websocket.close();
        connections[connectionId] = undefined;
    };
    if (!connections[connectionId]) {
        connections[connectionId] = {
            provider,
            closeConnection,
        };
    }
    else {
        connections[connectionId].provider = provider;
    }
    log(connectionId, "initialising connection", shouldLogStdout);
    // If websocket connection is closed.
    provider._websocket.onclose = async (event) => {
        log(connectionId, `connection closed${event?.code ? ` (${event.code})` : ""}`, shouldLogStdout);
        if (hasRequestedCloseConnection) {
            return;
        }
        await new Promise((r) => setTimeout(r, RECONNECT_WAIT_TIME));
        openPersistentWebsocketRpcConnection(url, network, shouldLogStdout, connectionId);
    };
    return connections[connectionId];
};
const log = (id, message, shouldLog) => {
    if (!shouldLog) {
        return;
    }
    console.log(`[${new Date().toLocaleString()}] [handle-sdk ws connection #${id}] ${message}`);
};
